@@ -43,7 +43,7 @@ database_aspect_assign(
 }
 
 extern void
-database_aspect_clear(
+database_aspect_discharge(
   struct database_aspect *const         io_aspect)
 {
 
@@ -53,16 +53,6 @@ database_aspect_clear(
   return;
 }
 
-extern void
-database_aspect_discharge(
-  struct database_aspect *const         io_aspect)
-{
-
-  database_aspect_clear(io_aspect);
-
-  return;
-}
-
 extern void
 database_aspect_password_delete(
   struct database_aspect *const         io_aspect)
