@@ -380,7 +380,7 @@ database_property_save(
 
     if (0 == l_aspect.m_tag[0])
     {
-      strcpy(l_aspect.m_tag, DATABASE_CONFIG_DEFAULT_TAG);
+      g_strlcpy(l_aspect.m_tag, DATABASE_CONFIG_DEFAULT_TAG, sizeof(l_aspect.m_tag));
       gtk_entry_set_text((*io_db).m_tag_entry, l_aspect.m_tag);
     }
 
@@ -457,7 +457,7 @@ database_property_test(
     }
 
     l_dialog= GTK_DIALOG(gtk_message_dialog_new(
-      mainw(),
+      get_main_window(),
       GTK_DIALOG_MODAL,
       GTK_MESSAGE_INFO,
       GTK_BUTTONS_OK,
@@ -470,7 +470,7 @@ database_property_test(
   if (l_error)
   {
     l_dialog= GTK_DIALOG(gtk_message_dialog_new(
-      mainw(),
+      get_main_window(),
       GTK_DIALOG_MODAL,
       GTK_MESSAGE_ERROR,
       GTK_BUTTONS_CLOSE,
@@ -550,11 +550,11 @@ database_aspect_property(
       break;
     }
 
-    gtk_window_set_transient_for(GTK_WINDOW(l_dialog), mainw());
+    gtk_window_set_transient_for(GTK_WINDOW(l_dialog), get_main_window());
 
     if (0 == (*io_aspect).m_tag[0])
     {
-      strcpy((*io_aspect).m_tag, DATABASE_CONFIG_DEFAULT_TAG);
+      g_strlcpy((*io_aspect).m_tag, DATABASE_CONFIG_DEFAULT_TAG, sizeof((*io_aspect).m_tag));
     }
 
     l_found= 0;
@@ -562,7 +562,7 @@ database_aspect_property(
 
     if (0 == (*io_aspect).m_tag[0])
     {
-      strcpy((*io_aspect).m_tag, DATABASE_CONFIG_DEFAULT_TAG);
+      g_strlcpy((*io_aspect).m_tag, DATABASE_CONFIG_DEFAULT_TAG, sizeof((*io_aspect).m_tag));
     }
 
     for (l_slot= 0; l_db.m_config.m_count > l_slot; l_slot++)
