@@ -106,6 +106,7 @@ extern void
 item_draw(
   struct item*const                     io_item,
   cairo_t*const                         i_cr,
+  double const                          i_scale,
   struct item_draw_options const*const  i_option)
 {
   struct item_draw_context              l_ctx;
@@ -128,6 +129,7 @@ item_draw(
     }
 
     l_ctx.m_cr= i_cr;
+    l_ctx.m_scale= i_scale;
 
     if (item_draw_design == l_ctx.m_option.m_type)
     {
@@ -146,21 +148,21 @@ item_draw(
 extern void
 item_move_down(
   struct item*const                     io_item,
-  struct item_node*const                i_node)
+  struct item_node*const                io_node)
 {
   struct item_node*                     l_node;
 
   do
   {
-    l_node= (*i_node).m_prev;
+    l_node= (*io_node).m_prev;
 
     if (0 == l_node)
     {
       break;
     }
   
-    item_node_unlink(io_item, i_node);
-    item_node_insert_before(io_item, l_node, i_node);
+    item_node_unlink(io_item, io_node);
+    item_node_insert_before(io_item, l_node, io_node);
 
   }while(0);
 
@@ -170,21 +172,21 @@ item_move_down(
 extern void
 item_move_to_back(
   struct item*const                     io_item,
-  struct item_node*const                i_node)
+  struct item_node*const                io_node)
 {
   struct item_node*                     l_node;
 
   do
   {
-    l_node= (*i_node).m_prev;
+    l_node= (*io_node).m_prev;
 
     if (0 == l_node)
     {
       break;
     }
   
-    item_node_unlink(io_item, i_node);
-    item_node_insert_before(io_item, (*io_item).m_head, i_node);
+    item_node_unlink(io_item, io_node);
+    item_node_insert_before(io_item, (*io_item).m_head, io_node);
 
   }while(0);
 
@@ -194,21 +196,21 @@ item_move_to_back(
 extern void
 item_move_to_front(
   struct item*const                     io_item,
-  struct item_node*const                i_node)
+  struct item_node*const                io_node)
 {
   struct item_node*                     l_node;
 
   do
   {
-    l_node= (*i_node).m_next;
+    l_node= (*io_node).m_next;
 
     if (0 == l_node)
     {
       break;
     }
   
-    item_node_unlink(io_item, i_node);
-    item_node_append(io_item, i_node);
+    item_node_unlink(io_item, io_node);
+    item_node_append(io_item, io_node);
 
   }while(0);
 
@@ -218,21 +220,21 @@ item_move_to_front(
 extern void
 item_move_up(
   struct item*const                     io_item,
-  struct item_node*const                i_node)
+  struct item_node*const                io_node)
 {
   struct item_node*                     l_node;
 
   do
   {
-    l_node= (*i_node).m_next;
+    l_node= (*io_node).m_next;
 
     if (0 == l_node)
     {
       break;
     }
   
-    item_node_unlink(io_item, i_node);
-    item_node_insert_after(io_item, l_node, i_node);
+    item_node_unlink(io_item, io_node);
+    item_node_insert_after(io_item, l_node, io_node);
 
   }while(0);
 
@@ -240,21 +242,57 @@ item_move_up(
 }
 
 extern void
+item_node_get_nth(
+  struct item_node**                    o_node,
+  struct item*const                     io_item,
+  unsigned const                        i_slot)
+{
+  struct item_node*                     l_node;
+  unsigned                              l_slot;
+
+  (*o_node)= 0;
+  l_node= (*io_item).m_head;
+  l_slot= 0;
+
+  do
+  {
+
+    if (0 == l_node)
+    {
+      break;
+    }
+
+    if (i_slot == l_slot)
+    {
+      (*o_node)= l_node;
+      break;
+    }
+
+    l_node= (*l_node).m_next;
+    l_slot++;
+
+  }while(1);
+
+  return;
+}
+
+extern int
 item_node_in_event(
   struct item_node**                    o_node,
-  enum event_type*const                 o_type,
+  cairo_t*                              io_cr,
   struct item const*const               i_item,
   struct geom_point const*const         i_event,
   double const                          i_scale)
 {
   struct item_in_event                  l_ctx;
+  int                                   l_hit;
   struct item_node*                     l_node;
 
   (*o_node)= 0;
-  (*o_type)= event_none;
   memset(&l_ctx, 0, sizeof(l_ctx));
   l_ctx.m_event= *i_event;
   l_ctx.m_scale= i_scale; 
+  l_hit= 0;
   l_node= (*i_item).m_tail;
 
   do
@@ -265,10 +303,9 @@ item_node_in_event(
       break;
     }
 
-    l_ctx.m_selected= (*l_node).m_selected;
-    (*(*l_node).m_method.m_in_event)(o_type, &(*l_node).m_object, &l_ctx);
+    l_hit= (*(*l_node).m_method.m_in_event)(&(*l_node).m_object, io_cr, &l_ctx);
 
-    if (event_none != (*o_type))
+    if (l_hit)
     {
       (*o_node)= l_node;
       break;
@@ -278,7 +315,7 @@ item_node_in_event(
 
   }while(1);
 
-  return;
+  return l_hit;
 }
 
 extern void
@@ -312,9 +349,7 @@ item_selected_move(
 
 extern void
 item_normalize(
-  struct item*const                     io_item,
-  double const                          i_bound_width,
-  double const                          i_bound_height)
+  struct item*const                     io_item)
 {
   struct item_node*                     l_node;
 
@@ -328,10 +363,7 @@ item_normalize(
       break;
     }
 
-    (*(*l_node).m_method.m_normalize)(
-      &(*l_node).m_object, 
-      i_bound_width,
-      i_bound_height);
+    (*(*l_node).m_method.m_normalize)(&(*l_node).m_object);
 
     l_node= (*l_node).m_next;
   
@@ -342,9 +374,7 @@ item_normalize(
 
 extern void
 item_selected_normalize(
-  struct item*const                     io_item,
-  double const                          i_bound_width,
-  double const                          i_bound_height)
+  struct item*const                     io_item)
 {
   struct item_node*                     l_node;
 
@@ -360,10 +390,7 @@ item_selected_normalize(
 
     if ((*l_node).m_selected)
     {
-      (*(*l_node).m_method.m_normalize)(
-        &(*l_node).m_object, 
-        i_bound_width,
-        i_bound_height);
+      (*(*l_node).m_method.m_normalize)(&(*l_node).m_object);
     }
 
     l_node= (*l_node).m_next;
@@ -557,8 +584,10 @@ item_node_new(
 
   if (l_node)
   {
+    item_deselect_all(io_item);
     item_node_append(io_item, l_node);
     (*l_node).m_type= i_type;
+    (*l_node).m_selected= 1;
   }
 
   (*o_node)= l_node;
@@ -652,6 +681,65 @@ item_node_write(
   return 0;
 }
 
+extern void
+item_selected_rotate(
+  struct item*const                     io_item,
+  double const                          i_rotation)
+{
+  struct item_node*                     l_node;
+
+  l_node= (*io_item).m_head;
+
+  do
+  {
+
+    if (0 == l_node)
+    {
+      break;
+    }
+
+    if ((*l_node).m_selected)
+    {
+      (*(*l_node).m_method.m_rotate)(&(*l_node).m_object, i_rotation);
+    }
+
+    l_node= (*l_node).m_next;
+  
+  }while(1);
+
+  return;
+}
+
+extern void
+item_selected_shear(
+  struct item*const                     io_item,
+  double const                          i_delta_x,
+  double const                          i_delta_y)
+{
+  struct item_node*                     l_node;
+
+  l_node= (*io_item).m_head;
+
+  do
+  {
+
+    if (0 == l_node)
+    {
+      break;
+    }
+
+    if ((*l_node).m_selected)
+    {
+      (*(*l_node).m_method.m_shear)(&(*l_node).m_object, i_delta_x, i_delta_y);
+    }
+
+    l_node= (*l_node).m_next;
+  
+  }while(1);
+
+  return;
+}
+
 extern int
 item_read(
   GError**                              o_error,
@@ -707,6 +795,8 @@ item_read(
 
     l_exit= (*(*l_node).m_method.m_read)(&l_error, &(*l_node).m_object, i_xml);
 
+    (*l_node).m_selected= 0;
+
   }while(0);
 
   if (l_error)
