@@ -105,6 +105,7 @@ extern void
 item_draw(
   struct item*const                     io_item,
   cairo_t*const                         i_cr,
+  double const                          i_scale,
   struct item_draw_options const*const  i_option);
 
 extern void
@@ -116,10 +117,10 @@ item_node_append(
   struct item*const                     io_item,
   struct item_node*const                i_node);
 
-extern void
+extern int
 item_node_in_event(
   struct item_node**                    o_node,
-  enum event_type*const                 o_type,
+  cairo_t*                              io_cr,
   struct item const*const               i_item,
   struct geom_point const*const         i_event,
   double const                          i_scale);
@@ -144,22 +145,28 @@ item_selected_move(
 extern void
 item_move_to_front(
   struct item*const                     io_item,
-  struct item_node*const                i_node);
+  struct item_node*const                io_node);
 
 extern void
 item_move_to_back(
   struct item*const                     io_item,
-  struct item_node*const                i_node);
+  struct item_node*const                io_node);
 
 extern void
 item_move_down(
   struct item*const                     io_item,
-  struct item_node*const                i_node);
+  struct item_node*const                io_node);
 
 extern void
 item_move_up(
   struct item*const                     io_item,
-  struct item_node*const                i_node);
+  struct item_node*const                io_node);
+
+extern void
+item_node_get_nth(
+  struct item_node**                    o_node,
+  struct item*const                     io_item,
+  unsigned const                        i_slot);
 
 extern void
 item_node_new(
@@ -178,9 +185,7 @@ item_node_remove(
 
 extern void
 item_normalize(
-  struct item*const                     io_item,
-  double const                          i_bound_width,
-  double const                          i_bound_height);
+  struct item*const                     io_item);
 
 extern int
 item_read(
@@ -190,9 +195,7 @@ item_read(
 
 extern void
 item_selected_normalize(
-  struct item*const                     io_item,
-  double const                          i_bound_width,
-  double const                          i_bound_height);
+  struct item*const                     io_item);
 
 extern void
 item_selected_remove(
@@ -203,6 +206,17 @@ item_selected_resize(
   struct item*const                     io_item,
   struct item_resize_event const*const  i_ctx);
 
+extern void
+item_selected_rotate(
+  struct item*const                     io_item,
+  double const                          i_rotation);
+
+extern void
+item_selected_shear(
+  struct item*const                     io_item,
+  double const                          i_delta_x,
+  double const                          i_delta_y);
+
 extern int
 item_node_write(
   GError**                              o_error,
