@@ -51,6 +51,17 @@ item_circle_assign(
   return;
 }
 
+extern void
+item_circle_copy(
+  struct item_circle *const             o_circle,
+  struct item_circle const*const        i_circle)
+{
+
+  memcpy(o_circle, i_circle, sizeof(*o_circle));
+
+  return;
+}
+
 extern void
 item_circle_discharge(
   struct item_circle*const              io_circle)
@@ -67,91 +78,89 @@ item_circle_draw(
   struct item_draw_context const*const  i_ctx)
 {
 
-  do
+  cairo_new_path((*i_ctx).m_cr);
+  cairo_save((*i_ctx).m_cr);
+  cairo_scale((*i_ctx).m_cr, (*i_ctx).m_scale, (*i_ctx).m_scale);
+
+  if ((*i_circle).m_fill.m_active)
   {
+    cairo_save((*i_ctx).m_cr);
 
-    if ((*i_circle).m_fill.m_active)
+    cairo_set_source_rgba(
+      (*i_ctx).m_cr,
+      (*i_circle).m_fill.m_color.red,
+      (*i_circle).m_fill.m_color.green,
+      (*i_circle).m_fill.m_color.blue,
+      (*i_circle).m_fill.m_color.alpha);
+
+    cairo_translate(
+      (*i_ctx).m_cr,
+      (*i_circle).m_center_x,
+      (*i_circle).m_center_y);
+
+    cairo_scale(
+      (*i_ctx).m_cr,
+      ((*i_circle).m_len_x/2),
+      ((*i_circle).m_len_y/2));
+
+    cairo_arc((*i_ctx).m_cr, 0.0, 0.0, 1.0, 0.0, 2*G_PI);
+    cairo_fill((*i_ctx).m_cr);
+    cairo_restore((*i_ctx).m_cr);
+  }
+
+  if ((*i_circle).m_border.m_active)
+  {
+    cairo_save((*i_ctx).m_cr);
+
+    cairo_translate(
+      (*i_ctx).m_cr,
+      (*i_circle).m_center_x,
+      (*i_circle).m_center_y);
+
+    cairo_scale(
+      (*i_ctx).m_cr,
+      ((*i_circle).m_len_x/2),
+      ((*i_circle).m_len_y/2));
+
+    cairo_arc((*i_ctx).m_cr, 0.0, 0.0, 1.0, 0.0, 2*G_PI);
+    cairo_restore((*i_ctx).m_cr);
+
+    cairo_set_source_rgba(
+      (*i_ctx).m_cr,
+      (*i_circle).m_border.m_color.red,
+      (*i_circle).m_border.m_color.green,
+      (*i_circle).m_border.m_color.blue,
+      (*i_circle).m_border.m_color.alpha);
+
+    item_common_cairo_dash_set((*i_ctx).m_cr, (*i_circle).m_border.m_style);
+    cairo_set_line_width((*i_ctx).m_cr, (*i_circle).m_border.m_thickness);
+    cairo_stroke((*i_ctx).m_cr);
+  }
+
+  if (0 == (*i_ctx).m_selected)
+  {
+    if ((*i_ctx).m_option.m_highlight &&
+      (item_draw_design == (*i_ctx).m_option.m_type))
     {
       cairo_save((*i_ctx).m_cr);
-
-      cairo_set_source_rgba(
-        (*i_ctx).m_cr,
-        (*i_circle).m_fill.m_color.red,
-        (*i_circle).m_fill.m_color.green,
-        (*i_circle).m_fill.m_color.blue,
-        (*i_circle).m_fill.m_color.alpha);
-
       cairo_translate(
         (*i_ctx).m_cr,
         (*i_circle).m_center_x,
         (*i_circle).m_center_y);
-
       cairo_scale(
         (*i_ctx).m_cr,
         ((*i_circle).m_len_x/2),
         ((*i_circle).m_len_y/2));
-
-      cairo_arc((*i_ctx).m_cr, 0.0, 0.0, 1.0, 0.0, 2*G_PI);
-      cairo_fill((*i_ctx).m_cr);
-      cairo_restore((*i_ctx).m_cr);
-    }
-
-    if ((*i_circle).m_border.m_active)
-    {
-      cairo_save((*i_ctx).m_cr);
-
-      cairo_translate(
-        (*i_ctx).m_cr,
-        (*i_circle).m_center_x,
-        (*i_circle).m_center_y);
-
-      cairo_scale(
-        (*i_ctx).m_cr,
-        ((*i_circle).m_len_x/2),
-        ((*i_circle).m_len_y/2));
-
       cairo_arc((*i_ctx).m_cr, 0.0, 0.0, 1.0, 0.0, 2*G_PI);
       cairo_restore((*i_ctx).m_cr);
-
-      cairo_set_source_rgba(
-        (*i_ctx).m_cr,
-        (*i_circle).m_border.m_color.red,
-        (*i_circle).m_border.m_color.green,
-        (*i_circle).m_border.m_color.blue,
-        (*i_circle).m_border.m_color.alpha);
-
-      item_common_cairo_dash_set((*i_ctx).m_cr, (*i_circle).m_border.m_style);
-      cairo_set_line_width((*i_ctx).m_cr, (*i_circle).m_border.m_thickness);
+      cairo_set_source_rgb((*i_ctx).m_cr, 0.50, 0.50, 0.00);
+      item_common_cairo_dash_set((*i_ctx).m_cr, line_style_solid);
+      cairo_set_line_width((*i_ctx).m_cr, 1.0);
       cairo_stroke((*i_ctx).m_cr);
     }
+  }
 
-    if (0 == (*i_ctx).m_selected)
-    {
-      if ((*i_ctx).m_option.m_highlight &&
-        (item_draw_design == (*i_ctx).m_option.m_type))
-      {
-        cairo_save((*i_ctx).m_cr);
-        cairo_translate(
-          (*i_ctx).m_cr,
-          (*i_circle).m_center_x,
-          (*i_circle).m_center_y);
-        cairo_scale(
-          (*i_ctx).m_cr,
-          ((*i_circle).m_len_x/2),
-          ((*i_circle).m_len_y/2));
-        cairo_arc((*i_ctx).m_cr, 0.0, 0.0, 1.0, 0.0, 2*G_PI);
-        cairo_restore((*i_ctx).m_cr);
-        cairo_set_source_rgb((*i_ctx).m_cr, 0.50, 0.50, 0.00);
-        item_common_cairo_dash_set((*i_ctx).m_cr, line_style_solid);
-        cairo_set_line_width((*i_ctx).m_cr, 1.0);
-        cairo_stroke((*i_ctx).m_cr);
-      }
-      break;
-    }
-
-    item_common_circle_draw_grips((*i_ctx).m_cr, (struct geom_ellipse*)i_circle);
-
-  }while(0);
+  cairo_restore((*i_ctx).m_cr);
 
   return;
 }
@@ -159,24 +168,83 @@ item_circle_draw(
 extern void
 item_circle_get_bbox(
   struct geom_rect*const                o_bbox,
-  void const*const                      i_object)
+  cairo_t*                              io_cr,
+  double const                          i_scale,
+  struct item_circle const*const        i_circle)
 {
-  /* _mjo: TODO return bbox */
+
+  geom_ellipse_get_bbox(o_bbox, (struct geom_ellipse*)i_circle);
+  (*o_bbox).m_pos_x*= i_scale;
+  (*o_bbox).m_pos_y*= i_scale;
+  (*o_bbox).m_len_x*= i_scale;
+  (*o_bbox).m_len_y*= i_scale;
+
   return;
 }
 
 extern void
-item_circle_in_event(
-  enum event_type*const                 o_type,
-  struct item_circle const*const        i_circle,
-  struct item_in_event const*const      i_ctx)
+item_circle_get_position(
+  double*const                          o_pos_x,
+  double*const                          o_pos_y,
+  struct item_circle const*const        i_circle)
 {
 
-  item_common_circle_in_event(o_type, i_ctx, (struct geom_ellipse*)i_circle);
+  (*o_pos_x)= (*i_circle).m_center_x;
+  (*o_pos_y)= (*i_circle).m_center_y;
 
   return;
 }
 
+extern void
+item_circle_get_rotation(
+  double*const                          o_rotation,
+  struct item_circle const*const        i_circle)
+{
+
+  (*o_rotation)= 0.0;
+
+  return;
+}
+
+extern void
+item_circle_get_size(
+  double*const                          o_len_x,
+  double*const                          o_len_y,
+  struct item_circle const*const        i_circle)
+{
+
+  (*o_len_x)= (*i_circle).m_len_x;
+  (*o_len_y)= (*i_circle).m_len_y;
+
+  return;
+}
+
+extern void
+item_circle_get_shear(
+  double*const                          o_shear_x,
+  double*const                          o_shear_y,
+  struct item_circle const*const        i_circle)
+{
+  
+  (*o_shear_x)= 0.0;
+  (*o_shear_y)= 0.0;
+
+  return;
+}
+
+extern int
+item_circle_in_event(
+  struct item_circle const*const        i_circle,
+  cairo_t*                              io_cr,
+  struct item_in_event const*const      i_ctx)
+{
+  int                                   l_hit;
+
+  l_hit= item_common_circle_in_event(i_ctx, io_cr, (struct geom_ellipse*)i_circle);
+
+  return l_hit;
+}
+
 extern void
 item_circle_move(
   struct item_circle*const              io_circle,
@@ -190,9 +258,7 @@ item_circle_move(
 
 extern void
 item_circle_normalize(
-  struct item_circle*const              io_circle,
-  double const                          i_bound_width,
-  double const                          i_bound_height)
+  struct item_circle*const              io_circle)
 {
 
   if (0 > (*io_circle).m_len_x)
@@ -208,6 +274,49 @@ item_circle_normalize(
   return;
 }
 
+extern void
+item_circle_set_position(
+  struct item_circle*const              io_circle,
+  double const                          i_pos_x,
+  double const                          i_pos_y)
+{
+
+  (*io_circle).m_center_x= i_pos_x;
+  (*io_circle).m_center_y= i_pos_y;
+
+  return;
+}
+
+extern void
+item_circle_set_rotation(
+  struct item_circle*const              io_circle,
+  double                                i_rotation)
+{
+  return;
+}
+
+extern void
+item_circle_set_size(
+  struct item_circle*const              io_circle,
+  double                                i_len_x,
+  double                                i_len_y)
+{
+
+  (*io_circle).m_len_x= i_len_x;
+  (*io_circle).m_len_y= i_len_y;
+
+  return;
+}
+
+extern void
+item_circle_set_shear(
+  struct item_circle*const              io_circle,
+  double const                          i_shear_x,
+  double const                          i_shear_y)
+{
+  return;
+}
+
 extern int
 item_circle_read(
   GError**                              o_error,
@@ -258,7 +367,7 @@ item_circle_read(
           (*io_circle).m_len_y= xml_convert_double(l_value);
           break;
         case element_tag_border:
-          l_exit= item_common_read_border_attr(&l_error, &(*io_circle).m_border, l_xml);
+          l_exit= item_common_read_border(&l_error, &(*io_circle).m_border, l_xml);
           break;
         case element_tag_fill:
           l_exit= item_common_read_fill(&l_error, &(*io_circle).m_fill, l_xml);
@@ -290,14 +399,26 @@ item_circle_resize(
   struct item_resize_event const*const  i_ctx)
 {
 
-  item_common_circle_resize(
-    (struct geom_ellipse*)io_circle, 
-    i_ctx, 
-    (*io_circle).m_ellipse);
+  item_common_circle_resize((struct geom_ellipse*)io_circle, i_ctx, (*io_circle).m_ellipse); 
 
   return;
 }
 
+extern void
+item_circle_rotate(
+  struct item_circle*const              io_circle,
+  double const                          i_rotation)
+{
+}
+  
+extern void
+item_circle_shear(
+  struct item_circle*const              io_circle,
+  double const                          i_delta_x,
+  double const                          i_delta_y)
+{
+}
+
 extern int
 item_circle_write(
   GError**                              o_error,
@@ -314,7 +435,7 @@ item_circle_write(
   fprintf(io_fp, "\t\t\t\t<center_y>%s</center_y>\n", g_ascii_dtostr(l_buf, sizeof(l_buf), (*i_circle).m_center_y));
   fprintf(io_fp, "\t\t\t\t<len_x>%s</len_x>\n", g_ascii_dtostr(l_buf, sizeof(l_buf), (*i_circle).m_len_x));
   fprintf(io_fp, "\t\t\t\t<len_y>%s</len_y>\n", g_ascii_dtostr(l_buf, sizeof(l_buf), (*i_circle).m_len_y));
-  item_common_write_border_attr(o_error, io_fp, &(*i_circle).m_border);
+  item_common_write_border(o_error, io_fp, &(*i_circle).m_border);
   item_common_write_fill(o_error, io_fp, &(*i_circle).m_fill);
   fprintf(io_fp, "\t\t\t\t<ellipse on=\"%s\"/>\n", ((*i_circle).m_ellipse ? "true" : "false"));
   fprintf(io_fp, "\t\t\t</item>\n");
