@@ -39,7 +39,7 @@ struct item_circle
   gdouble                               m_center_y;
   gdouble                               m_len_x;
   gdouble                               m_len_y;
-  struct item_border_attr               m_border;
+  struct item_border               m_border;
   struct item_fill                      m_fill;
   gint                                  m_ellipse;
 };
@@ -50,8 +50,9 @@ item_circle_assign(
   struct item_method*const              o_method);
 
 extern void
-item_circle_extent_update(
-  struct item_circle*const              io_circle);
+item_circle_copy(
+  struct item_circle *const             o_circle,
+  struct item_circle const*const        i_circle);
 
 extern void
 item_circle_discharge(
@@ -60,12 +61,37 @@ item_circle_discharge(
 extern void
 item_circle_get_bbox(
   struct geom_rect*const                o_bbox,
-  void const*const                      i_object);
+  cairo_t*                              io_cr,
+  double const                          i_scale,
+  struct item_circle const*const        i_circle);
 
 extern void
+item_circle_get_position(
+  double*const                          o_pos_x,
+  double*const                          o_pos_y,
+  struct item_circle const*const        i_circle);
+
+extern void
+item_circle_get_rotation(
+  double*const                          o_rotation,
+  struct item_circle const*const        i_circle);
+
+extern void
+item_circle_get_size(
+  double*const                          o_len_x,
+  double*const                          o_len_y,
+  struct item_circle const*const        i_circle);
+
+extern void
+item_circle_get_shear(
+  double*const                          o_shear_x,
+  double*const                          o_shear_y,
+  struct item_circle const*const        i_circle);
+
+extern int
 item_circle_in_event(
-  enum event_type*const                 o_type,
   struct item_circle const*const        i_circle,
+  cairo_t*                              io_cr,
   struct item_in_event const*const      i_ctx);
 
 extern void
@@ -80,25 +106,57 @@ item_circle_move(
 
 extern void
 item_circle_normalize(
+  struct item_circle*const              io_circle);
+
+extern void
+item_circle_set_position(
   struct item_circle*const              io_circle,
-  double const                          i_bound_width,
-  double const                          i_bound_height);
+  double const                          i_pos_x,
+  double const                          i_pos_y);
+
+extern void
+item_circle_set_rotation(
+  struct item_circle*const              io_circle,
+  double                                i_rotation);
+
+extern void
+item_circle_set_size(
+  struct item_circle*const              io_circle,
+  double                                i_len_x,
+  double                                i_len_y);
+
+extern void
+item_circle_set_shear(
+  struct item_circle*const              io_circle,
+  double const                          i_shear_x,
+  double const                          i_shear_y);
 
 extern int
 item_circle_property(
-  struct item_circle*const               io_circle);
+  struct item_circle*const              io_circle);
 
 extern int
 item_circle_read(
   GError**                              o_error,
   struct item_circle*const              io_circle,
-  struct xml *const               i_element);
+  struct xml *const                     i_element);
 
 extern void
 item_circle_resize(
   struct item_circle*const              io_circle,
   struct item_resize_event const*const  i_ctx);
 
+extern void
+item_circle_rotate(
+  struct item_circle*const              io_circle,
+  double const                          i_rotation);
+  
+extern void
+item_circle_shear(
+  struct item_circle*const              io_circle,
+  double const                          i_delta_x,
+  double const                          i_delta_y);
+
 extern int
 item_circle_write(
   GError**                              o_error,
