@@ -29,7 +29,7 @@ NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 #include "item_circle.h"
-#include "mainw.h"
+#include "item_property.h"
 
 struct circle_dialog
 {
@@ -44,155 +44,54 @@ struct circle_dialog
   GtkCheckButton*                       m_ellipse_checkbutton;
 };
 
-static void
-item_circle_border_color_button_cb(
-  GtkWidget *                           i_widget,
-  gpointer                              i_data)
-{
-  GdkRGBA                               l_color;
-  GtkWidget*                            l_dialog;
-  int                                   l_exit;
-  struct circle_dialog*                 l_circle;
-  gchar*                                l_rgba;
-  gchar const*                          l_text;
-
-  l_dialog= 0;
-  memset(&l_color, 0, sizeof(l_color));
-
-  do
-  {
-
-    l_circle= (struct circle_dialog*)i_data;
-
-    l_dialog= gtk_color_chooser_dialog_new("Border Color", get_main_window());
-
-    l_text= gtk_entry_get_text((*l_circle).m_border_color_entry);
-    gdk_rgba_parse(&l_color, l_text);
-    gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(l_dialog), &l_color);
-
-    gtk_window_set_modal((GtkWindow*)l_dialog, 1);
-    l_exit= gtk_dialog_run(GTK_DIALOG(l_dialog));
-
-    if (GTK_RESPONSE_OK != l_exit)
-    {
-      break;
-    }
-
-    gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(l_dialog), &l_color);
-
-    l_rgba= gdk_rgba_to_string(&l_color);
-    gtk_entry_set_text((*l_circle).m_border_color_entry, l_rgba);
-    g_free(l_rgba);
-
-  }while(0);
-
-  if (l_dialog)
-  {
-    gtk_widget_destroy((GtkWidget*)l_dialog);
-  }
-  
-  return;
-}
-
-static void
-item_circle_fill_color_button_cb(
-  GtkWidget *                           i_widget,
-  gpointer                              i_data)
-{
-  GdkRGBA                               l_color;
-  GtkWidget*                            l_dialog;
-  int                                   l_exit;
-  struct circle_dialog*                 l_circle;
-  gchar*                                l_rgba;
-  gchar const*                          l_text;
-
-  l_dialog= 0;
-  memset(&l_color, 0, sizeof(l_color));
-
-  do
-  {
-
-    l_circle= (struct circle_dialog*)i_data;
-
-    l_dialog= gtk_color_chooser_dialog_new("Fill Color", get_main_window());
-    gtk_color_chooser_set_use_alpha(GTK_COLOR_CHOOSER(l_dialog), 1);
-
-    l_text= gtk_entry_get_text((*l_circle).m_border_color_entry);
-    gdk_rgba_parse(&l_color, l_text);
-    gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(l_dialog), &l_color);
-
-    gtk_window_set_modal((GtkWindow*)l_dialog, 1);
-    l_exit= gtk_dialog_run(GTK_DIALOG(l_dialog));
-
-    if (GTK_RESPONSE_OK != l_exit)
-    {
-      break;
-    }
-
-    gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(l_dialog), &l_color);
-
-    l_rgba= gdk_rgba_to_string(&l_color);
-    gtk_entry_set_text((*l_circle).m_fill_color_entry, l_rgba);
-    g_free(l_rgba);
-
-  }while(0);
-
-  if (l_dialog)
-  {
-    gtk_widget_destroy((GtkWidget*)l_dialog);
-  }
-  
-  return;
-}
-
 static void
 item_circle_bind(
-  struct circle_dialog*const            o_circle,
+  struct circle_dialog*const            o_dlg,
   GtkBuilder*const                      i_builder)
 {
 
-  memset(o_circle, 0, sizeof(*o_circle));
+  memset(o_dlg, 0, sizeof(*o_dlg));
 
   do
   {
 
-    (*o_circle).m_border_checkbutton=
+    (*o_dlg).m_border_checkbutton=
       GTK_CHECK_BUTTON(gtk_builder_get_object(i_builder, "border_checkbutton"));
 
-    (*o_circle).m_border_style_comboboxtext=
+    (*o_dlg).m_border_style_comboboxtext=
       GTK_COMBO_BOX_TEXT(gtk_builder_get_object(i_builder, "border_style_comboboxtext"));
 
-    (*o_circle).m_border_thickness_spinbutton=
+    (*o_dlg).m_border_thickness_spinbutton=
       GTK_SPIN_BUTTON(gtk_builder_get_object(i_builder, "border_thickness_spinbutton"));
 
-    (*o_circle).m_border_color_entry=
+    (*o_dlg).m_border_color_entry=
       GTK_ENTRY(gtk_builder_get_object(i_builder, "border_color_entry"));
 
-    (*o_circle).m_border_color_button=
+    (*o_dlg).m_border_color_button=
       GTK_BUTTON(gtk_builder_get_object(i_builder, "border_color_button"));
 
     g_signal_connect(
-      (*o_circle).m_border_color_button,
+      (*o_dlg).m_border_color_button,
       "clicked",
-      G_CALLBACK(item_circle_border_color_button_cb),
-      o_circle);
+      G_CALLBACK(item_property_border_color_button_cb),
+      (*o_dlg).m_border_color_entry);
 
-    (*o_circle).m_fill_color_checkbutton=
+    (*o_dlg).m_fill_color_checkbutton=
       GTK_CHECK_BUTTON(gtk_builder_get_object(i_builder, "fill_color_checkbutton"));
 
-    (*o_circle).m_fill_color_button=
+    (*o_dlg).m_fill_color_button=
       GTK_BUTTON(gtk_builder_get_object(i_builder, "fill_color_button"));
 
-    g_signal_connect(
-      (*o_circle).m_fill_color_button,
-      "clicked",
-      G_CALLBACK(item_circle_fill_color_button_cb),
-      o_circle);
-
-    (*o_circle).m_fill_color_entry=
+    (*o_dlg).m_fill_color_entry=
       GTK_ENTRY(gtk_builder_get_object(i_builder, "fill_color_entry"));
 
-    (*o_circle).m_ellipse_checkbutton=
+    g_signal_connect(
+      (*o_dlg).m_fill_color_button,
+      "clicked",
+      G_CALLBACK(item_property_fill_color_button_cb),
+      (*o_dlg).m_fill_color_entry);
+
+    (*o_dlg).m_ellipse_checkbutton=
       GTK_CHECK_BUTTON(gtk_builder_get_object(i_builder, "ellipse_checkbutton"));
 
   }while(0);
@@ -202,99 +101,99 @@ item_circle_bind(
 
 static void
 item_circle_set_values(
-  struct circle_dialog*const            i_circled,
-  struct item_circle const*const        i_circle)
+  struct circle_dialog*const            i_dlg,
+  struct item_circle const*const        i_object)
 {
   gchar*                                l_color;
 
   gtk_toggle_button_set_active(
-    GTK_TOGGLE_BUTTON((*i_circled).m_border_checkbutton),
-    (*i_circle).m_border.m_active);
+    GTK_TOGGLE_BUTTON((*i_dlg).m_border_checkbutton),
+    (*i_object).m_border.m_active);
 
   gtk_combo_box_set_active(
-      GTK_COMBO_BOX((*i_circled).m_border_style_comboboxtext), 
-      (*i_circle).m_border.m_style);
+      GTK_COMBO_BOX((*i_dlg).m_border_style_comboboxtext), 
+      (*i_object).m_border.m_style);
 
   gtk_spin_button_set_value(
-    GTK_SPIN_BUTTON((*i_circled).m_border_thickness_spinbutton),
-    (*i_circle).m_border.m_thickness);
+    GTK_SPIN_BUTTON((*i_dlg).m_border_thickness_spinbutton),
+    (*i_object).m_border.m_thickness);
 
-  l_color= gdk_rgba_to_string(&(*i_circle).m_border.m_color);
-  gtk_entry_set_text((*i_circled).m_border_color_entry, l_color);
+  l_color= gdk_rgba_to_string(&(*i_object).m_border.m_color);
+  gtk_entry_set_text((*i_dlg).m_border_color_entry, l_color);
   g_free(l_color);
   l_color= 0;
 
   gtk_toggle_button_set_active(
-    GTK_TOGGLE_BUTTON((*i_circled).m_fill_color_checkbutton),
-    (*i_circle).m_fill.m_active);
+    GTK_TOGGLE_BUTTON((*i_dlg).m_fill_color_checkbutton),
+    (*i_object).m_fill.m_active);
 
-  l_color= gdk_rgba_to_string(&(*i_circle).m_fill.m_color);
-  gtk_entry_set_text((*i_circled).m_fill_color_entry, l_color);
+  l_color= gdk_rgba_to_string(&(*i_object).m_fill.m_color);
+  gtk_entry_set_text((*i_dlg).m_fill_color_entry, l_color);
   g_free(l_color);
   l_color= 0;
 
   gtk_toggle_button_set_active(
-    GTK_TOGGLE_BUTTON((*i_circled).m_ellipse_checkbutton),
-    (*i_circle).m_ellipse);
+    GTK_TOGGLE_BUTTON((*i_dlg).m_ellipse_checkbutton),
+    (*i_object).m_ellipse);
 
   return;
 }
 
 static void
 item_circle_copy_values(
-  struct item_circle *const             io_circle,
-  struct circle_dialog const*const      i_circled)
+  struct item_circle *const             io_object,
+  struct circle_dialog const*const      i_dlg)
 {
   gchar const*                          l_text;
   gint                                  l_rc;
 
-  (*io_circle).m_border.m_active=
+  (*io_object).m_border.m_active=
     gtk_toggle_button_get_active(
-      GTK_TOGGLE_BUTTON((*i_circled).m_border_checkbutton));
+      GTK_TOGGLE_BUTTON((*i_dlg).m_border_checkbutton));
 
   l_rc = gtk_combo_box_get_active(
-    GTK_COMBO_BOX((*i_circled).m_border_style_comboboxtext));
+    GTK_COMBO_BOX((*i_dlg).m_border_style_comboboxtext));
 
-  if ((0 <= l_rc) && (LINE_STYLE_SLOTS > l_rc))
+  if ((0 <= l_rc) && (line_style_last > l_rc))
   {
-    (*io_circle).m_border.m_style= (enum line_style_type)l_rc;
+    (*io_object).m_border.m_style= (enum line_style_type)l_rc;
   }
   else
   {
-    (*io_circle).m_border.m_style= line_style_solid;
+    (*io_object).m_border.m_style= line_style_solid;
   }
 
-  (*io_circle).m_border.m_thickness= gtk_spin_button_get_value(
-    GTK_SPIN_BUTTON((*i_circled).m_border_thickness_spinbutton));
+  (*io_object).m_border.m_thickness= gtk_spin_button_get_value(
+    GTK_SPIN_BUTTON((*i_dlg).m_border_thickness_spinbutton));
 
-  l_text= gtk_entry_get_text(GTK_ENTRY((*i_circled).m_border_color_entry));
-  gdk_rgba_parse(&(*io_circle).m_border.m_color, l_text);
+  l_text= gtk_entry_get_text(GTK_ENTRY((*i_dlg).m_border_color_entry));
+  gdk_rgba_parse(&(*io_object).m_border.m_color, l_text);
 
-  (*io_circle).m_fill.m_active=
+  (*io_object).m_fill.m_active=
     gtk_toggle_button_get_active(
-      GTK_TOGGLE_BUTTON((*i_circled).m_fill_color_checkbutton));
+      GTK_TOGGLE_BUTTON((*i_dlg).m_fill_color_checkbutton));
 
-  l_text= gtk_entry_get_text(GTK_ENTRY((*i_circled).m_fill_color_entry));
-  gdk_rgba_parse(&(*io_circle).m_fill.m_color, l_text);
+  l_text= gtk_entry_get_text(GTK_ENTRY((*i_dlg).m_fill_color_entry));
+  gdk_rgba_parse(&(*io_object).m_fill.m_color, l_text);
 
-  (*io_circle).m_ellipse=
+  (*io_object).m_ellipse=
     gtk_toggle_button_get_active(
-      GTK_TOGGLE_BUTTON((*i_circled).m_ellipse_checkbutton));
+      GTK_TOGGLE_BUTTON((*i_dlg).m_ellipse_checkbutton));
 
   return;
 }
 
 extern int
 item_circle_property(
-  struct item_circle*const              io_circle)
+  struct item_circle*const              io_object)
 {
   GtkBox*                               l_box;
   GtkBuilder*                           l_builder;
   GtkDialog*                            l_dialog;
-  GtkGrid*                              l_grid;
+  struct circle_dialog                  l_dlg;
   GError*                               l_error;
   int                                   l_exit;
-  struct circle_dialog                  l_circle;
+  GtkGrid*                              l_grid;
   int                                   l_rc;
 
   l_builder= 0;
@@ -328,9 +227,9 @@ item_circle_property(
       break;
     }
 
-    item_circle_bind(&l_circle, l_builder);
+    item_circle_bind(&l_dlg, l_builder);
 
-    item_circle_set_values(&l_circle, io_circle);
+    item_circle_set_values(&l_dlg, io_object);
 
     l_dialog= GTK_DIALOG(gtk_dialog_new_with_buttons(
       "Circle Edit",
@@ -357,7 +256,7 @@ item_circle_property(
       break;
     }
 
-    item_circle_copy_values(io_circle, &l_circle);
+    item_circle_copy_values(io_object, &l_dlg);
 
   }while(0);
 
