@@ -32,7 +32,7 @@
 #line 1 "item_common_lookup.gperf"
 
 /*
-Copyright (c) 2015, iwrite authors
+Copyright (c) 2015-2016, iwrite authors
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -66,12 +66,12 @@ struct element_tag
  int type;
 };
 
-#define TOTAL_KEYWORDS 104
+#define TOTAL_KEYWORDS 111
 #define MIN_WORD_LENGTH 3
 #define MAX_WORD_LENGTH 16
-#define MIN_HASH_VALUE 9
-#define MAX_HASH_VALUE 243
-/* maximum key range = 235, duplicates = 0 */
+#define MIN_HASH_VALUE 5
+#define MAX_HASH_VALUE 360
+/* maximum key range = 356, duplicates = 0 */
 
 #ifdef __GNUC__
 __inline
@@ -83,21 +83,21 @@ inline
 static unsigned int
 hash (register const char *str, register unsigned int len)
 {
-  static unsigned char asso_values[] =
+  static unsigned short asso_values[] =
     {
-      244, 244, 244, 244, 244, 244, 244, 244, 244, 244,
-      244, 244, 244, 244, 244, 244, 244, 244, 244, 244,
-      244, 244, 244, 244, 244, 244, 244, 244, 244, 244,
-      244, 244, 244, 244, 244, 244, 244, 244, 244, 244,
-      244, 244, 244, 244, 244, 244, 244, 244,  40, 105,
-       30,  25,  20,  15,  10,   0, 244, 244, 244, 244,
-      244, 244, 244, 244, 244, 244, 244, 244, 244, 244,
-      244, 244, 244, 244, 244, 244, 244, 244, 244, 244,
-      244, 244, 244, 244, 244, 244, 244, 244, 244, 244,
-      244, 244, 244, 244, 244,  35, 244,   0,  95,   5,
-       40,   5,  10,  60,  15,  55, 244,   0,  10,  15,
-       55,   0,  25, 244,   0,  80,   0,  10,  30,  65,
-       10,  80,  10, 244, 244, 244, 244, 244
+      361, 361, 361, 361, 361, 361, 361, 361, 361, 361,
+      361, 361, 361, 361, 361, 361, 361, 361, 361, 361,
+      361, 361, 361, 361, 361, 361, 361, 361, 361, 361,
+      361, 361, 361, 361, 361, 361, 361, 361, 361, 361,
+      361, 361, 361, 361, 361, 361, 361, 361,  95,  80,
+       75,  85,  60,  30,   5,   0, 361, 361, 361, 361,
+      361, 361, 361, 361, 361, 361, 361, 361, 361, 361,
+      361, 361, 361, 361, 361, 361, 361, 361, 361, 361,
+      361, 361, 361, 361, 361, 361, 361, 361, 361, 361,
+      361, 361, 361, 361, 361,  35, 361,   0,  40,  25,
+      105,   5,  15,  40,  20,  45, 361,  10,   0,  25,
+        0,  15,  80,  30,   0,  40,   5,   0,  35,  45,
+       50,  15,  15, 361, 361, 361, 361, 361
     };
   register int hval = len;
 
@@ -134,243 +134,269 @@ in_word_set (register const char *str, register unsigned int len)
 {
   static struct element_tag wordlist[] =
     {
-#line 129 "item_common_lookup.gperf"
-      {"text",				element_tag_text},
-#line 45 "item_common_lookup.gperf"
-      {"color",				element_tag_color},
-#line 121 "item_common_lookup.gperf"
-      {"rotate",				element_tag_rotate},
-#line 64 "item_common_lookup.gperf"
-      {"font", 				element_tag_font},
-#line 68 "item_common_lookup.gperf"
-      {"ftext",				element_tag_ftext},
-#line 65 "item_common_lookup.gperf"
-      {"format",				element_tag_format},
-#line 48 "item_common_lookup.gperf"
-      {"cover_footer",			element_tag_cover_footer},
-#line 76 "item_common_lookup.gperf"
-      {"host",				element_tag_host},
-#line 46 "item_common_lookup.gperf"
-      {"colorspace",  			element_tag_colorspace,},
-#line 49 "item_common_lookup.gperf"
-      {"cover_header",			element_tag_cover_header},
-#line 75 "item_common_lookup.gperf"
-      {"hostaddr",			element_tag_hostaddr},
-#line 66 "item_common_lookup.gperf"
-      {"frame",				element_tag_frame},
-#line 119 "item_common_lookup.gperf"
-      {"report_footer",			element_tag_report_footer},
-#line 101 "item_common_lookup.gperf"
-      {"port",				element_tag_port},
-#line 88 "item_common_lookup.gperf"
-      {"locale",				element_tag_locale},
-#line 130 "item_common_lookup.gperf"
-      {"textual",			element_tag_textual},
-#line 120 "item_common_lookup.gperf"
-      {"report_header",			element_tag_report_header},
-#line 96 "item_common_lookup.gperf"
-      {"page",				element_tag_page},
-#line 79 "item_common_lookup.gperf"
+#line 80 "item_common_lookup.gperf"
       {"label",				element_tag_label},
 #line 84 "item_common_lookup.gperf"
-      {"length",  			element_tag_length,},
-#line 80 "item_common_lookup.gperf"
-      {"label_height", 			element_tag_label_height},
-#line 72 "item_common_lookup.gperf"
-      {"has_alpha",  			element_tag_has_alpha,},
-#line 85 "item_common_lookup.gperf"
-      {"len_x", 				element_tag_len_x},
-#line 73 "item_common_lookup.gperf"
-      {"height",				element_tag_height},
-#line 108 "item_common_lookup.gperf"
-      {"print_header",			element_tag_print_header},
-#line 41 "item_common_lookup.gperf"
-      {"center_x",			element_tag_center_x},
-#line 50 "item_common_lookup.gperf"
-      {"data",				element_tag_data},
-#line 137 "item_common_lookup.gperf"
-      {"value",				element_tag_value},
-#line 117 "item_common_lookup.gperf"
-      {"rect_v7",  			element_tag_rect_v7},
-#line 52 "item_common_lookup.gperf"
-      {"date", 				element_tag_date},
-#line 104 "item_common_lookup.gperf"
-      {"pos_x", 				element_tag_pos_x},
-#line 56 "item_common_lookup.gperf"
-      {"driver",				element_tag_driver},
-#line 57 "item_common_lookup.gperf"
-      {"ellipse",			element_tag_ellipse},
-#line 123 "item_common_lookup.gperf"
-      {"rowstride",  			element_tag_rowstride,},
-#line 74 "item_common_lookup.gperf"
-      {"horizontal_pitch", 		element_tag_horizontal_pitch},
-#line 116 "item_common_lookup.gperf"
-      {"rect_v6",  			element_tag_rect_v6},
-#line 115 "item_common_lookup.gperf"
-      {"rect_v5",  			element_tag_rect_v5},
-#line 128 "item_common_lookup.gperf"
-      {"tag",           			element_tag_tag},
-#line 93 "item_common_lookup.gperf"
-      {"name", 				element_tag_name},
-#line 114 "item_common_lookup.gperf"
-      {"rect_v4",  			element_tag_rect_v4},
-#line 118 "item_common_lookup.gperf"
-      {"report_detail",			element_tag_report_detail},
-#line 37 "item_common_lookup.gperf"
-      {"attribute",			element_tag_attribute},
-#line 103 "item_common_lookup.gperf"
-      {"pos_x2", 			element_tag_pos_x2},
-#line 113 "item_common_lookup.gperf"
-      {"rect_v3",  			element_tag_rect_v3},
-#line 83 "item_common_lookup.gperf"
       {"len", 				element_tag_len},
-#line 87 "item_common_lookup.gperf"
-      {"line",				element_tag_line},
-#line 55 "item_common_lookup.gperf"
-      {"double_line",			element_tag_doubleline},
+#line 94 "item_common_lookup.gperf"
+      {"name", 				element_tag_name},
 #line 112 "item_common_lookup.gperf"
-      {"rect_v2",  			element_tag_rect_v2},
-#line 61 "item_common_lookup.gperf"
-      {"fill", 				element_tag_fill},
-#line 44 "item_common_lookup.gperf"
-      {"circle",				element_tag_circle},
-#line 91 "item_common_lookup.gperf"
-      {"margin_right",			element_tag_margin_right},
-#line 133 "item_common_lookup.gperf"
-      {"timezone",			element_tag_timezone},
-#line 122 "item_common_lookup.gperf"
-      {"rows", 				element_tag_rows},
-#line 77 "item_common_lookup.gperf"
-      {"image",				element_tag_image},
-#line 98 "item_common_lookup.gperf"
-      {"page_number",			element_tag_page_number},
-#line 110 "item_common_lookup.gperf"
-      {"rect_v0",  			element_tag_rect_v0},
+      {"rect",				element_tag_rect},
+#line 136 "item_common_lookup.gperf"
+      {"textual",			element_tag_textual},
 #line 135 "item_common_lookup.gperf"
-      {"type",				element_tag_type},
-#line 90 "item_common_lookup.gperf"
-      {"margin_left",			element_tag_margin_left},
-#line 100 "item_common_lookup.gperf"
-      {"pattern",			element_tag_pattern},
-#line 127 "item_common_lookup.gperf"
-      {"style",				element_tag_style},
-#line 70 "item_common_lookup.gperf"
-      {"group_footer",			element_tag_group_footer},
-#line 140 "item_common_lookup.gperf"
-      {"wrapmode",			element_tag_wrapmode},
-#line 124 "item_common_lookup.gperf"
-      {"scale",				element_tag_scale},
+      {"text",				element_tag_text},
+#line 133 "item_common_lookup.gperf"
+      {"table", 				element_tag_table},
 #line 81 "item_common_lookup.gperf"
-      {"label_width", 			element_tag_label_width},
-#line 71 "item_common_lookup.gperf"
-      {"group_header",			element_tag_group_header},
-#line 92 "item_common_lookup.gperf"
-      {"margin_top",			element_tag_margin_top},
+      {"label_height", 			element_tag_label_height},
+#line 89 "item_common_lookup.gperf"
+      {"locale",				element_tag_locale},
+#line 124 "item_common_lookup.gperf"
+      {"rotation",			element_tag_rotation},
+#line 142 "item_common_lookup.gperf"
+      {"type",				element_tag_type},
+#line 67 "item_common_lookup.gperf"
+      {"frame",				element_tag_frame},
+#line 95 "item_common_lookup.gperf"
+      {"orientation",			element_tag_orientation},
+#line 122 "item_common_lookup.gperf"
+      {"report_footer",			element_tag_report_footer},
+#line 69 "item_common_lookup.gperf"
+      {"ftext",				element_tag_ftext},
+#line 85 "item_common_lookup.gperf"
+      {"length",  			element_tag_length},
+#line 123 "item_common_lookup.gperf"
+      {"report_header",			element_tag_report_header},
+#line 65 "item_common_lookup.gperf"
+      {"font", 				element_tag_font},
+#line 87 "item_common_lookup.gperf"
+      {"len_y", 				element_tag_len_y},
+#line 66 "item_common_lookup.gperf"
+      {"format",				element_tag_format},
+#line 76 "item_common_lookup.gperf"
+      {"hostaddr",			element_tag_hostaddr},
+#line 77 "item_common_lookup.gperf"
+      {"host",				element_tag_host},
+#line 45 "item_common_lookup.gperf"
+      {"color",				element_tag_color},
+#line 120 "item_common_lookup.gperf"
+      {"rect_v7",  			element_tag_rect_v7},
+#line 134 "item_common_lookup.gperf"
+      {"tag",           			element_tag_tag},
+#line 73 "item_common_lookup.gperf"
+      {"has_alpha",  			element_tag_has_alpha},
+#line 144 "item_common_lookup.gperf"
+      {"value",				element_tag_value},
+#line 83 "item_common_lookup.gperf"
+      {"left_margin", 			element_tag_left_margin},
+#line 119 "item_common_lookup.gperf"
+      {"rect_v6",  			element_tag_rect_v6},
+#line 88 "item_common_lookup.gperf"
+      {"line",				element_tag_line},
+#line 46 "item_common_lookup.gperf"
+      {"colorspace",  			element_tag_colorspace},
+#line 74 "item_common_lookup.gperf"
+      {"height",				element_tag_height},
+#line 50 "item_common_lookup.gperf"
+      {"cover_header",			element_tag_cover_header},
+#line 143 "item_common_lookup.gperf"
+      {"username",			element_tag_username},
+#line 125 "item_common_lookup.gperf"
+      {"rows", 				element_tag_rows},
+#line 132 "item_common_lookup.gperf"
+      {"style",				element_tag_style},
+#line 64 "item_common_lookup.gperf"
+      {"fnumber",			element_tag_fnumber},
+#line 62 "item_common_lookup.gperf"
+      {"fill", 				element_tag_fill},
+#line 111 "item_common_lookup.gperf"
+      {"query", 				element_tag_query},
 #line 40 "item_common_lookup.gperf"
       {"border", 			element_tag_border},
+#line 49 "item_common_lookup.gperf"
+      {"cover_footer",			element_tag_cover_footer},
+#line 37 "item_common_lookup.gperf"
+      {"attribute",			element_tag_attribute},
 #line 47 "item_common_lookup.gperf"
-      {"columns", 			element_tag_columns},
-#line 67 "item_common_lookup.gperf"
-      {"fsum",				element_tag_fsum},
-#line 58 "item_common_lookup.gperf"
-      {"encode",				element_tag_encode},
-#line 51 "item_common_lookup.gperf"
-      {"data_type", 			element_tag_data_type},
-#line 69 "item_common_lookup.gperf"
-      {"group",				element_tag_group},
-#line 82 "item_common_lookup.gperf"
-      {"left_margin", 			element_tag_left_margin},
-#line 94 "item_common_lookup.gperf"
-      {"orientation",			element_tag_orientation},
-#line 99 "item_common_lookup.gperf"
-      {"page_width", 			element_tag_page_width},
-#line 97 "item_common_lookup.gperf"
-      {"page_height", 			element_tag_page_height},
-#line 95 "item_common_lookup.gperf"
+      {"column",				element_tag_column},
+#line 96 "item_common_lookup.gperf"
       {"overlay",			element_tag_overlay},
-#line 59 "item_common_lookup.gperf"
-      {"fbarcode",			element_tag_fbarcode},
-#line 138 "item_common_lookup.gperf"
-      {"vertical_pitch", 		element_tag_vertical_pitch},
-#line 109 "item_common_lookup.gperf"
-      {"prompt_password",		element_tag_prompt_password},
-#line 78 "item_common_lookup.gperf"
-      {"iwrite",				element_tag_iwrite},
-#line 38 "item_common_lookup.gperf"
-      {"autowrap",			element_tag_autowrap},
-#line 62 "item_common_lookup.gperf"
-      {"fimage",				element_tag_fimage},
-#line 60 "item_common_lookup.gperf"
-      {"filename", 			element_tag_filename},
-#line 134 "item_common_lookup.gperf"
-      {"top_margin", 			element_tag_top_margin},
-#line 106 "item_common_lookup.gperf"
-      {"pos_y2", 			element_tag_pos_y2},
-#line 125 "item_common_lookup.gperf"
-      {"size", 				element_tag_size},
-#line 102 "item_common_lookup.gperf"
-      {"pos_x1", 			element_tag_pos_x1},
-#line 111 "item_common_lookup.gperf"
-      {"rect_v1",  			element_tag_rect_v1},
-#line 139 "item_common_lookup.gperf"
-      {"width",				element_tag_width},
-#line 54 "item_common_lookup.gperf"
-      {"dbname",				element_tag_dbname},
-#line 136 "item_common_lookup.gperf"
-      {"username",			element_tag_username},
-#line 63 "item_common_lookup.gperf"
-      {"fnumber",			element_tag_fnumber},
-#line 53 "item_common_lookup.gperf"
-      {"date_style",			element_tag_date_style},
-#line 126 "item_common_lookup.gperf"
-      {"special",			element_tag_special},
-#line 86 "item_common_lookup.gperf"
-      {"len_y", 				element_tag_len_y},
 #line 42 "item_common_lookup.gperf"
       {"center_y",			element_tag_center_y},
-#line 131 "item_common_lookup.gperf"
-      {"thickness",			element_tag_thickness},
-#line 132 "item_common_lookup.gperf"
+#line 82 "item_common_lookup.gperf"
+      {"label_width", 			element_tag_label_width},
+#line 118 "item_common_lookup.gperf"
+      {"rect_v5",  			element_tag_rect_v5},
+#line 61 "item_common_lookup.gperf"
+      {"filename", 			element_tag_filename},
+#line 141 "item_common_lookup.gperf"
+      {"transform",			element_tag_transform},
+#line 127 "item_common_lookup.gperf"
+      {"scale",				element_tag_scale},
+#line 44 "item_common_lookup.gperf"
+      {"circle",				element_tag_circle},
+#line 129 "item_common_lookup.gperf"
+      {"shear_y",  			element_tag_shear_y},
+#line 139 "item_common_lookup.gperf"
+      {"timezone",			element_tag_timezone},
+#line 68 "item_common_lookup.gperf"
+      {"fsum",				element_tag_fsum},
+#line 78 "item_common_lookup.gperf"
+      {"image",				element_tag_image},
+#line 91 "item_common_lookup.gperf"
+      {"margin_left",			element_tag_margin_left},
+#line 92 "item_common_lookup.gperf"
+      {"margin_right",			element_tag_margin_right},
+#line 147 "item_common_lookup.gperf"
+      {"wrapmode",			element_tag_wrapmode},
+#line 97 "item_common_lookup.gperf"
+      {"page",				element_tag_page},
+#line 75 "item_common_lookup.gperf"
+      {"horizontal_pitch", 		element_tag_horizontal_pitch},
+#line 101 "item_common_lookup.gperf"
+      {"pattern",			element_tag_pattern},
+#line 130 "item_common_lookup.gperf"
+      {"size", 				element_tag_size},
+#line 140 "item_common_lookup.gperf"
+      {"top_margin", 			element_tag_top_margin},
+#line 58 "item_common_lookup.gperf"
+      {"ellipse",			element_tag_ellipse},
+#line 60 "item_common_lookup.gperf"
+      {"fbarcode",			element_tag_fbarcode},
+#line 109 "item_common_lookup.gperf"
+      {"print_header",			element_tag_print_header},
+#line 102 "item_common_lookup.gperf"
+      {"port",				element_tag_port},
+#line 79 "item_common_lookup.gperf"
+      {"iwrite",				element_tag_iwrite},
+#line 117 "item_common_lookup.gperf"
+      {"rect_v4",  			element_tag_rect_v4},
+#line 51 "item_common_lookup.gperf"
+      {"data",				element_tag_data},
+#line 86 "item_common_lookup.gperf"
+      {"len_x", 				element_tag_len_x},
+#line 63 "item_common_lookup.gperf"
+      {"fimage",				element_tag_fimage},
+#line 48 "item_common_lookup.gperf"
+      {"columns", 			element_tag_columns},
+#line 53 "item_common_lookup.gperf"
+      {"date", 				element_tag_date},
+#line 138 "item_common_lookup.gperf"
       {"time_style",			element_tag_time_style},
-#line 107 "item_common_lookup.gperf"
+#line 57 "item_common_lookup.gperf"
+      {"driver",				element_tag_driver},
+#line 128 "item_common_lookup.gperf"
+      {"shear_x",			element_tag_shear_x},
+#line 145 "item_common_lookup.gperf"
+      {"vertical_pitch", 		element_tag_vertical_pitch},
+#line 59 "item_common_lookup.gperf"
+      {"encode",				element_tag_encode},
+#line 115 "item_common_lookup.gperf"
+      {"rect_v2",  			element_tag_rect_v2},
+#line 121 "item_common_lookup.gperf"
+      {"report_detail",			element_tag_report_detail},
+#line 137 "item_common_lookup.gperf"
+      {"thickness",			element_tag_thickness},
+#line 114 "item_common_lookup.gperf"
+      {"rect_v1",  			element_tag_rect_v1},
+#line 108 "item_common_lookup.gperf"
       {"pos_y", 				element_tag_pos_y},
-#line 89 "item_common_lookup.gperf"
-      {"margin_bottom",			element_tag_margin_bottom},
+#line 116 "item_common_lookup.gperf"
+      {"rect_v3",  			element_tag_rect_v3},
+#line 43 "item_common_lookup.gperf"
+      {"channels",  			element_tag_channels},
+#line 146 "item_common_lookup.gperf"
+      {"width",				element_tag_width},
+#line 56 "item_common_lookup.gperf"
+      {"double_line",			element_tag_doubleline},
+#line 72 "item_common_lookup.gperf"
+      {"group_header",			element_tag_group_header},
+#line 126 "item_common_lookup.gperf"
+      {"rowstride",  			element_tag_rowstride},
 #line 39 "item_common_lookup.gperf"
       {"bits_per_sample",  		element_tag_bits_per_sample,},
-#line 105 "item_common_lookup.gperf"
+#line 113 "item_common_lookup.gperf"
+      {"rect_v0",  			element_tag_rect_v0},
+#line 41 "item_common_lookup.gperf"
+      {"center_x",			element_tag_center_x},
+#line 71 "item_common_lookup.gperf"
+      {"group_footer",			element_tag_group_footer},
+#line 90 "item_common_lookup.gperf"
+      {"margin_bottom",			element_tag_margin_bottom},
+#line 99 "item_common_lookup.gperf"
+      {"page_number",			element_tag_page_number},
+#line 93 "item_common_lookup.gperf"
+      {"margin_top",			element_tag_margin_top},
+#line 54 "item_common_lookup.gperf"
+      {"date_style",			element_tag_date_style},
+#line 131 "item_common_lookup.gperf"
+      {"special",			element_tag_special},
+#line 98 "item_common_lookup.gperf"
+      {"page_height", 			element_tag_page_height},
+#line 55 "item_common_lookup.gperf"
+      {"dbname",				element_tag_dbname},
+#line 107 "item_common_lookup.gperf"
+      {"pos_y2", 			element_tag_pos_y2},
+#line 106 "item_common_lookup.gperf"
       {"pos_y1", 			element_tag_pos_y1},
-#line 43 "item_common_lookup.gperf"
-      {"channels",  			element_tag_channels,}
+#line 105 "item_common_lookup.gperf"
+      {"pos_x", 				element_tag_pos_x},
+#line 70 "item_common_lookup.gperf"
+      {"group",				element_tag_group},
+#line 38 "item_common_lookup.gperf"
+      {"autowrap",			element_tag_autowrap},
+#line 104 "item_common_lookup.gperf"
+      {"pos_x2", 			element_tag_pos_x2},
+#line 103 "item_common_lookup.gperf"
+      {"pos_x1", 			element_tag_pos_x1},
+#line 52 "item_common_lookup.gperf"
+      {"data_type", 			element_tag_data_type},
+#line 100 "item_common_lookup.gperf"
+      {"page_width", 			element_tag_page_width},
+#line 110 "item_common_lookup.gperf"
+      {"prompt_password",		element_tag_prompt_password}
     };
 
   static signed char lookup[] =
     {
-       -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,   0,
-        1,   2,  -1,  -1,   3,   4,   5,   6,  -1,   7,
-        8,  -1,   9,  10,  -1,  11,  -1,  -1,  12,  13,
-       -1,  14,  15,  16,  17,  18,  19,  20,  -1,  21,
-       22,  23,  24,  25,  26,  27,  -1,  28,  -1,  29,
-       30,  31,  32,  -1,  33,  -1,  34,  35,  -1,  -1,
-       -1,  -1,  36,  37,  38,  -1,  -1,  39,  40,  41,
-       -1,  42,  43,  44,  45,  -1,  46,  47,  -1,  48,
-       -1,  49,  50,  51,  52,  53,  54,  55,  -1,  56,
-       -1,  57,  58,  -1,  -1,  59,  -1,  60,  61,  -1,
-       62,  63,  64,  -1,  -1,  65,  66,  67,  -1,  68,
-       -1,  69,  -1,  -1,  70,  71,  72,  -1,  -1,  -1,
-       -1,  73,  -1,  -1,  -1,  74,  75,  76,  77,  78,
-       79,  80,  -1,  81,  -1,  -1,  82,  -1,  83,  -1,
-       84,  85,  -1,  -1,  86,  -1,  87,  -1,  -1,  -1,
-       -1,  -1,  88,  -1,  -1,  89,  -1,  -1,  -1,  -1,
-       -1,  90,  -1,  91,  -1,  -1,  -1,  92,  -1,  -1,
-       93,  -1,  -1,  -1,  -1,  -1,  -1,  94,  -1,  -1,
-       95,  -1,  -1,  96,  97,  98,  -1,  -1,  -1,  -1,
-       99,  -1,  -1, 100,  -1,  -1,  -1,  -1,  -1,  -1,
-       -1,  -1,  -1,  -1,  -1, 101,  -1,  -1,  -1,  -1,
-       -1,  -1,  -1,  -1,  -1,  -1, 102,  -1,  -1,  -1,
+       -1,  -1,  -1,  -1,  -1,   0,  -1,  -1,   1,   2,
+       -1,  -1,  -1,  -1,   3,  -1,  -1,   4,  -1,   5,
+        6,  -1,   7,  -1,  -1,  -1,   8,  -1,   9,  10,
+       11,  12,  -1,  13,  -1,  14,  15,  -1,  16,  17,
+       18,  19,  -1,  20,  21,  22,  -1,  23,  24,  25,
+       26,  27,  28,  -1,  29,  30,  31,  32,  33,  34,
+       35,  -1,  36,  -1,  37,  38,  39,  40,  -1,  41,
+       -1,  42,  43,  44,  -1,  -1,  45,  46,  47,  48,
+       49,  50,  51,  52,  53,  54,  55,  56,  57,  58,
+       -1,  59,  60,  -1,  61,  62,  -1,  63,  64,  -1,
+       -1,  -1,  65,  -1,  66,  -1,  67,  68,  -1,  69,
+       70,  71,  72,  -1,  73,  74,  75,  76,  -1,  77,
+       -1,  78,  79,  80,  81,  -1,  -1,  82,  -1,  -1,
+       83,  -1,  84,  85,  -1,  86,  87,  88,  -1,  89,
+       90,  -1,  91,  92,  -1,  -1,  -1,  93,  94,  -1,
+       -1,  95,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
+       -1,  -1,  -1,  -1,  -1,  96,  -1,  -1,  -1,  -1,
+       97,  -1,  98,  -1,  -1,  -1,  99,  -1,  -1,  -1,
+       -1, 100,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
+       -1, 101,  -1,  -1,  -1,  -1, 102,  -1,  -1,  -1,
+      103,  -1,  -1,  -1,  -1, 104,  -1,  -1,  -1,  -1,
+       -1,  -1,  -1, 105,  -1,  -1,  -1,  -1,  -1,  -1,
+       -1,  -1,  -1,  -1,  -1,  -1, 106,  -1,  -1,  -1,
+       -1, 107,  -1,  -1, 108,  -1,  -1,  -1,  -1,  -1,
+       -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
+      109,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
        -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
-       -1,  -1,  -1, 103
+       -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
+       -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
+       -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
+       -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
+       -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
+       -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
+       -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
+       -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,  -1,
+      110
     };
 
   if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
@@ -392,5 +418,5 @@ in_word_set (register const char *str, register unsigned int len)
     }
   return 0;
 }
-#line 141 "item_common_lookup.gperf"
+#line 148 "item_common_lookup.gperf"
 
