@@ -38,8 +38,8 @@ item_date_assign(
 
   memset(o_date, 0, sizeof(*o_date));
 
-  (*o_date).m_len_x= 30.0;
-  (*o_date).m_len_y= 18.0;
+  (*o_date).m_box.m_len_x= 30.0;
+  (*o_date).m_box.m_len_y= 18.0;
   (*o_date).m_font= pango_font_description_new();
   (*o_date).m_color.alpha= 1.0;
   (*o_date).m_border.m_style= line_style_solid;
@@ -53,6 +53,20 @@ item_date_assign(
   return;
 }
 
+extern void
+item_date_copy(
+  struct item_date *const               o_date,
+  struct item_date const*const          i_date)
+{
+
+  memcpy(o_date, i_date, sizeof(*o_date));
+  (*o_date).m_font= pango_font_description_copy((*i_date).m_font);
+  (*o_date).m_locale= g_strdup((*i_date).m_locale); 
+  (*o_date).m_timezone= g_strdup((*i_date).m_timezone); 
+
+  return;
+}
+
 extern void
 item_date_discharge(
   struct item_date*const                io_date)
@@ -83,8 +97,14 @@ item_date_draw(
   struct item_date*const                i_date,
   struct item_draw_context const*const  i_ctx)
 {
+  double                                l_center_x;
+  double                                l_center_y;
   PangoFontDescription*                 l_font;
   PangoLayout*                          l_layout;
+  cairo_matrix_t                        l_matrix;
+  double                                l_radians;
+  double                                l_shear_x;
+  double                                l_shear_y;
   char*                                 l_text;
 
   l_font= 0;
@@ -94,47 +114,6 @@ item_date_draw(
   do
   {
 
-    cairo_save((*i_ctx).m_cr);
-
-    if ((*i_date).m_fill.m_active)
-    {
-      cairo_set_source_rgba(
-        (*i_ctx).m_cr,
-        (*i_date).m_fill.m_color.red,
-        (*i_date).m_fill.m_color.green,
-        (*i_date).m_fill.m_color.blue,
-        (*i_date).m_fill.m_color.alpha);
-
-      cairo_rectangle(
-        (*i_ctx).m_cr,
-        (*i_date).m_pos_x,
-        (*i_date).m_pos_y,
-        (*i_date).m_len_x,
-        (*i_date).m_len_y);
-
-      cairo_fill((*i_ctx).m_cr);
-    }
-
-    cairo_rectangle(
-      (*i_ctx).m_cr,
-      (*i_date).m_pos_x,
-      (*i_date).m_pos_y,
-      (*i_date).m_len_x,
-      (*i_date).m_len_x);
-
-    cairo_clip((*i_ctx).m_cr);
-
-    cairo_set_source_rgba(
-      (*i_ctx).m_cr,
-      (*i_date).m_color.red,
-      (*i_date).m_color.green,
-      (*i_date).m_color.blue,
-      (*i_date).m_color.alpha);
-
-    l_layout= pango_cairo_create_layout((*i_ctx).m_cr);
-    pango_layout_set_font_description(l_layout, (*i_date).m_font); 
-    cairo_translate((*i_ctx).m_cr, (*i_date).m_pos_x, (*i_date).m_pos_y);
-
     if ((item_draw_design == (*i_ctx).m_option.m_type) &&
       (0 == (*i_date).m_time))
     {
@@ -149,11 +128,52 @@ item_date_draw(
       (*i_date).m_locale,
       (*i_date).m_timezone);
 
-    pango_layout_set_text(l_layout, l_text, -1);
-    pango_cairo_update_layout((*i_ctx).m_cr, l_layout);
-    pango_cairo_show_layout((*i_ctx).m_cr, l_layout);
+    cairo_new_path((*i_ctx).m_cr);
+    cairo_save((*i_ctx).m_cr);
+    cairo_scale((*i_ctx).m_cr, (*i_ctx).m_scale, (*i_ctx).m_scale);
 
-    cairo_restore((*i_ctx).m_cr);
+    l_layout= pango_cairo_create_layout((*i_ctx).m_cr);
+    pango_layout_set_width(l_layout, -1);
+    pango_layout_set_text(l_layout, l_text, -1);
+    pango_layout_set_font_description(l_layout, (*i_date).m_font); 
+
+    l_center_x= (*i_date).m_box.m_pos_x + ((*i_date).m_box.m_len_x / 2.0);
+    l_center_y= (*i_date).m_box.m_pos_y + ((*i_date).m_box.m_len_y / 2.0);
+
+    cairo_translate((*i_ctx).m_cr, l_center_x, l_center_y);
+    l_radians= geom_deg2rad((*i_date).m_transform.m_rotation);
+    cairo_rotate((*i_ctx).m_cr, l_radians);
+    cairo_translate((*i_ctx).m_cr, -l_center_x, -l_center_y);
+
+    l_shear_x= tan(geom_deg2rad((*i_date).m_transform.m_shear_x));
+    l_shear_y= tan(geom_deg2rad((*i_date).m_transform.m_shear_y));
+    
+    cairo_matrix_init(
+      &l_matrix,
+      1.0, l_shear_y,
+      l_shear_x, 1.0,
+      (*i_date).m_box.m_pos_x, (*i_date).m_box.m_pos_y);
+    cairo_transform((*i_ctx).m_cr, &l_matrix);
+
+
+    if ((*i_date).m_fill.m_active)
+    {
+      cairo_set_source_rgba(
+        (*i_ctx).m_cr,
+        (*i_date).m_fill.m_color.red,
+        (*i_date).m_fill.m_color.green,
+        (*i_date).m_fill.m_color.blue,
+        (*i_date).m_fill.m_color.alpha);
+
+      cairo_rectangle(
+        (*i_ctx).m_cr,
+        0.0,
+        0.0,
+        (*i_date).m_box.m_len_x,
+        (*i_date).m_box.m_len_y);
+
+      cairo_fill_preserve((*i_ctx).m_cr);
+    }
 
     if ((*i_date).m_border.m_active)
     {
@@ -169,28 +189,39 @@ item_date_draw(
 
       cairo_rectangle(
         (*i_ctx).m_cr,
-        (*i_date).m_pos_x,
-        (*i_date).m_pos_y,
-        (*i_date).m_len_x,
-        (*i_date).m_len_y);
+        0.0,
+        0.0,
+        (*i_date).m_box.m_len_x,
+        (*i_date).m_box.m_len_y);
 
+      cairo_stroke_preserve((*i_ctx).m_cr);
+    }
+
+    cairo_set_source_rgba(
+      (*i_ctx).m_cr,
+      (*i_date).m_color.red,
+      (*i_date).m_color.green,
+      (*i_date).m_color.blue,
+      (*i_date).m_color.alpha);
+
+    pango_cairo_update_layout((*i_ctx).m_cr, l_layout);
+    pango_cairo_show_layout((*i_ctx).m_cr, l_layout);
+
+    if ((*i_ctx).m_option.m_highlight && 0 == (*i_ctx).m_selected)
+    {
+      item_common_cairo_dash_set((*i_ctx).m_cr, line_style_solid);
+      cairo_set_line_width((*i_ctx).m_cr, 1.0);
+      cairo_set_source_rgb((*i_ctx).m_cr, 0.50, 0.50, 0.00);
+      cairo_rectangle(
+        (*i_ctx).m_cr,
+        0,
+        0,
+        (*i_date).m_box.m_len_x,
+        (*i_date).m_box.m_len_y);
       cairo_stroke((*i_ctx).m_cr);
     }
 
-    if (0 == (*i_ctx).m_selected)
-    {
-      if ((*i_ctx).m_option.m_highlight &&
-        (item_draw_design == (*i_ctx).m_option.m_type))
-      {
-        item_common_box_draw_hightlight(
-          (*i_ctx).m_cr, 
-          (struct geom_rect*)i_date,
-          (*i_date).m_border.m_thickness);
-      }
-      break;
-    }
-
-    item_common_box_draw_grips((*i_ctx).m_cr, (struct geom_rect*)i_date);
+    cairo_restore((*i_ctx).m_cr);
 
   }while(0);
 
@@ -204,10 +235,7 @@ item_date_draw(
     g_object_unref(l_layout);
   }
 
-  if (l_text)
-  {
-    g_free(l_text);
-  }
+  g_free(l_text);
 
   return;
 }
@@ -215,43 +243,143 @@ item_date_draw(
 extern void
 item_date_get_bbox(
   struct geom_rect*const                o_bbox,
-  void const*const                      i_object)
+  cairo_t*                              io_cr,
+  double const                          i_scale,
+  struct item_date const*const          i_date)
 {
-  (*o_bbox)= *(struct geom_rect*)i_object;
+  item_common_box_get_bbox(
+    o_bbox, io_cr, &(*i_date).m_box, &(*i_date).m_transform, i_scale);
   return;
 }
 
 extern void
-item_date_in_event(
-  enum event_type*const                 o_type,
-  struct item_date const*const          i_date,
-  struct item_in_event const*const      i_ctx)
+item_date_get_position(
+  double*const                          o_pos_x,
+  double*const                          o_pos_y,
+  struct item_date const*const          i_date)
 {
 
-  item_common_box_in_event(o_type, i_ctx, (struct geom_rect*)i_date);
+  (*o_pos_x)= (*i_date).m_box.m_pos_x;
+  (*o_pos_y)= (*i_date).m_box.m_pos_y;
 
   return;
 }
 
+extern void
+item_date_get_rotation(
+  double*const                          o_rotation,
+  struct item_date const*const          i_date)
+{
+
+  (*o_rotation)= (*i_date).m_transform.m_rotation;
+
+  return;
+}
+
+extern void
+item_date_get_size(
+  double*const                          o_len_x,
+  double*const                          o_len_y,
+  struct item_date const*const          i_date)
+{
+
+  (*o_len_x)= (*i_date).m_box.m_len_x;
+  (*o_len_y)= (*i_date).m_box.m_len_y;
+
+  return;
+}
+
+extern void
+item_date_get_shear(
+  double*const                          o_shear_x,
+  double*const                          o_shear_y,
+  struct item_date const*const          i_date)
+{
+
+  (*o_shear_x)= (*i_date).m_transform.m_shear_x;
+  (*o_shear_y)= (*i_date).m_transform.m_shear_y;
+
+  return;
+}
+
+extern int
+item_date_in_event(
+  struct item_date const*const          i_date,
+  cairo_t*                              io_cr,
+  struct item_in_event const*const      i_ctx)
+{
+  int                                   l_hit;
+
+  l_hit= item_common_box_in_event(
+    io_cr, &(*i_date).m_box, &(*i_date).m_transform, i_ctx);
+
+  return l_hit;
+}
+
 extern void
 item_date_move(
   struct item_date*const                io_date,
   struct geom_point const*const         i_event)
 {
-  item_common_box_move((struct geom_rect*)io_date, i_event);
+  item_common_box_move(&(*io_date).m_box, i_event);
   return;
 }
 
 extern void
 item_date_normalize(
-  struct item_date*const                io_date,
-  double const                          i_bound_width,
-  double const                          i_bound_height)
+  struct item_date*const                io_date)
 {
-  item_common_box_normalize(
-    (struct geom_rect*)io_date, 
-    i_bound_width,
-    i_bound_height);
+  item_common_box_normalize(&(*io_date).m_box);
+  return;
+}
+
+extern void
+item_date_set_position(
+  struct item_date*const                io_date,
+  double const                          i_pos_x,
+  double const                          i_pos_y)
+{
+
+  (*io_date).m_box.m_pos_x= i_pos_x;
+  (*io_date).m_box.m_pos_y= i_pos_y;
+
+  return;
+}
+
+extern void
+item_date_set_rotation(
+  struct item_date*const                io_date,
+  double                                i_rotation)
+{
+
+  (*io_date).m_transform.m_rotation= i_rotation;
+
+  return;
+}
+
+extern void
+item_date_set_size(
+  struct item_date*const                io_date,
+  double                                i_len_x,
+  double                                i_len_y)
+{
+
+  (*io_date).m_box.m_len_x= i_len_x;
+  (*io_date).m_box.m_len_y= i_len_y;
+
+  return;
+}
+
+extern void
+item_date_set_shear(
+  struct item_date*const                io_date,
+  double                                i_shear_x,
+  double                                i_shear_y)
+{
+
+  (*io_date).m_transform.m_shear_x= i_shear_x;
+  (*io_date).m_transform.m_shear_y= i_shear_y;
+
   return;
 }
 
@@ -294,17 +422,11 @@ item_date_read(
     {
       switch(l_type)
       {
-        case element_tag_pos_x:
-          (*io_date).m_pos_x= xml_convert_double(l_value);
+        case element_tag_rect:
+          item_common_box_read(&l_error, &(*io_date).m_box, l_xml);
           break;
-        case element_tag_pos_y:
-          (*io_date).m_pos_y= xml_convert_double(l_value);
-          break;
-        case element_tag_len_x:
-          (*io_date).m_len_x= xml_convert_double(l_value);
-          break;
-        case element_tag_len_y:
-          (*io_date).m_len_y= xml_convert_double(l_value);
+        case element_tag_transform:
+          item_common_read_transform(&l_error, &(*io_date).m_transform, l_xml);
           break;
         case element_tag_font:
           (*io_date).m_font= pango_font_description_from_string(l_value);
@@ -317,7 +439,7 @@ item_date_read(
           }
           break;
         case element_tag_border:
-          l_exit= item_common_read_border_attr(&l_error, &(*io_date).m_border, l_xml);
+          l_exit= item_common_read_border(&l_error, &(*io_date).m_border, l_xml);
           break;
         case element_tag_fill:
           l_exit= item_common_read_fill(&l_error, &(*io_date).m_fill, l_xml);
@@ -357,7 +479,29 @@ item_date_resize(
   struct item_resize_event const*const  i_ctx)
 {
 
-  item_common_box_resize((struct geom_rect *)io_date, i_ctx);
+  item_common_box_resize(&(*io_date).m_box, i_ctx, &(*io_date).m_transform);
+
+  return;
+}
+
+extern void
+item_date_rotate(
+  struct item_date*const                io_date,
+  double const                          i_rotation)
+{
+  (*io_date).m_transform.m_rotation= i_rotation;
+  return;
+}
+  
+extern void
+item_date_shear(
+  struct item_date*const                io_date,
+  double const                          i_delta_x,
+  double const                          i_delta_y)
+{
+
+  (*io_date).m_transform.m_shear_x+= i_delta_x;
+  (*io_date).m_transform.m_shear_y+= i_delta_y;
 
   return;
 }
@@ -368,7 +512,6 @@ item_date_write(
   FILE*const                            io_fp,
   struct item_date const*const          i_date)
 {
-  char                                  l_buf[G_ASCII_DTOSTR_BUF_SIZE+1];
   int                                   l_exit;
   char*                                 l_text;
 
@@ -376,17 +519,15 @@ item_date_write(
   l_text= 0;
 
   fprintf(io_fp, "\t\t\t<item name=\"date\">\n");
-  fprintf(io_fp, "\t\t\t\t<pos_x>%s</pos_x>\n", g_ascii_dtostr(l_buf, sizeof(l_buf), (*i_date).m_pos_x));
-  fprintf(io_fp, "\t\t\t\t<pos_y>%s</pos_y>\n", g_ascii_dtostr(l_buf, sizeof(l_buf), (*i_date).m_pos_y));
-  fprintf(io_fp, "\t\t\t\t<len_x>%s</len_x>\n", g_ascii_dtostr(l_buf, sizeof(l_buf), (*i_date).m_len_x));
-  fprintf(io_fp, "\t\t\t\t<len_y>%s</len_y>\n", g_ascii_dtostr(l_buf, sizeof(l_buf), (*i_date).m_len_y));
+  item_common_box_write(o_error, io_fp, &(*i_date).m_box);
+  item_common_write_transform(o_error, io_fp, &(*i_date).m_transform);
   l_text= pango_font_description_to_string((*i_date).m_font);
   fprintf(io_fp, "\t\t\t\t<font>%s</font>\n", l_text);
   g_free(l_text);
   l_text= gdk_rgba_to_string(&(*i_date).m_color);
   fprintf(io_fp, "\t\t\t\t<color>%s</color>\n", l_text);
   g_free(l_text);
-  item_common_write_border_attr(o_error, io_fp, &(*i_date).m_border);
+  item_common_write_border(o_error, io_fp, &(*i_date).m_border);
   item_common_write_fill(o_error, io_fp, &(*i_date).m_fill);
   fprintf(io_fp, "\t\t\t\t<date_style>%s</date_style>\n", item_common_get_datetime_style_text((*i_date).m_date_style));
   fprintf(io_fp, "\t\t\t\t<time_style>%s</time_style>\n", item_common_get_datetime_style_text((*i_date).m_time_style));
