@@ -35,13 +35,11 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 struct item_date
 {
-  gdouble                               m_pos_x;
-  gdouble                               m_pos_y;
-  gdouble                               m_len_x;
-  gdouble                               m_len_y;
+  struct geom_rect                      m_box;
+  struct item_transform                 m_transform;
   PangoFontDescription*                 m_font; 
   GdkRGBA                               m_color;
-  struct item_border_attr               m_border;
+  struct item_border               m_border;
   struct item_fill                      m_fill;
   enum date_style_type                  m_date_style;
   enum date_style_type                  m_time_style;
@@ -56,8 +54,9 @@ item_date_assign(
   struct item_method*const              o_method);
 
 extern void
-item_date_extent_update(
-  struct item_date*const                io_date);
+item_date_copy(
+  struct item_date *const               o_date,
+  struct item_date const*const          i_date);
 
 extern void
 item_date_discharge(
@@ -66,12 +65,37 @@ item_date_discharge(
 extern void
 item_date_get_bbox(
   struct geom_rect*const                o_bbox,
-  void const*const                      i_object);
+  cairo_t*                              io_cr,
+  double const                          i_scale,
+  struct item_date const*const          i_date);
 
 extern void
+item_date_get_position(
+  double*const                          o_pos_x,
+  double*const                          o_pos_y,
+  struct item_date const*const          i_date);
+
+extern void
+item_date_get_rotation(
+  double*const                          o_rotation,
+  struct item_date const*const          i_date);
+
+extern void
+item_date_get_size(
+  double*const                          o_len_x,
+  double*const                          o_len_y,
+  struct item_date const*const          i_date);
+
+extern void
+item_date_get_shear(
+  double*const                          o_shear_x,
+  double*const                          o_shear_y,
+  struct item_date const*const          i_date);
+
+extern int
 item_date_in_event(
-  enum event_type*const                 o_type,
   struct item_date const*const          i_date,
+  cairo_t*                              io_cr,
   struct item_in_event const*const      i_ctx);
 
 extern void
@@ -86,9 +110,30 @@ item_date_move(
 
 extern void
 item_date_normalize(
+  struct item_date*const                io_date);
+
+extern void
+item_date_set_position(
   struct item_date*const                io_date,
-  double const                          i_bound_width,
-  double const                          i_bound_height);
+  double const                          i_pos_x,
+  double const                          i_pos_y);
+
+extern void
+item_date_set_rotation(
+  struct item_date*const                io_date,
+  double                                i_rotation);
+
+extern void
+item_date_set_size(
+  struct item_date*const                io_date,
+  double                                i_len_x,
+  double                                i_len_y);
+
+extern void
+item_date_set_shear(
+  struct item_date*const                io_date,
+  double const                          i_shear_x,
+  double const                          i_shear_y);
 
 extern int
 item_date_property(
@@ -98,13 +143,24 @@ extern int
 item_date_read(
   GError**                              o_error,
   struct item_date*const                io_date,
-  struct xml *const               i_element);
+  struct xml *const                     i_element);
 
 extern void
 item_date_resize(
   struct item_date*const                io_date,
   struct item_resize_event const*const  i_ctx);
 
+extern void
+item_date_rotate(
+  struct item_date*const                io_date,
+  double const                          i_rotation);
+  
+extern void
+item_date_shear(
+  struct item_date*const                io_date,
+  double const                          i_delta_x,
+  double const                          i_delta_y);
+
 extern int
 item_date_write(
   GError**                              o_error,
