@@ -36,77 +36,132 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 struct item_fbarcode
 {
-  gdouble                               m_pos_x;
-  gdouble                               m_pos_y;
-  gdouble                               m_len_x;
-  gdouble                               m_len_y;
+  struct geom_rect                      m_box;
   enum symbology_type                   m_barcode;
   gdouble                               m_scale;
-  gchar                                 m_tag[1+FIELD_NAME_MAX_LEN];
+  struct item_table                     m_table;
   gchar*                                m_value;
   guint                                 m_value_size;
 };
 
 extern void
 item_fbarcode_assign(
-  struct item_fbarcode*const            o_fbarcode,
+  struct item_fbarcode*const            o_object,
   struct item_method*const              o_method);
 
 extern void
-item_fbarcode_extent_update(
-  struct item_fbarcode*const            io_fbarcode);
+item_fbarcode_copy(
+  struct item_fbarcode *const           o_object,
+  struct item_fbarcode const*const      i_object);
 
 extern void
 item_fbarcode_discharge(
-  struct item_fbarcode*const            io_fbarcode);
+  struct item_fbarcode*const            io_object);
 
 extern void
 item_fbarcode_get_bbox(
   struct geom_rect*const                o_bbox,
-  void const*const                      i_object);
+  cairo_t*                              io_cr,
+  double const                          i_scale,
+  struct item_fbarcode const*const      i_object);
 
 extern void
+item_fbarcode_get_position(
+  double*const                          o_pos_x,
+  double*const                          o_pos_y,
+  struct item_fbarcode const*const      i_object);
+
+extern void
+item_fbarcode_get_rotation(
+  double*const                          o_rotation,
+  struct item_fbarcode const*const      i_object);
+
+extern void
+item_fbarcode_get_size(
+  double*const                          o_len_x,
+  double*const                          o_len_y,
+  struct item_fbarcode const*const      i_object);
+
+extern void
+item_fbarcode_get_shear(
+  double*const                          o_shear_x,
+  double*const                          o_shear_y,
+  struct item_fbarcode const*const      i_object);
+
+extern int
 item_fbarcode_in_event(
-  enum event_type*const                 o_type,
-  struct item_fbarcode const*const      i_fbarcode,
+  struct item_fbarcode const*const      i_object,
+  cairo_t*                              io_cr,
   struct item_in_event const*const      i_ctx);
 
 extern void
 item_fbarcode_draw(
-  struct item_fbarcode*const            io_fbarcode,
+  struct item_fbarcode*const            io_object,
   struct item_draw_context const*const  i_ctx);
 
 extern void
 item_fbarcode_move(
-  struct item_fbarcode*const            io_fbarcode,
+  struct item_fbarcode*const            io_object,
   struct geom_point const*const         i_event);
 
 extern void
 item_fbarcode_normalize(
-  struct item_fbarcode*const            io_fbarcode,
-  double const                          i_bound_width,
-  double const                          i_bound_height);
+  struct item_fbarcode*const            io_object);
+
+extern void
+item_fbarcode_set_position(
+  struct item_fbarcode*const            io_object,
+  double const                          i_pos_x,
+  double const                          i_pos_y);
+
+extern void
+item_fbarcode_set_rotation(
+  struct item_fbarcode*const            io_object,
+  double                                i_rotation);
+
+extern void
+item_fbarcode_set_size(
+  struct item_fbarcode*const            io_object,
+  double                                i_len_x,
+  double                                i_len_y);
+
+extern void
+item_fbarcode_set_shear(
+  struct item_fbarcode*const            io_object,
+  double const                          i_shear_x,
+  double const                          i_shear_y);
 
 extern int
 item_fbarcode_property(
-  struct item_fbarcode*const            io_fbarcode);
+  struct item_fbarcode*const            io_object);
 
 extern int
 item_fbarcode_read(
   GError**                              o_error,
-  struct item_fbarcode*const            io_fbarcode,
-  struct xml *const               i_element);
+  struct item_fbarcode*const            io_object,
+  struct xml *const                     i_element);
 
 extern void
 item_fbarcode_resize(
-  struct item_fbarcode*const            io_fbarcode,
+  struct item_fbarcode*const            io_object,
   struct item_resize_event const*const  i_ctx);
 
+extern void
+item_fbarcode_rotate(
+  struct item_fbarcode*const            io_object,
+  double const                          i_rotation);
+  
+extern void
+item_fbarcode_shear(
+  struct item_fbarcode*const            io_object,
+  double const                          i_delta_x,
+  double const                          i_delta_y);
+
 extern int
 item_fbarcode_write(
   GError**                              o_error,
   FILE*const                            io_fp,
-  struct item_fbarcode const*const      io_fbarcode);
+  struct item_fbarcode const*const      io_object);
 
 #define __item_fbarcode_h__
 #endif
