@@ -29,8 +29,7 @@ NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 #include "item_fimage.h"
-#include "database_field.h"
-#include "mainw.h"
+#include "item_property.h"
 
 struct fimage_dialog
 {
@@ -39,133 +38,51 @@ struct fimage_dialog
   GtkSpinButton*                        m_border_thickness_spinbutton;
   GtkEntry*                             m_border_color_entry;
   GtkButton*                            m_border_color_button;
-  GtkEntry*                             m_field_entry;
-  GtkButton*                            m_field_button;
+  struct item_table_dialog              m_table;
 };
 
-static void
-item_fimage_border_color_button_cb(
-  GtkWidget *                           i_widget,
-  gpointer                              i_data)
-{
-  GdkRGBA                               l_color;
-  GtkWidget*                            l_dialog;
-  int                                   l_exit;
-  struct fimage_dialog*                l_fimage;
-  gchar*                                l_rgba;
-  gchar const*                          l_text;
-
-  l_dialog= 0;
-  memset(&l_color, 0, sizeof(l_color));
-
-  do
-  {
-
-    l_fimage= (struct fimage_dialog*)i_data;
-
-    l_dialog= gtk_color_chooser_dialog_new("Border Color", get_main_window());
-
-    l_text= gtk_entry_get_text((*l_fimage).m_border_color_entry);
-    gdk_rgba_parse(&l_color, l_text);
-    gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(l_dialog), &l_color);
-
-    gtk_window_set_modal((GtkWindow*)l_dialog, 1);
-    l_exit= gtk_dialog_run(GTK_DIALOG(l_dialog));
-
-    if (GTK_RESPONSE_OK != l_exit)
-    {
-      break;
-    }
-
-    gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(l_dialog), &l_color);
-
-    l_rgba= gdk_rgba_to_string(&l_color);
-    gtk_entry_set_text((*l_fimage).m_border_color_entry, l_rgba);
-    g_free(l_rgba);
-
-  }while(0);
-
-  if (l_dialog)
-  {
-    gtk_widget_destroy((GtkWidget*)l_dialog);
-  }
-  
-  return;
-}
-
-static void
-item_fimage_field_button_cb(
-  GtkWidget *                           i_widget,
-  gpointer                              i_data)
-{
-  struct fimage_dialog*                l_fimage;
-  char*                                 l_attribute;
-
-  l_attribute= 0;
-
-  l_fimage= (struct fimage_dialog*)i_data;
-
-  database_field_property(
-    &l_attribute, 
-    &(*g_mainw).m_report.m_aspect,
-    &(*g_mainw).m_report.m_query);
-
-  if (l_attribute)
-  {
-    gtk_entry_set_text((*l_fimage).m_field_entry, l_attribute);
-  }
-
-  if (l_attribute)
-  {
-    g_free(l_attribute);
-  }
-
-  return;
-}
-
 static void
 item_fimage_bind(
-  struct fimage_dialog*const             o_fimage,
+  struct fimage_dialog*const            o_dlg,
   GtkBuilder*const                      i_builder)
 {
 
-  memset(o_fimage, 0, sizeof(*o_fimage));
+  memset(o_dlg, 0, sizeof(*o_dlg));
 
   do
   {
 
-    (*o_fimage).m_border_checkbutton=
+    (*o_dlg).m_border_checkbutton=
       GTK_CHECK_BUTTON(gtk_builder_get_object(i_builder, "border_checkbutton"));
 
-    (*o_fimage).m_border_style_combobox=
+    (*o_dlg).m_border_style_combobox=
       GTK_COMBO_BOX_TEXT(gtk_builder_get_object(i_builder, "border_style_comboboxtext"));
 
-    (*o_fimage).m_border_thickness_spinbutton=
+    (*o_dlg).m_border_thickness_spinbutton=
       GTK_SPIN_BUTTON(gtk_builder_get_object(i_builder, "border_thickness_spinbutton"));
 
-    (*o_fimage).m_border_color_entry=
+    (*o_dlg).m_border_color_entry=
       GTK_ENTRY(gtk_builder_get_object(i_builder, "border_color_entry"));
 
-    (*o_fimage).m_border_color_button=
+    (*o_dlg).m_border_color_button=
       GTK_BUTTON(gtk_builder_get_object(i_builder, "border_color_button"));
 
     g_signal_connect(
-      (*o_fimage).m_border_color_button,
+      (*o_dlg).m_border_color_button,
       "clicked",
-      G_CALLBACK(item_fimage_border_color_button_cb),
-      o_fimage);
+      G_CALLBACK(item_property_border_color_button_cb),
+      (*o_dlg).m_border_color_entry);
 
-    (*o_fimage).m_field_entry=
-      GTK_ENTRY(gtk_builder_get_object(i_builder, "field_entry"));
+    (*o_dlg).m_table.m_column_comboboxtext=
+      GTK_COMBO_BOX_TEXT(gtk_builder_get_object(i_builder, "column_comboboxtext"));
 
-    (*o_fimage).m_field_button=
-      GTK_BUTTON(gtk_builder_get_object(i_builder, "field_button"));
+    item_property_load_query((*o_dlg).m_table.m_query_comboboxtext);
 
     g_signal_connect(
-      (*o_fimage).m_field_button,
-      "clicked",
-      G_CALLBACK(item_fimage_field_button_cb),
-      o_fimage);
+      (*o_dlg).m_table.m_query_comboboxtext,
+      "changed",
+      G_CALLBACK(item_property_comboboxtext_cb),
+      &(*o_dlg).m_table);
 
   }while(0);
 
@@ -174,82 +91,88 @@ item_fimage_bind(
 
 static void
 item_fimage_set_values(
-  struct fimage_dialog*const             i_fimaged,
-  struct item_fimage const*const         i_fimage)
+  struct fimage_dialog*const            io_dlg,
+  struct item_fimage const*const        i_object)
 {
   gchar*                                l_color;
 
   gtk_toggle_button_set_active(
-    GTK_TOGGLE_BUTTON((*i_fimaged).m_border_checkbutton),
-    (*i_fimage).m_border.m_active);
+    GTK_TOGGLE_BUTTON((*io_dlg).m_border_checkbutton),
+    (*i_object).m_border.m_active);
 
   gtk_combo_box_set_active(
-      GTK_COMBO_BOX((*i_fimaged).m_border_style_combobox), 
-      (*i_fimage).m_border.m_style);
+      GTK_COMBO_BOX((*io_dlg).m_border_style_combobox), 
+      (*i_object).m_border.m_style);
 
   gtk_spin_button_set_value(
-    GTK_SPIN_BUTTON((*i_fimaged).m_border_thickness_spinbutton),
-    (*i_fimage).m_border.m_thickness);
+    GTK_SPIN_BUTTON((*io_dlg).m_border_thickness_spinbutton),
+    (*i_object).m_border.m_thickness);
 
-  l_color= gdk_rgba_to_string(&(*i_fimage).m_border.m_color);
-  gtk_entry_set_text((*i_fimaged).m_border_color_entry, l_color);
+  l_color= gdk_rgba_to_string(&(*i_object).m_border.m_color);
+  gtk_entry_set_text((*io_dlg).m_border_color_entry, l_color);
   g_free(l_color);
   l_color= 0;
 
-  gtk_entry_set_text((*i_fimaged).m_field_entry, (*i_fimage).m_tag);
+  item_property_database_set_active(
+    (*io_dlg).m_table.m_query_comboboxtext,
+    (*io_dlg).m_table.m_column_comboboxtext,
+    &(*i_object).m_table);
 
   return;
 }
 
 static void
 item_fimage_copy_values(
-  struct item_fimage *const              io_fimage,
-  struct fimage_dialog const*const       i_fimaged)
+  struct item_fimage *const             io_object,
+  struct fimage_dialog const*const      i_dlg)
 {
   gchar const*                          l_text;
   gint                                  l_rc;
 
-  (*io_fimage).m_border.m_active=
+  (*io_object).m_border.m_active=
     gtk_toggle_button_get_active(
-      GTK_TOGGLE_BUTTON((*i_fimaged).m_border_checkbutton));
+      GTK_TOGGLE_BUTTON((*i_dlg).m_border_checkbutton));
 
   l_rc = gtk_combo_box_get_active(
-    GTK_COMBO_BOX((*i_fimaged).m_border_style_combobox));
+    GTK_COMBO_BOX((*i_dlg).m_border_style_combobox));
 
-  if ((0 <= l_rc) && (LINE_STYLE_SLOTS > l_rc))
+  if ((0 <= l_rc) && (line_style_last > l_rc))
   {
-    (*io_fimage).m_border.m_style= (enum line_style_type)l_rc;
+    (*io_object).m_border.m_style= (enum line_style_type)l_rc;
   }
   else
   {
-    (*io_fimage).m_border.m_style= line_style_solid;
+    (*io_object).m_border.m_style= line_style_solid;
   }
 
-  (*io_fimage).m_border.m_thickness= gtk_spin_button_get_value(
-    GTK_SPIN_BUTTON((*i_fimaged).m_border_thickness_spinbutton));
+  (*io_object).m_border.m_thickness= gtk_spin_button_get_value(
+    GTK_SPIN_BUTTON((*i_dlg).m_border_thickness_spinbutton));
 
-  l_text= gtk_entry_get_text(GTK_ENTRY((*i_fimaged).m_border_color_entry));
-  gdk_rgba_parse(&(*io_fimage).m_border.m_color, l_text);
+  l_text= gtk_entry_get_text(GTK_ENTRY((*i_dlg).m_border_color_entry));
+  gdk_rgba_parse(&(*io_object).m_border.m_color, l_text);
 
-  l_text= gtk_entry_get_text(GTK_ENTRY((*i_fimaged).m_field_entry));
-  memset((*io_fimage).m_tag, 0, sizeof((*io_fimage).m_tag));
-  strncpy((*io_fimage).m_tag, l_text, sizeof((*io_fimage).m_tag)-1);
-  g_strstrip((*io_fimage).m_tag);
+  g_free((*io_object).m_table.m_query);
+  (*io_object).m_table.m_query= 
+    gtk_combo_box_text_get_active_text((*i_dlg).m_table.m_query_comboboxtext);
+
+  g_free((*io_object).m_table.m_column);
+  (*io_object).m_table.m_column= 
+    gtk_combo_box_text_get_active_text((*i_dlg).m_table.m_column_comboboxtext);
 
   return;
 }
 
 extern int
 item_fimage_property(
-  struct item_fimage*const               io_fimage)
+  struct item_fimage*const              io_object)
 {
   GtkBox*                               l_box;
   GtkBuilder*                           l_builder;
   GtkDialog*                            l_dialog;
+  struct fimage_dialog                  l_dlg;
   GError*                               l_error;
   int                                   l_exit;
   GtkGrid*                              l_grid;
-  struct fimage_dialog                  l_fimage;
   int                                   l_rc;
 
   l_builder= 0;
@@ -283,9 +206,9 @@ item_fimage_property(
       break;
     }
 
-    item_fimage_bind(&l_fimage, l_builder);
+    item_fimage_bind(&l_dlg, l_builder);
 
-    item_fimage_set_values(&l_fimage, io_fimage);
+    item_fimage_set_values(&l_dlg, io_object);
 
     l_dialog= GTK_DIALOG(gtk_dialog_new_with_buttons(
       "Image Edit",
@@ -312,7 +235,7 @@ item_fimage_property(
       break;
     }
 
-    item_fimage_copy_values(io_fimage, &l_fimage);
+    item_fimage_copy_values(io_object, &l_dlg);
 
   }while(0);
 
