@@ -35,68 +35,132 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 struct item_frame
 {
-  rectvect_t                            m_rect;
+  struct geom_rect                      m_box;
+  struct item_transform                 m_transform;
   struct item_border                    m_border;
   struct item_fill                      m_fill;
-  gint                                  m_rotate_shear;
 };
 
 extern void
 item_frame_assign(
-  struct item_frame*const               o_frame,
+  struct item_frame*const               o_object,
   struct item_method*const              o_method);
 
+extern void
+item_frame_copy(
+  struct item_frame *const              o_object,
+  struct item_frame const*const         i_object);
+
+extern void
+item_frame_discharge(
+  struct item_frame*const               io_object);
+
+extern void
+item_frame_draw(
+  struct item_frame*const               i_object,
+  struct item_draw_context const*const  i_ctx);
+
 extern void
 item_frame_get_bbox(
   struct geom_rect*const                o_bbox,
-  void const*const                      i_object);
+  cairo_t*                              io_cr,
+  double const                          i_scale,
+  struct item_frame const*const         i_object);
 
 extern void
+item_frame_get_position(
+  double*const                          o_pos_x,
+  double*const                          o_pos_y,
+  struct item_frame const*const         i_object);
+
+extern void
+item_frame_get_rotation(
+  double*const                          o_rotation,
+  struct item_frame const*const         i_object);
+
+extern void
+item_frame_get_size(
+  double*const                          o_len_x,
+  double*const                          o_len_y,
+  struct item_frame const*const         i_object);
+
+extern void
+item_frame_get_shear(
+  double*const                          o_shear_x,
+  double*const                          o_shear_y,
+  struct item_frame const*const         i_object);
+
+
+extern int
 item_frame_in_event(
-  enum event_type*const                 o_type,
-  struct item_frame const*const         i_frame,
+  struct item_frame const*const         i_object,
+  cairo_t*                              io_cr,
   struct item_in_event const*const      i_ctx);
 
-extern void
-item_frame_discharge(
-  struct item_frame*const               io_frame);
-
-extern void
-item_frame_draw(
-  struct item_frame*const               i_frame,
-  struct item_draw_context const*const  i_ctx);
-
 extern void
 item_frame_move(
-  struct item_frame*const               io_frame,
+  struct item_frame*const               io_object,
   struct geom_point const*const         i_event);
 
 extern void
 item_frame_normalize(
-  struct item_frame*const               io_frame,
-  double const                          i_bound_width,
-  double const                          i_bound_height);
+  struct item_frame*const               io_object);
+
+extern void
+item_frame_set_position(
+  struct item_frame*const               io_object,
+  double const                          i_pos_x,
+  double const                          i_pos_y);
+
+extern void
+item_frame_set_rotation(
+  struct item_frame*const               io_object,
+  double                                i_rotation);
+
+extern void
+item_frame_set_size(
+  struct item_frame*const               io_object,
+  double                                i_len_x,
+  double                                i_len_y);
+
+extern void
+item_frame_set_shear(
+  struct item_frame*const               io_object,
+  double const                          i_shear_x,
+  double const                          i_shear_y);
+
 
 extern int
 item_frame_property(
-  struct item_frame*const               io_frame);
+  struct item_frame*const               io_object);
 
 extern int
 item_frame_read(
   GError**                              o_error,
-  struct item_frame*const               io_frame,
-  struct xml *const               i_element);
+  struct item_frame*const               io_object,
+  struct xml *const                     i_element);
 
 extern void
 item_frame_resize(
-  struct item_frame*const               io_frame,
+  struct item_frame*const               io_object,
   struct item_resize_event const*const  i_ctx);
 
+extern void
+item_frame_rotate(
+  struct item_frame*const               io_object,
+  double const                          i_rotation);
+  
+extern void
+item_frame_shear(
+  struct item_frame*const               io_object,
+  double const                          i_delta_x,
+  double const                          i_delta_y);
+
 extern int
 item_frame_write(
   GError**                              o_error,
   FILE*const                            io_fp,
-  struct item_frame const*const         io_frame);
+  struct item_frame const*const         io_object);
 
 #define __item_frame_h__
 #endif
