@@ -35,80 +35,136 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 struct item_ftext
 {
-  gdouble                               m_pos_x;
-  gdouble                               m_pos_y;
-  gdouble                               m_len_x;
-  gdouble                               m_len_y;
+  struct geom_rect                      m_box;
+  struct item_transform                 m_transform;
   PangoFontDescription*                 m_font; 
   GdkRGBA                               m_color;
-  struct item_border_attr               m_border;
+  struct item_border                    m_border;
   struct item_fill                      m_fill;
   gint                                  m_autowrap;
   PangoWrapMode                         m_wrapmode;
-  gchar                                 m_tag[1+FIELD_NAME_MAX_LEN];
+  struct item_table                     m_table;
   gchar*                                m_value;
 };
 
 extern void
 item_ftext_assign(
-  struct item_ftext*const               o_ftext,
+  struct item_ftext*const               o_object,
   struct item_method*const              o_method);
 
 extern void
-item_ftext_extent_update(
-  struct item_ftext*const               io_ftext);
+item_ftext_copy(
+  struct item_ftext *const              o_object,
+  struct item_ftext const*const         i_object);
 
 extern void
 item_ftext_discharge(
-  struct item_ftext*const               io_ftext);
+  struct item_ftext*const               io_object);
 
 extern void
 item_ftext_get_bbox(
   struct geom_rect*const                o_bbox,
-  void const*const                      i_object);
+  cairo_t*                              io_cr,
+  double const                          i_scale,
+  struct item_ftext const*const         i_object);
 
 extern void
+item_ftext_get_position(
+  double*const                          o_pos_x,
+  double*const                          o_pos_y,
+  struct item_ftext const*const         i_object);
+
+extern void
+item_ftext_get_rotation(
+  double*const                          o_rotation,
+  struct item_ftext const*const         i_object);
+
+extern void
+item_ftext_get_size(
+  double*const                          o_len_x,
+  double*const                          o_len_y,
+  struct item_ftext const*const         i_object);
+
+extern void
+item_ftext_get_shear(
+  double*const                          o_shear_x,
+  double*const                          o_shear_y,
+  struct item_ftext const*const         i_object);
+
+extern int
 item_ftext_in_event(
-  enum event_type*const                 o_type,
-  struct item_ftext const*const         i_ftext,
+  struct item_ftext const*const         i_object,
+  cairo_t*                              io_cr,
   struct item_in_event const*const      i_ctx);
 
 extern void
 item_ftext_draw(
-  struct item_ftext*const               io_ftext,
+  struct item_ftext*const               io_object,
   struct item_draw_context const*const  i_ctx);
 
 extern void
 item_ftext_move(
-  struct item_ftext*const               io_ftext,
+  struct item_ftext*const               io_object,
   struct geom_point const*const         i_event);
 
 extern void
 item_ftext_normalize(
-  struct item_ftext*const               io_ftext,
-  double const                          i_bound_width,
-  double const                          i_bound_height);
+  struct item_ftext*const               io_object);
+
+extern void
+item_ftext_set_position(
+  struct item_ftext*const               io_object,
+  double const                          i_pos_x,
+  double const                          i_pos_y);
+
+extern void
+item_ftext_set_rotation(
+  struct item_ftext*const               io_object,
+  double                                i_rotation);
+
+extern void
+item_ftext_set_size(
+  struct item_ftext*const               io_object,
+  double                                i_len_x,
+  double                                i_len_y);
+
+extern void
+item_ftext_set_shear(
+  struct item_ftext*const               io_object,
+  double const                          i_shear_x,
+  double const                          i_shear_y);
 
 extern int
 item_ftext_property(
-  struct item_ftext*const               io_ftext);
+  struct item_ftext*const               io_object);
 
 extern int
 item_ftext_read(
   GError**                              o_error,
-  struct item_ftext*const               io_ftext,
-  struct xml *const               i_element);
+  struct item_ftext*const               io_object,
+  struct xml *const                     i_element);
 
 extern void
 item_ftext_resize(
-  struct item_ftext*const               io_ftext,
+  struct item_ftext*const               io_object,
   struct item_resize_event const*const  i_ctx);
 
+extern void
+item_ftext_rotate(
+  struct item_ftext*const               io_object,
+  double const                          i_rotation);
+  
+extern void
+item_ftext_shear(
+  struct item_ftext*const               io_object,
+  double const                          i_delta_x,
+  double const                          i_delta_y);
+
 extern int
 item_ftext_write(
   GError**                              o_error,
   FILE*const                            io_fp,
-  struct item_ftext const*const         io_ftext);
+  struct item_ftext const*const         io_object);
 
 #define __item_ftext_h__
 #endif
