@@ -38,8 +38,8 @@ item_image_assign(
 
   memset(o_image, 0, sizeof(*o_image));
 
-  (*o_image).m_len_x= 30.0;
-  (*o_image).m_len_y= 30.0;
+  (*o_image).m_box.m_len_x= 30.0;
+  (*o_image).m_box.m_len_y= 30.0;
   (*o_image).m_border.m_thickness= 1.0;
   (*o_image).m_border.m_color.alpha= 1.0;
 
@@ -48,6 +48,27 @@ item_image_assign(
   return;
 }
 
+extern void
+item_image_copy(
+  struct item_image *const              o_image,
+  struct item_image const*const         i_image)
+{
+
+  memcpy(o_image, i_image, sizeof(*o_image));
+
+  if ((*i_image).m_image)
+  {
+    (*o_image).m_image= gdk_pixbuf_copy((*i_image).m_image);
+  }
+
+  if ((*i_image).m_image_sized)
+  {
+    (*o_image).m_image_sized= gdk_pixbuf_copy((*i_image).m_image_sized);
+  }
+
+  return;
+}
+
 extern void
 item_image_destroy(
   struct item_image*const                io_image)
@@ -100,10 +121,10 @@ item_image_draw(
         (*i_image).m_border.m_color.alpha);
       cairo_rectangle(
         (*i_ctx).m_cr,
-        (*i_image).m_pos_x,
-        (*i_image).m_pos_y,
-        (*i_image).m_len_x,
-        (*i_image).m_len_y);
+        (*i_image).m_box.m_pos_x,
+        (*i_image).m_box.m_pos_y,
+        (*i_image).m_box.m_len_x,
+        (*i_image).m_box.m_len_y);
       cairo_stroke((*i_ctx).m_cr);
     }
 
@@ -112,8 +133,8 @@ item_image_draw(
       gdk_cairo_set_source_pixbuf(
         (*i_ctx).m_cr, 
         (*i_image).m_image_sized,
-        (*i_image).m_pos_x,
-        (*i_image).m_pos_y);
+        (*i_image).m_box.m_pos_x,
+        (*i_image).m_box.m_pos_y);
 
       cairo_paint((*i_ctx).m_cr);
     }
@@ -125,10 +146,10 @@ item_image_draw(
       cairo_set_source_rgb((*i_ctx).m_cr, 0.0, 0.0, 0.0);
       cairo_rectangle(
         (*i_ctx).m_cr,
-        (*i_image).m_pos_x,
-        (*i_image).m_pos_y,
-        (*i_image).m_len_x,
-        (*i_image).m_len_y);
+        (*i_image).m_box.m_pos_x,
+        (*i_image).m_box.m_pos_y,
+        (*i_image).m_box.m_len_x,
+        (*i_image).m_box.m_len_y);
       cairo_stroke((*i_ctx).m_cr);
     }
 
@@ -137,16 +158,11 @@ item_image_draw(
       if ((*i_ctx).m_option.m_highlight &&
         (item_draw_design == (*i_ctx).m_option.m_type))
       {
-        item_common_box_draw_hightlight(
-          (*i_ctx).m_cr, 
-          (struct geom_rect*)i_image,
-          1.0);
+        item_common_box_draw_hightlight((*i_ctx).m_cr, &(*i_image).m_box, 1.0);
       }
       break;
     }
 
-    item_common_box_draw_grips((*i_ctx).m_cr, (struct geom_rect*)i_image);
-
   }while(0);
 
   return;
@@ -155,24 +171,82 @@ item_image_draw(
 extern void
 item_image_get_bbox(
   struct geom_rect*const                o_bbox,
-  void const*const                      i_object)
+  cairo_t*                              io_cr,
+  double const                          i_scale,
+  struct item_image const*const         i_image)
 {
-  (*o_bbox)= *(struct geom_rect*)i_object;
+
+  (*o_bbox)= (*i_image).m_box;
+
   return;
 }
 
 extern void
-item_image_in_event(
-  enum event_type*const                 o_type,
-  struct item_image const*const         i_image,
-  struct item_in_event const*const      i_ctx)
+item_image_get_position(
+  double*const                          o_pos_x,
+  double*const                          o_pos_y,
+  struct item_image const*const         i_image)
 {
 
-  item_common_box_in_event(o_type, i_ctx, (struct geom_rect*)i_image);
+  (*o_pos_x)= (*i_image).m_box.m_pos_x;
+  (*o_pos_y)= (*i_image).m_box.m_pos_y;
 
   return;
 }
 
+extern void
+item_image_get_rotation(
+  double*const                          o_rotation,
+  struct item_image const*const         i_image)
+{
+
+  (*o_rotation)= 0.0;
+
+  return;
+}
+
+extern void
+item_image_get_size(
+  double*const                          o_len_x,
+  double*const                          o_len_y,
+  struct item_image const*const         i_image)
+{
+
+  (*o_len_x)= (*i_image).m_box.m_len_x;
+  (*o_len_y)= (*i_image).m_box.m_len_y;
+
+  return;
+}
+
+extern void
+item_image_get_shear(
+  double*const                          o_shear_x,
+  double*const                          o_shear_y,
+  struct item_image const*const         i_image)
+{
+  
+  (*o_shear_x)= 0.0;
+  (*o_shear_y)= 0.0;
+
+  return;
+}
+
+extern int
+item_image_in_event(
+  struct item_image const*const         i_image,
+  cairo_t*                              io_cr,
+  struct item_in_event const*const      i_ctx)
+{
+  int                                   l_hit;
+  struct item_transform                 l_transform;
+
+  memset(&l_transform, 0, sizeof(l_transform));
+
+  l_hit= item_common_box_in_event(io_cr, &(*i_image).m_box, &l_transform, i_ctx);
+
+  return l_hit;
+}
+
 extern int
 item_image_load(
   GError**                              o_error,
@@ -206,8 +280,8 @@ item_image_load(
 
     (*io_image).m_image_sized= gdk_pixbuf_scale_simple(
       (*io_image).m_image,
-      (*io_image).m_len_x,
-      (*io_image).m_len_y,
+      (*io_image).m_box.m_len_x,
+      (*io_image).m_box.m_len_y,
       GDK_INTERP_BILINEAR);
 
   }while(0);
@@ -225,21 +299,16 @@ item_image_move(
   struct item_image*const               io_image,
   struct geom_point const*const         i_event)
 {
-  item_common_box_move((struct geom_rect*)io_image, i_event);
+  item_common_box_move(&(*io_image).m_box, i_event);
   return;
 }
 
 extern void
 item_image_normalize(
-  struct item_image*const               io_image,
-  double const                          i_bound_width,
-  double const                          i_bound_height)
+  struct item_image*const               io_image)
 {
 
-  item_common_box_normalize(
-    (struct geom_rect*)io_image, 
-    i_bound_width,
-    i_bound_height);
+  item_common_box_normalize(&(*io_image).m_box);
 
   do
   {
@@ -257,8 +326,8 @@ item_image_normalize(
 
     (*io_image).m_image_sized= gdk_pixbuf_scale_simple(
       (*io_image).m_image,
-      (*io_image).m_len_x,
-      (*io_image).m_len_y,
+      (*io_image).m_box.m_len_x,
+      (*io_image).m_box.m_len_y,
       GDK_INTERP_BILINEAR);
 
   }while(0);
@@ -266,6 +335,49 @@ item_image_normalize(
   return;
 }
 
+extern void
+item_image_set_position(
+  struct item_image*const               io_image,
+  double const                          i_pos_x,
+  double const                          i_pos_y)
+{
+
+  (*io_image).m_box.m_pos_x= i_pos_x;
+  (*io_image).m_box.m_pos_y= i_pos_y;
+
+  return;
+}
+
+extern void
+item_image_set_rotation(
+  struct item_image*const               io_image,
+  double                                i_rotation)
+{
+  return;
+}
+
+extern void
+item_image_set_size(
+  struct item_image*const               io_image,
+  double                                i_len_x,
+  double                                i_len_y)
+{
+
+  (*io_image).m_box.m_len_x= i_len_x;
+  (*io_image).m_box.m_len_y= i_len_y;
+
+  return;
+}
+
+extern void
+item_image_set_shear(
+  struct item_image*const               io_image,
+  double const                          i_shear_x,
+  double const                          i_shear_y)
+{
+  return;
+}
+
 extern int
 item_image_read(
   GError**                              o_error,
@@ -277,7 +389,6 @@ item_image_read(
   int                                   l_found;
   GList*                                l_node;
   enum element_tag_type                 l_type;
-  char const*                           l_value;
   struct xml*                           l_xml;
 
   l_error= 0;
@@ -297,26 +408,16 @@ item_image_read(
 
     item_common_lookup(&l_found, &l_type, (*l_xml).m_tag);
     g_strstrip((*l_xml).m_string->str);
-    l_value= (*l_xml).m_string->str;
 
     if (l_found)
     {
       switch(l_type)
       {
-        case element_tag_pos_x:
-          (*io_image).m_pos_x= xml_convert_double(l_value);
-          break;
-        case element_tag_pos_y:
-          (*io_image).m_pos_y= xml_convert_double(l_value);
-          break;
-        case element_tag_len_x:
-          (*io_image).m_len_x= xml_convert_double(l_value);
-          break;
-        case element_tag_len_y:
-          (*io_image).m_len_y= xml_convert_double(l_value);
+        case element_tag_rect:
+          item_common_box_read(&l_error, &(*io_image).m_box, l_xml);
           break;
         case element_tag_border:
-          l_exit= item_common_read_border_attr(&l_error, &(*io_image).m_border, l_xml);
+          l_exit= item_common_read_border(&l_error, &(*io_image).m_border, l_xml);
           break;
         case element_tag_data:
           l_exit= pixbuf_read(&l_error, &(*io_image).m_image, l_xml);
@@ -333,8 +434,8 @@ item_image_read(
   {
     (*io_image).m_image_sized= gdk_pixbuf_scale_simple(
       (*io_image).m_image,
-      (*io_image).m_len_x,
-      (*io_image).m_len_y,
+      (*io_image).m_box.m_len_x,
+      (*io_image).m_box.m_len_y,
       GDK_INTERP_BILINEAR);
   }
 
@@ -351,29 +452,42 @@ item_image_resize(
   struct item_image*const               io_image,
   struct item_resize_event const*const  i_ctx)
 {
+  struct item_transform                 l_transform;
 
-  item_common_box_resize((struct geom_rect *)io_image, i_ctx);
+  memset(&l_transform, 0, sizeof(l_transform));
+  item_common_box_resize(&(*io_image).m_box, i_ctx, &l_transform);
 
   return;
 }
 
+extern void
+item_image_rotate(
+  struct item_image*const               io_image,
+  double const                          i_rotation)
+{
+}
+  
+extern void
+item_image_shear(
+  struct item_image*const               io_image,
+  double const                          i_delta_x,
+  double const                          i_delta_y)
+{
+}
+
 extern int
 item_image_write(
   GError**                              o_error,
   FILE*const                            io_fp,
   struct item_image const*const         i_image)
 {
-  char                                  l_buf[G_ASCII_DTOSTR_BUF_SIZE+1];
   int                                   l_exit;
 
   l_exit= 0;
 
   fprintf(io_fp, "\t\t\t<item name=\"image\">\n");
-  fprintf(io_fp, "\t\t\t\t<pos_x>%s</pos_x>\n", g_ascii_dtostr(l_buf, sizeof(l_buf), (*i_image).m_pos_x));
-  fprintf(io_fp, "\t\t\t\t<pos_y>%s</pos_y>\n", g_ascii_dtostr(l_buf, sizeof(l_buf), (*i_image).m_pos_y));
-  fprintf(io_fp, "\t\t\t\t<len_x>%s</len_x>\n", g_ascii_dtostr(l_buf, sizeof(l_buf), (*i_image).m_len_x));
-  fprintf(io_fp, "\t\t\t\t<len_y>%s</len_y>\n", g_ascii_dtostr(l_buf, sizeof(l_buf), (*i_image).m_len_y));
-  item_common_write_border_attr(o_error, io_fp, &(*i_image).m_border);
+  item_common_box_write(o_error, io_fp, &(*i_image).m_box);
+  item_common_write_border(o_error, io_fp, &(*i_image).m_border);
 
   if ((*i_image).m_image)
   {
