@@ -36,11 +36,8 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 struct item_image
 {
-  gdouble                               m_pos_x;
-  gdouble                               m_pos_y;
-  gdouble                               m_len_x;
-  gdouble                               m_len_y;
-  struct item_border_attr               m_border;
+  struct geom_rect                      m_box;
+  struct item_border               m_border;
   GdkPixbuf *                           m_image;
   GdkPixbuf *                           m_image_sized;
 };
@@ -51,15 +48,9 @@ item_image_assign(
   struct item_method*const              o_method);
 
 extern void
-item_image_get_bbox(
-  struct geom_rect*const                o_bbox,
-  void const*const                      i_object);
-
-extern void
-item_image_in_event(
-  enum event_type*const                 o_type,
-  struct item_image const*const         i_image,
-  struct item_in_event const*const      i_ctx);
+item_image_copy(
+  struct item_image *const              o_image,
+  struct item_image const*const         i_image);
 
 extern void
 item_image_destroy(
@@ -74,6 +65,43 @@ item_image_draw(
   struct item_image*const               io_image,
   struct item_draw_context const*const  i_ctx);
 
+extern void
+item_image_get_bbox(
+  struct geom_rect*const                o_bbox,
+  cairo_t*                              io_cr,
+  double const                          i_scale,
+  struct item_image const*const         i_image);
+
+extern void
+item_image_get_position(
+  double*const                          o_pos_x,
+  double*const                          o_pos_y,
+  struct item_image const*const         i_image);
+
+extern void
+item_image_get_rotation(
+  double*const                          o_rotation,
+  struct item_image const*const         i_image);
+
+extern void
+item_image_get_size(
+  double*const                          o_len_x,
+  double*const                          o_len_y,
+  struct item_image const*const         i_image);
+
+extern void
+item_image_get_shear(
+  double*const                          o_shear_x,
+  double*const                          o_shear_y,
+  struct item_image const*const         i_image);
+
+
+extern int
+item_image_in_event(
+  struct item_image const*const         i_image,
+  cairo_t*                              io_cr,
+  struct item_in_event const*const      i_ctx);
+
 extern int
 item_image_load(
   GError**                              o_error,
@@ -87,9 +115,30 @@ item_image_move(
 
 extern void
 item_image_normalize(
+  struct item_image*const               io_image);
+
+extern void
+item_image_set_position(
   struct item_image*const               io_image,
-  double const                          i_bound_width,
-  double const                          i_bound_height);
+  double const                          i_pos_x,
+  double const                          i_pos_y);
+
+extern void
+item_image_set_rotation(
+  struct item_image*const               io_image,
+  double                                i_rotation);
+
+extern void
+item_image_set_size(
+  struct item_image*const               io_image,
+  double                                i_len_x,
+  double                                i_len_y);
+
+extern void
+item_image_set_shear(
+  struct item_image*const               io_image,
+  double const                          i_shear_x,
+  double const                          i_shear_y);
 
 extern int
 item_image_property(
@@ -99,13 +148,24 @@ extern int
 item_image_read(
   GError**                              o_error,
   struct item_image*const               io_image,
-  struct xml *const               i_element);
+  struct xml *const                     i_element);
 
 extern void
 item_image_resize(
   struct item_image*const               io_image,
   struct item_resize_event const*const  i_ctx);
 
+extern void
+item_image_rotate(
+  struct item_image*const               io_image,
+  double const                          i_rotation);
+  
+extern void
+item_image_shear(
+  struct item_image*const               io_image,
+  double const                          i_delta_x,
+  double const                          i_delta_y);
+
 extern int
 item_image_write(
   GError**                              o_error,
