@@ -29,6 +29,7 @@ NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 #include "item_image.h"
+#include "item_property.h"
 
 struct image_dialog
 {
@@ -40,57 +41,6 @@ struct image_dialog
   GtkEntry*                             m_filename_entry;
 };
 
-static void
-item_image_border_color_button_cb(
-  GtkWidget *                           i_widget,
-  gpointer                              i_data)
-{
-  GdkRGBA                               l_color;
-  GtkWidget*                            l_dialog;
-  int                                   l_exit;
-  struct image_dialog*                  l_image;
-  gchar*                                l_rgba;
-  gchar const*                          l_text;
-
-  l_dialog= 0;
-  memset(&l_color, 0, sizeof(l_color));
-
-  do
-  {
-
-    l_image= (struct image_dialog*)i_data;
-
-    l_dialog= gtk_color_chooser_dialog_new("Border Color", get_main_window());
-
-    l_text= gtk_entry_get_text((*l_image).m_border_color_entry);
-    gdk_rgba_parse(&l_color, l_text);
-    gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(l_dialog), &l_color);
-
-    gtk_window_set_modal((GtkWindow*)l_dialog, 1);
-
-    l_exit= gtk_dialog_run(GTK_DIALOG(l_dialog));
-
-    if (GTK_RESPONSE_OK != l_exit)
-    {
-      break;
-    }
-
-    gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(l_dialog), &l_color);
-
-    l_rgba= gdk_rgba_to_string(&l_color);
-    gtk_entry_set_text((*l_image).m_border_color_entry, l_rgba);
-    g_free(l_rgba);
-
-  }while(0);
-
-  if (l_dialog)
-  {
-    gtk_widget_destroy((GtkWidget*)l_dialog);
-  }
-  
-  return;
-}
-
 static void
 item_file_button_cb(
   GtkWidget *                           i_widget,
@@ -98,8 +48,8 @@ item_file_button_cb(
 {
   GtkFileChooser*                       l_chooser;
   GtkWidget*                            l_dialog;
+  struct image_dialog*                  l_dlg;
   GtkFileFilter*                        l_filter;
-  struct image_dialog*                  l_imaged;
   char*                                 l_imagefile;
   int                                   l_rc;
 
@@ -109,7 +59,7 @@ item_file_button_cb(
   do
   {
 
-    l_imaged= (struct image_dialog*)i_data;
+    l_dlg= (struct image_dialog*)i_data;
 
     l_dialog = gtk_file_chooser_dialog_new(
       "Open Image",
@@ -140,7 +90,7 @@ item_file_button_cb(
     }
 
     l_imagefile= gtk_file_chooser_get_filename(l_chooser);
-    gtk_entry_set_text ((*l_imaged).m_filename_entry, l_imagefile);
+    gtk_entry_set_text ((*l_dlg).m_filename_entry, l_imagefile);
 
   }while(0);
 
@@ -159,41 +109,41 @@ item_file_button_cb(
 
 static void
 item_image_bind(
-  struct image_dialog*const             o_image,
+  struct image_dialog*const             o_dlg,
   GtkBuilder*const                      i_builder)
 {
   GtkButton*                            l_button;
 
-  memset(o_image, 0, sizeof(*o_image));
+  memset(o_dlg, 0, sizeof(*o_dlg));
 
   do
   {
 
-    (*o_image).m_border_color_entry=
+    (*o_dlg).m_border_color_entry=
       GTK_ENTRY(gtk_builder_get_object(i_builder, "color_entry"));
 
-    (*o_image).m_border_checkbutton=
+    (*o_dlg).m_border_checkbutton=
       GTK_CHECK_BUTTON(gtk_builder_get_object(i_builder, "border_checkbutton"));
 
-    (*o_image).m_border_style_comboboxtext=
+    (*o_dlg).m_border_style_comboboxtext=
       GTK_COMBO_BOX_TEXT(gtk_builder_get_object(i_builder, "border_style_comboboxtext"));
 
-    (*o_image).m_border_thickness_spinbutton=
+    (*o_dlg).m_border_thickness_spinbutton=
       GTK_SPIN_BUTTON(gtk_builder_get_object(i_builder, "border_thickness_spinbutton"));
 
-    (*o_image).m_border_color_entry=
+    (*o_dlg).m_border_color_entry=
       GTK_ENTRY(gtk_builder_get_object(i_builder, "border_color_entry"));
 
-    (*o_image).m_border_color_button=
+    (*o_dlg).m_border_color_button=
       GTK_BUTTON(gtk_builder_get_object(i_builder, "border_color_button"));
 
     g_signal_connect(
-      (*o_image).m_border_color_button,
+      (*o_dlg).m_border_color_button,
       "clicked",
-      G_CALLBACK(item_image_border_color_button_cb),
-      o_image);
+      G_CALLBACK(item_property_border_color_button_cb),
+      (*o_dlg).m_border_color_entry);
 
-    (*o_image).m_filename_entry=
+    (*o_dlg).m_filename_entry=
       GTK_ENTRY(gtk_builder_get_object(i_builder, "filename_entry"));
 
     l_button= 
@@ -203,7 +153,7 @@ item_image_bind(
       l_button,
       "clicked",
       G_CALLBACK(item_file_button_cb),
-      o_image);
+      o_dlg);
 
   }while(0);
 
@@ -212,25 +162,25 @@ item_image_bind(
 
 static void
 item_image_set_values(
-  struct image_dialog*const             i_imaged,
-  struct item_image const*const         i_image)
+  struct image_dialog*const             io_dlg,
+  struct item_image const*const         i_object)
 {
   gchar *                               l_color;
 
   gtk_toggle_button_set_active(
-    GTK_TOGGLE_BUTTON((*i_imaged).m_border_checkbutton),
-    (*i_image).m_border.m_active);
+    GTK_TOGGLE_BUTTON((*io_dlg).m_border_checkbutton),
+    (*i_object).m_border.m_active);
 
   gtk_combo_box_set_active(
-      GTK_COMBO_BOX((*i_imaged).m_border_style_comboboxtext), 
-      (*i_image).m_border.m_style);
+      GTK_COMBO_BOX((*io_dlg).m_border_style_comboboxtext), 
+      (*i_object).m_border.m_style);
 
   gtk_spin_button_set_value(
-    GTK_SPIN_BUTTON((*i_imaged).m_border_thickness_spinbutton),
-    (*i_image).m_border.m_thickness);
+    GTK_SPIN_BUTTON((*io_dlg).m_border_thickness_spinbutton),
+    (*i_object).m_border.m_thickness);
 
-  l_color= gdk_rgba_to_string(&(*i_image).m_border.m_color);
-  gtk_entry_set_text((*i_imaged).m_border_color_entry, l_color);
+  l_color= gdk_rgba_to_string(&(*i_object).m_border.m_color);
+  gtk_entry_set_text((*io_dlg).m_border_color_entry, l_color);
   g_free(l_color);
   l_color= 0;
 
@@ -239,8 +189,8 @@ item_image_set_values(
 
 static void
 item_image_copy_values(
-  struct item_image *const              io_image,
-  struct image_dialog const*const       i_imaged)
+  struct item_image *const              io_object,
+  struct image_dialog const*const       i_dlg)
 {
   GtkDialog*                            l_dialog;
   GError*                               l_error;
@@ -248,33 +198,33 @@ item_image_copy_values(
   gchar const*                          l_text;
 
   l_error= 0;
-  (*io_image).m_border.m_active=
+  (*io_object).m_border.m_active=
     gtk_toggle_button_get_active(
-      GTK_TOGGLE_BUTTON((*i_imaged).m_border_checkbutton));
+      GTK_TOGGLE_BUTTON((*i_dlg).m_border_checkbutton));
 
   l_rc = gtk_combo_box_get_active(
-    GTK_COMBO_BOX((*i_imaged).m_border_style_comboboxtext));
+    GTK_COMBO_BOX((*i_dlg).m_border_style_comboboxtext));
 
-  if ((0 <= l_rc) && (LINE_STYLE_SLOTS > l_rc))
+  if ((0 <= l_rc) && (line_style_last > l_rc))
   {
-    (*io_image).m_border.m_style= (enum line_style_type)l_rc;
+    (*io_object).m_border.m_style= (enum line_style_type)l_rc;
   }
   else
   {
-    (*io_image).m_border.m_style= line_style_solid;
+    (*io_object).m_border.m_style= line_style_solid;
   }
 
-  l_text= gtk_entry_get_text(GTK_ENTRY((*i_imaged).m_border_color_entry));
-  gdk_rgba_parse(&(*io_image).m_border.m_color, l_text);
+  l_text= gtk_entry_get_text(GTK_ENTRY((*i_dlg).m_border_color_entry));
+  gdk_rgba_parse(&(*io_object).m_border.m_color, l_text);
 
-  (*io_image).m_border.m_thickness= gtk_spin_button_get_value(
-    GTK_SPIN_BUTTON((*i_imaged).m_border_thickness_spinbutton));
+  (*io_object).m_border.m_thickness= gtk_spin_button_get_value(
+    GTK_SPIN_BUTTON((*i_dlg).m_border_thickness_spinbutton));
 
-  l_text= gtk_entry_get_text(GTK_ENTRY((*i_imaged).m_filename_entry));
+  l_text= gtk_entry_get_text(GTK_ENTRY((*i_dlg).m_filename_entry));
 
   if (l_text && l_text[0])
   {
-    item_image_load(&l_error, io_image, l_text);
+    item_image_load(&l_error, io_object, l_text);
   }
 
   if (l_error)
@@ -297,15 +247,15 @@ item_image_copy_values(
 
 extern int
 item_image_property(
-  struct item_image*const               io_image)
+  struct item_image*const               io_object)
 {
   GtkBox*                               l_box;
   GtkBuilder*                           l_builder;
   GtkDialog*                            l_dialog;
+  struct image_dialog                   l_dlg;
   GError*                               l_error;
   int                                   l_exit;
   GtkGrid*                              l_grid;
-  struct image_dialog                   l_image;
   int                                   l_rc;
 
   l_builder= 0;
@@ -339,9 +289,9 @@ item_image_property(
       break;
     }
 
-    item_image_bind(&l_image, l_builder);
+    item_image_bind(&l_dlg, l_builder);
 
-    item_image_set_values(&l_image, io_image);
+    item_image_set_values(&l_dlg, io_object);
 
     l_dialog= GTK_DIALOG(gtk_dialog_new_with_buttons(
       "Image Edit",
@@ -368,7 +318,7 @@ item_image_property(
       break;
     }
 
-    item_image_copy_values(io_image, &l_image);
+    item_image_copy_values(io_object, &l_dlg);
 
   }while(0);
 
