@@ -42,7 +42,6 @@ item_line_assign(
   (*o_line).m_pos_y1= 10.0;
   (*o_line).m_pos_x2= 100.0;
   (*o_line).m_pos_y2= 10.0;
-  (*o_line).m_style= line_style_solid;
   (*o_line).m_thickness= 1;
   (*o_line).m_color.alpha= 1.0;
 
@@ -51,6 +50,17 @@ item_line_assign(
   return;
 }
 
+extern void
+item_line_copy(
+  struct item_line *const               o_line,
+  struct item_line const*const          i_line)
+{
+
+  memcpy(o_line, i_line, sizeof(*i_line));
+
+  return;
+}
+
 extern void
 item_line_discharge(
   struct item_line*const                io_line)
@@ -64,70 +74,32 @@ item_line_draw(
   struct item_draw_context const*const  i_ctx)
 {
 
-  do
+  cairo_new_path((*i_ctx).m_cr);
+  cairo_save((*i_ctx).m_cr);
+  cairo_scale((*i_ctx).m_cr, (*i_ctx).m_scale, (*i_ctx).m_scale);
+
+  cairo_set_source_rgba(
+    (*i_ctx).m_cr,
+    (*i_line).m_color.red,
+    (*i_line).m_color.green,
+    (*i_line).m_color.blue,
+    (*i_line).m_color.alpha);
+
+  item_common_cairo_dash_set((*i_ctx).m_cr, (*i_line).m_style);
+  cairo_set_line_width((*i_ctx).m_cr, (*i_line).m_thickness);
+
+  cairo_move_to((*i_ctx).m_cr, (*i_line).m_pos_x1, (*i_line).m_pos_y1);
+  cairo_line_to((*i_ctx).m_cr, (*i_line).m_pos_x2, (*i_line).m_pos_y2);
+  cairo_stroke((*i_ctx).m_cr);
+
+  if ((*i_line).m_double_line)
   {
-
-    cairo_set_source_rgba(
-      (*i_ctx).m_cr,
-      (*i_line).m_color.red,
-      (*i_line).m_color.green,
-      (*i_line).m_color.blue,
-      (*i_line).m_color.alpha);
-
-    item_common_cairo_dash_set((*i_ctx).m_cr, (*i_line).m_style);
-    cairo_set_line_width((*i_ctx).m_cr, (*i_line).m_thickness);
-
-    cairo_move_to((*i_ctx).m_cr, (*i_line).m_pos_x1, (*i_line).m_pos_y1);
-    cairo_line_to((*i_ctx).m_cr, (*i_line).m_pos_x2, (*i_line).m_pos_y2);
+    cairo_move_to((*i_ctx).m_cr, (*i_line).m_pos_x1, 3.00+(*i_line).m_pos_y1);
+    cairo_line_to((*i_ctx).m_cr, (*i_line).m_pos_x2, 3.00+(*i_line).m_pos_y2);
     cairo_stroke((*i_ctx).m_cr);
+  }
 
-    if ((*i_line).m_double_line)
-    {
-      switch((*i_line).m_type)
-      {
-        case line_type_horizontal:
-          cairo_move_to((*i_ctx).m_cr, (*i_line).m_pos_x1, 3.00+(*i_line).m_pos_y1);
-          cairo_line_to((*i_ctx).m_cr, (*i_line).m_pos_x2, 3.00+(*i_line).m_pos_y2);
-          cairo_stroke((*i_ctx).m_cr);
-          break;
-        case line_type_vertical:
-          cairo_move_to((*i_ctx).m_cr, 3.00+(*i_line).m_pos_x1, (*i_line).m_pos_y1);
-          cairo_line_to((*i_ctx).m_cr, 3.00+(*i_line).m_pos_x2, (*i_line).m_pos_y2);
-          cairo_stroke((*i_ctx).m_cr);
-          break;
-        case line_type_diagonal:
-          cairo_move_to((*i_ctx).m_cr, 3.00+(*i_line).m_pos_x1, 3.00+(*i_line).m_pos_y1);
-          cairo_line_to((*i_ctx).m_cr, 3.00+(*i_line).m_pos_x2, 3.00+(*i_line).m_pos_y2);
-          cairo_stroke((*i_ctx).m_cr);
-        default:
-          break;
-      }
-    }
-
-    if (0 == (*i_ctx).m_selected)
-    {
-      break;
-    }
-
-    cairo_set_source_rgb((*i_ctx).m_cr, 0.0, 1.0, 0.0);
-
-    cairo_rectangle(
-      (*i_ctx).m_cr,
-      (*i_line).m_pos_x1-4,
-      (*i_line).m_pos_y1-4,
-      8,
-      8);
-    cairo_fill((*i_ctx).m_cr);
-
-    cairo_rectangle(
-      (*i_ctx).m_cr,
-      (*i_line).m_pos_x2-4,
-      (*i_line).m_pos_y2-4,
-      8,
-      8);
-    cairo_fill((*i_ctx).m_cr);
-
-  }while(0);
+  cairo_restore((*i_ctx).m_cr);
 
   return;
 }
@@ -135,122 +107,82 @@ item_line_draw(
 extern void
 item_line_get_bbox(
   struct geom_rect*const                o_bbox,
+  cairo_t*                              io_cr,
+  double const                          i_scale,
   void const*const                      i_object)
 {
   struct item_line const*               l_line;
 
   l_line= (struct item_line const*)i_object;
-  (*o_bbox).m_pos_x= (*l_line).m_pos_x1;
-  (*o_bbox).m_pos_y= (*l_line).m_pos_y1;
-  (*o_bbox).m_len_x= (*l_line).m_pos_x2 - (*l_line).m_pos_x1;
-  (*o_bbox).m_len_y= (int)(*l_line).m_thickness;
+  (*o_bbox).m_pos_x= i_scale * (*l_line).m_pos_x1;
+  (*o_bbox).m_pos_y= i_scale * (*l_line).m_pos_y1;
+  (*o_bbox).m_len_x= i_scale * ((*l_line).m_pos_x2 - (*l_line).m_pos_x1);
+  (*o_bbox).m_len_y= i_scale * ((*l_line).m_pos_y2 - (*l_line).m_pos_y1);
 
   return;
 }
 
-static int
-item_line_in_event_grips(
-  enum event_type*const                 o_type,
-  struct item_line const*const          i_line,
-  struct item_in_event const*const      i_ctx)
-{
-  int                                   l_hit;
-
-  l_hit= 0;
-
-  do
-  {
-
-    l_hit= item_common_event_inside(
-      i_ctx,
-      (*i_line).m_pos_x1-4,
-      (*i_line).m_pos_y1-4,
-      8,
-      8);
-
-    if (l_hit)
-    {
-      if (line_type_horizontal == (*i_line).m_type)
-      {
-        (*o_type)= event_resize_west;
-      }
-      else if (line_type_vertical == (*i_line).m_type)
-      {
-        (*o_type)= event_resize_north;
-      }
-      else
-      {
-        (*o_type)= event_resize_north_west;
-      }
-      break;
-    }
-    
-    l_hit= item_common_event_inside(
-      i_ctx,
-      (*i_line).m_pos_x2-4,
-      (*i_line).m_pos_y2-4,
-      8,
-      8);
-
-    if (l_hit)
-    {
-      if (line_type_horizontal == (*i_line).m_type)
-      {
-        (*o_type)= event_resize_east;
-      }
-      else if (line_type_vertical == (*i_line).m_type)
-      {
-       (*o_type)= event_resize_south;
-      }
-      else
-      {
-        (*o_type)= event_resize_south_east;
-      }
-      break;
-    }
-
-  }while(0);
-
-  return l_hit;
-}
-
 extern void
+item_line_get_position(
+  double*const                          o_pos_x,
+  double*const                          o_pos_y,
+  struct item_line const*const          i_line)
+{
+
+  (*o_pos_x)= (*i_line).m_pos_x1;
+  (*o_pos_y)= (*i_line).m_pos_y1;
+
+  return;
+}
+
+extern void
+item_line_get_rotation(
+  double*const                          o_rotation,
+  struct item_line const*const          i_line)
+{
+
+  (*o_rotation)= 0.0;
+
+  return;
+}
+
+extern void
+item_line_get_size(
+  double*const                          o_len_x,
+  double*const                          o_len_y,
+  struct item_line const*const          i_line)
+{
+
+  (*o_len_x)= (*i_line).m_pos_x2 - (*i_line).m_pos_x1;
+  (*o_len_y)= (*i_line).m_pos_y2 - (*i_line).m_pos_y1;
+
+  return;
+}
+
+extern void
+item_line_get_shear(
+  double*const                          o_shear_x,
+  double*const                          o_shear_y,
+  struct item_line const*const          i_line)
+{
+  
+  (*o_shear_x)= 0.0;
+  (*o_shear_y)= 0.0;
+
+  return;
+}
+
+extern int
 item_line_in_event(
-  enum event_type*const                 o_type,
   struct item_line const*const          i_line,
+  cairo_t*                              io_cr,
   struct item_in_event const*const      i_ctx)
 {
   int                                   l_hit;
 
-  l_hit= 0;
+  l_hit= item_common_line_in_event(i_ctx, io_cr, (struct geom_line*)i_line);
 
-  do
-  {
-
-    (*o_type)= event_none;
-
-    l_hit= item_common_line_in_event(i_ctx, (struct geom_line*)i_line);
-
-    if (0 == l_hit)
-    {
-      break;
-    }
-
-    if ((*i_ctx).m_selected)
-    {
-      l_hit= item_line_in_event_grips(o_type, i_line, i_ctx);
-
-      if (l_hit)
-      {
-        break;
-      }
-    }
-
-    (*o_type)= event_move;
-
-  }while(0);
-
-  return;
+  return l_hit;
 }
 
 extern void
@@ -269,68 +201,72 @@ item_line_move(
 
 extern void
 item_line_normalize(
-  struct item_line*const                io_line,
-  double const                          i_bound_width,
-  double const                          i_bound_height)
+  struct item_line*const                io_line)
 {
   gdouble                               l_swap;
 
   do
   {
 
-    if (line_type_diagonal == (*io_line).m_type)
-    {
-      break;
-    }
-
     if ((*io_line).m_pos_x1 > (*io_line).m_pos_x2)
     {
       l_swap= (*io_line).m_pos_x1;
       (*io_line).m_pos_x1= (*io_line).m_pos_x2;
       (*io_line).m_pos_x2= l_swap;
-    }
 
-    if ((*io_line).m_pos_y1 > (*io_line).m_pos_y2)
-    {
       l_swap= (*io_line).m_pos_y1;
       (*io_line).m_pos_y1= (*io_line).m_pos_y2;
       (*io_line).m_pos_y2= l_swap;
     }
 
-
-    if (0 > (int)(*io_line).m_pos_x2)
-    {
-      l_swap= (*io_line).m_pos_x2 - (*io_line).m_pos_x1;
-      (*io_line).m_pos_x2= 2.0;
-      (*io_line).m_pos_x1= (*io_line).m_pos_x2 - l_swap;
-    }
-
-    if (0 > (int)(*io_line).m_pos_y2)
-    {
-      l_swap= (*io_line).m_pos_y2 - (*io_line).m_pos_y1;
-      (*io_line).m_pos_y1= 2.0 - l_swap;
-      (*io_line).m_pos_y2= (*io_line).m_pos_y1 + l_swap;
-    }
-
-    if (i_bound_width < (int)(*io_line).m_pos_x1)
-    {
-      l_swap= (*io_line).m_pos_x2 - (*io_line).m_pos_x1;
-      (*io_line).m_pos_x1= i_bound_width - 2.0;
-      (*io_line).m_pos_x2= (*io_line).m_pos_x1 + l_swap;
-    }
-
-    if (i_bound_height < (int)(*io_line).m_pos_y1)
-    {
-      l_swap= (*io_line).m_pos_y2 - (*io_line).m_pos_y1;
-      (*io_line).m_pos_y1= i_bound_height - 2.0;
-      (*io_line).m_pos_y2= (*io_line).m_pos_y1 + l_swap;
-    }
-
   }while(0);
 
   return;
 }
 
+extern void
+item_line_set_position(
+  struct item_line*const                io_line,
+  double const                          i_pos_x,
+  double const                          i_pos_y)
+{
+
+  (*io_line).m_pos_x1= i_pos_x;
+  (*io_line).m_pos_y1= i_pos_y;
+
+  return;
+}
+
+extern void
+item_line_set_rotation(
+  struct item_line*const                io_line,
+  double                                i_rotation)
+{
+  return;
+}
+
+extern void
+item_line_set_size(
+  struct item_line*const                io_line,
+  double                                i_len_x,
+  double                                i_len_y)
+{
+
+  (*io_line).m_pos_x2= (*io_line).m_pos_x1 + i_len_x;
+  (*io_line).m_pos_y2= (*io_line).m_pos_y1 + i_len_y;
+
+  return;
+}
+
+extern void
+item_line_set_shear(
+  struct item_line*const                io_line,
+  double const                          i_shear_x,
+  double const                          i_shear_y)
+{
+  return;
+}
+
 extern int
 item_line_read(
   GError**                              o_error,
@@ -395,24 +331,6 @@ item_line_read(
             (*io_line).m_color= l_rgba;
           }
           break;
-        case element_tag_type:
-          (*io_line).m_type= line_type_horizontal;
-          do
-          {
-            l_rc= strcmp("vertical", l_value);
-            if (0 == l_rc)
-            {
-              (*io_line).m_type= line_type_vertical;
-              break;
-            }
-            l_rc= strcmp("diagonal", l_value);
-            if (0 == l_rc)
-            {
-              (*io_line).m_type= line_type_diagonal;
-              break;
-            }
-          }while(0);
-          break;
         case element_tag_doubleline:
           l_value= xml_lookup_attribute_value(l_xml, "on");
           (*io_line).m_double_line= xml_convert_boolean(l_value);
@@ -439,36 +357,66 @@ item_line_resize(
   struct item_line*const                io_line,
   struct item_resize_event const*const  i_ctx)
 {
+  enum event_type                       l_type;
+
+  l_type= (*i_ctx).m_type;
+
+  if ((*io_line).m_pos_y1 > (*io_line).m_pos_y2)
+  {
+    switch(l_type)
+    {
+      case event_resize_north:
+        l_type= event_resize_south;
+        break;
+      case event_resize_south:
+        l_type= event_resize_north;
+        break;
+      case event_resize_north_west:
+        l_type= event_resize_south_west;
+        break;
+      case event_resize_north_east:
+        l_type= event_resize_south_east;
+        break;
+      case event_resize_south_east:
+        l_type= event_resize_north_east;
+        break;
+      case event_resize_south_west:
+        l_type= event_resize_north_west;
+        break; 
+      default:
+        break;
+    }
+  }
   
-  switch((*i_ctx).m_type)
+  switch(l_type)
   {
     case event_resize_east:
-      (*io_line).m_pos_x2+= (*i_ctx).m_event.m_pos_x;
+      (*io_line).m_pos_x2+= (*i_ctx).m_delta_x;
       break;
     case event_resize_north:
-      (*io_line).m_pos_y1+= (*i_ctx).m_event.m_pos_y;
+      (*io_line).m_pos_y1+= (*i_ctx).m_delta_y;
       break;
     case event_resize_north_east:
-      (*io_line).m_pos_y1+= (*i_ctx).m_event.m_pos_y;
-      (*io_line).m_pos_x2+= (*i_ctx).m_event.m_pos_x;
+      (*io_line).m_pos_y1+= (*i_ctx).m_delta_y;
+      (*io_line).m_pos_x2+= (*i_ctx).m_delta_x;
       break;
     case event_resize_north_west:
-      (*io_line).m_pos_y1+= (*i_ctx).m_event.m_pos_y;
-      (*io_line).m_pos_x1+= (*i_ctx).m_event.m_pos_x;
+      (*io_line).m_pos_y1+= (*i_ctx).m_delta_y;
+      (*io_line).m_pos_x1+= (*i_ctx).m_delta_x;
       break;
     case event_resize_south:
-      (*io_line).m_pos_y2+= (*i_ctx).m_event.m_pos_y;
+      (*io_line).m_pos_y2+= (*i_ctx).m_delta_y;
       break;
     case event_resize_south_east:
-      (*io_line).m_pos_y2+= (*i_ctx).m_event.m_pos_y;
-      (*io_line).m_pos_x2+= (*i_ctx).m_event.m_pos_x;
+      (*io_line).m_pos_y2+= (*i_ctx).m_delta_y;
+      (*io_line).m_pos_x2+= (*i_ctx).m_delta_x;
       break;
     case event_resize_south_west:
-      (*io_line).m_pos_y2+= (*i_ctx).m_event.m_pos_y;
-      (*io_line).m_pos_x1+= (*i_ctx).m_event.m_pos_x;
+      (*io_line).m_pos_y2+= (*i_ctx).m_delta_y;
+      (*io_line).m_pos_x1+= (*i_ctx).m_delta_x;
       break;
     case event_resize_west:
-      (*io_line).m_pos_x1+= (*i_ctx).m_event.m_pos_x;
+      (*io_line).m_pos_x1+= (*i_ctx).m_delta_x;
       break;
     default:
       break;
@@ -477,6 +425,21 @@ item_line_resize(
   return;
 }
 
+extern void
+item_line_rotate(
+  struct item_line*const                io_line,
+  double const                          i_rotation)
+{
+}
+  
+extern void
+item_line_shear(
+  struct item_line*const                io_line,
+  double const                          i_delta_x,
+  double const                          i_delta_y)
+{
+}
+
 extern int
 item_line_write(
   GError**                              o_error,
@@ -499,23 +462,6 @@ item_line_write(
   g_free(l_text);
   fprintf(io_fp, "\t\t\t\t<style>%s</style>\n", item_common_get_line_style_text((*i_line).m_style));
   fprintf(io_fp, "\t\t\t\t<thickness>%s</thickness>\n", g_ascii_dtostr(l_buf, sizeof(l_buf), (*i_line).m_thickness));
-
-  switch((*i_line).m_type)
-  {
-    case line_type_horizontal:
-      l_text= "horizontal";
-      break;
-    case line_type_vertical:
-      l_text= "vertical";
-      break;
-    case line_type_diagonal:
-      l_text= "diagonal";
-      break;
-    default:
-      l_text= ""; 
-  }
-
-  fprintf(io_fp, "\t\t\t\t<type>%s</type>\n", l_text);
   fprintf(io_fp, "\t\t\t\t<double_line on=\"%s\"/>\n", ((*i_line).m_double_line ? "true" : "false"));
   fprintf(io_fp, "\t\t\t</item>\n");
 
