@@ -33,13 +33,6 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "item_common.h"
 #include "item_method.h"
 
-enum item_line_type
-{
-  line_type_horizontal,
-  line_type_vertical,
-  line_type_diagonal
-};
-
 struct item_line
 {
   gdouble                               m_pos_x1;
@@ -49,7 +42,6 @@ struct item_line
   enum line_style_type                  m_style;
   gdouble                               m_thickness;
   GdkRGBA                               m_color;
-  enum item_line_type                   m_type;
   gint                                  m_double_line;
 };
 
@@ -58,36 +50,51 @@ item_line_assign(
   struct item_line*const                o_line,
   struct item_method*const              o_method);
 
+extern void
+item_line_copy(
+  struct item_line *const               o_line,
+  struct item_line const*const          i_line);
+
+extern void
+item_line_discharge(
+  struct item_line*const                io_line);
+
 extern void
 item_line_get_bbox(
   struct geom_rect*const                o_bbox,
+  cairo_t*                              io_cr,
+  double const                          i_scale,
   void const*const                      i_object);
 
 extern void
+item_line_get_position(
+  double*const                          o_pos_x,
+  double*const                          o_pos_y,
+  struct item_line const*const          i_line);
+
+extern void
+item_line_get_rotation(
+  double*const                          o_rotation,
+  struct item_line const*const          i_line);
+
+extern void
+item_line_get_size(
+  double*const                          o_len_x,
+  double*const                          o_len_y,
+  struct item_line const*const          i_line);
+
+extern void
+item_line_get_shear(
+  double*const                          o_shear_x,
+  double*const                          o_shear_y,
+  struct item_line const*const          i_line);
+
+extern int
 item_line_in_event(
-  enum event_type*const                 o_type,
   struct item_line const*const          i_line,
+  cairo_t*                              io_cr,
   struct item_in_event const*const      i_ctx);
 
-extern void
-item_line_discharge(
-  struct item_line*const                io_line);
-
-extern void
-item_line_assign(
-  struct item_line*const                o_line,
-  struct item_method*const              o_method);
-
-extern void
-item_line_in_event(
-  enum event_type*const                 o_type,
-  struct item_line const*const          i_line,
-  struct item_in_event const*const i_ctx);
-
-extern void
-item_line_discharge(
-  struct item_line*const                io_line);
-
 extern void
 item_line_draw(
   struct item_line*const                io_line,
@@ -100,9 +107,30 @@ item_line_move(
 
 extern void
 item_line_normalize(
+  struct item_line*const                io_line);
+
+extern void
+item_line_set_position(
   struct item_line*const                io_line,
-  double const                          i_bound_width,
-  double const                          i_bound_height);
+  double const                          i_pos_x,
+  double const                          i_pos_y);
+
+extern void
+item_line_set_rotation(
+  struct item_line*const                io_line,
+  double                                i_rotation);
+
+extern void
+item_line_set_size(
+  struct item_line*const                io_line,
+  double                                i_len_x,
+  double                                i_len_y);
+
+extern void
+item_line_set_shear(
+  struct item_line*const                io_line,
+  double const                          i_shear_x,
+  double const                          i_shear_y);
 
 extern int
 item_line_property(
@@ -112,13 +140,24 @@ extern int
 item_line_read(
   GError**                              o_error,
   struct item_line*const                io_line,
-  struct xml *const               i_element);
+  struct xml *const                     i_element);
 
 extern void
 item_line_resize(
   struct item_line*const                io_line,
   struct item_resize_event const*const  i_ctx);
 
+extern void
+item_line_rotate(
+  struct item_line*const                io_line,
+  double const                          i_rotation);
+  
+extern void
+item_line_shear(
+  struct item_line*const                io_line,
+  double const                          i_delta_x,
+  double const                          i_delta_y);
+
 extern int
 item_line_write(
   GError**                              o_error,
