@@ -38,8 +38,8 @@ item_page_number_assign(
 
   memset(o_page_number, 0, sizeof(*o_page_number));
 
-  (*o_page_number).m_len_x= 30.0;
-  (*o_page_number).m_len_y= 18.0;
+  (*o_page_number).m_box.m_len_x= 30.0;
+  (*o_page_number).m_box.m_len_y= 18.0;
   (*o_page_number).m_font= pango_font_description_new();
   (*o_page_number).m_color.alpha= 1.0;
   (*o_page_number).m_border.m_style= line_style_solid;
@@ -52,11 +52,26 @@ item_page_number_assign(
   return;
 }
 
+extern void
+item_page_number_copy(
+  struct item_page_number *const        o_page_number,
+  struct item_page_number const*const   i_page_number)
+{
+
+  memcpy(o_page_number, i_page_number, sizeof((*o_page_number)));
+  (*o_page_number).m_font= pango_font_description_copy((*i_page_number).m_font);
+  (*o_page_number).m_page_number= 0;
+
+  return;
+}
+
 extern void
 item_page_number_discharge(
   struct item_page_number*const         io_page_number)
 {
 
+  g_free((*io_page_number).m_format);
+
   if ((*io_page_number).m_font)
   {
     pango_font_description_free((*io_page_number).m_font);
@@ -69,43 +84,32 @@ item_page_number_discharge(
 
 static void
 item_page_number_get_text(
-  char                                  o_text[1+SPECIAL_FIELD_VALUE_MAX_LEN],
+  char**                                o_text,
   struct item_page_number*const         i_page_number,
   struct item_draw_context const*const  i_ctx)
 {
-  char                                  l_format[1+FIELD_FORMAT_MAX_LEN];
+  char const*                           l_format;
   unsigned long                         l_page_number; 
 
-  memset(o_text, 0, 1+SPECIAL_FIELD_VALUE_MAX_LEN);
-
-  do
+  if (item_draw_design == (*i_ctx).m_option.m_type)
   {
+    l_page_number= 1;
+  }
+  else
+  {
+    l_page_number= (*i_page_number).m_page_number;
+  }
 
-    if (item_draw_design == (*i_ctx).m_option.m_type)
-    {
-      l_page_number= 1;
-    }
-    else
-    {
-      l_page_number= (*i_page_number).m_page_number;
-    }
+  if ((*i_page_number).m_format && (*i_page_number).m_format[0])
+  {
+    l_format= (*i_page_number).m_format;
+  }
+  else
+  {
+    l_format= "%ld";
+  }
 
-    if ((*i_page_number).m_format[0])
-    {
-      g_strlcpy(l_format, (*i_page_number).m_format, sizeof(l_format));
-    }
-    else
-    {
-      g_strlcpy(l_format, "%6ld", sizeof(l_format));
-    }
-
-    snprintf(
-      o_text, 
-      SPECIAL_FIELD_VALUE_MAX_LEN-1,
-      l_format,
-      l_page_number);
-
-  }while(0);
+  (*o_text)= g_strdup_printf(l_format, l_page_number);
 
   return;
 }
@@ -115,17 +119,26 @@ item_page_number_draw(
   struct item_page_number*const         i_page_number,
   struct item_draw_context const*const  i_ctx)
 {
+  double                                l_center_x;
+  double                                l_center_y;
   PangoFontDescription*                 l_font;
   PangoLayout*                          l_layout;
-  char                                  l_text[1+SPECIAL_FIELD_VALUE_MAX_LEN];
+  cairo_matrix_t                        l_matrix;
   size_t                                l_modulus;
+  double                                l_radians;
+  double                                l_shear_x;
+  double                                l_shear_y;
+  char*                                 l_text;
 
   l_font= 0;
   l_layout= 0;
+  l_text= 0;
 
   do
   {
 
+    item_page_number_get_text(&l_text, i_page_number, i_ctx);
+
     if (item_draw_print == (*i_ctx).m_option.m_type)
     {
       l_modulus= ((*i_page_number).m_page_number % 2);
@@ -149,6 +162,33 @@ item_page_number_draw(
       }
     }
 
+    cairo_new_path((*i_ctx).m_cr);
+    cairo_save((*i_ctx).m_cr);
+    cairo_scale((*i_ctx).m_cr, (*i_ctx).m_scale, (*i_ctx).m_scale);
+
+    l_layout= pango_cairo_create_layout((*i_ctx).m_cr);
+    pango_layout_set_width(l_layout, -1);
+    pango_layout_set_text(l_layout, l_text, -1);
+    pango_layout_set_font_description(l_layout, (*i_page_number).m_font); 
+
+    l_center_x= (*i_page_number).m_box.m_pos_x + ((*i_page_number).m_box.m_len_x / 2.0);
+    l_center_y= (*i_page_number).m_box.m_pos_y + ((*i_page_number).m_box.m_len_y / 2.0);
+
+    cairo_translate((*i_ctx).m_cr, l_center_x, l_center_y);
+    l_radians= geom_deg2rad((*i_page_number).m_transform.m_rotation);
+    cairo_rotate((*i_ctx).m_cr, l_radians);
+    cairo_translate((*i_ctx).m_cr, -l_center_x, -l_center_y);
+
+    l_shear_x= tan(geom_deg2rad((*i_page_number).m_transform.m_shear_x));
+    l_shear_y= tan(geom_deg2rad((*i_page_number).m_transform.m_shear_y));
+    
+    cairo_matrix_init(
+      &l_matrix,
+      1.0, l_shear_y,
+      l_shear_x, 1.0,
+      (*i_page_number).m_box.m_pos_x, (*i_page_number).m_box.m_pos_y);
+    cairo_transform((*i_ctx).m_cr, &l_matrix);
+
     if ((*i_page_number).m_fill.m_active)
     {
       cairo_set_source_rgba(
@@ -160,45 +200,14 @@ item_page_number_draw(
 
       cairo_rectangle(
         (*i_ctx).m_cr,
-        (*i_page_number).m_pos_x,
-        (*i_page_number).m_pos_y,
-        (*i_page_number).m_len_x,
-        (*i_page_number).m_len_y);
+        0.0,
+        0.0,
+        (*i_page_number).m_box.m_len_x,
+        (*i_page_number).m_box.m_len_y);
 
-      cairo_fill((*i_ctx).m_cr);
+      cairo_fill_preserve((*i_ctx).m_cr);
     }
 
-    cairo_save((*i_ctx).m_cr);
-
-    cairo_rectangle(
-      (*i_ctx).m_cr,
-      (*i_page_number).m_pos_x,
-      (*i_page_number).m_pos_y,
-      (*i_page_number).m_len_x,
-      (*i_page_number).m_len_x);
-
-    cairo_clip((*i_ctx).m_cr);
-
-    cairo_set_source_rgba(
-      (*i_ctx).m_cr,
-      (*i_page_number).m_color.red,
-      (*i_page_number).m_color.green,
-      (*i_page_number).m_color.blue,
-      (*i_page_number).m_color.alpha);
-
-    l_layout= pango_cairo_create_layout((*i_ctx).m_cr);
-    pango_layout_set_font_description(l_layout, (*i_page_number).m_font); 
-    cairo_translate((*i_ctx).m_cr, (*i_page_number).m_pos_x, (*i_page_number).m_pos_y);
-
-    item_page_number_get_text(l_text, i_page_number, i_ctx);
-
-    pango_layout_set_text(l_layout, l_text, -1);
-
-    pango_cairo_update_layout((*i_ctx).m_cr, l_layout);
-    pango_cairo_show_layout((*i_ctx).m_cr, l_layout);
-
-    cairo_restore((*i_ctx).m_cr);
-
     if ((*i_page_number).m_border.m_active)
     {
 
@@ -213,31 +222,44 @@ item_page_number_draw(
 
       cairo_rectangle(
         (*i_ctx).m_cr,
-        (*i_page_number).m_pos_x,
-        (*i_page_number).m_pos_y,
-        (*i_page_number).m_len_x,
-        (*i_page_number).m_len_y);
+        0.0,
+        0.0,
+        (*i_page_number).m_box.m_len_x,
+        (*i_page_number).m_box.m_len_y);
 
+      cairo_stroke_preserve((*i_ctx).m_cr);
+    }
+
+    cairo_set_source_rgba(
+      (*i_ctx).m_cr,
+      (*i_page_number).m_color.red,
+      (*i_page_number).m_color.green,
+      (*i_page_number).m_color.blue,
+      (*i_page_number).m_color.alpha);
+
+    pango_cairo_update_layout((*i_ctx).m_cr, l_layout);
+    pango_cairo_show_layout((*i_ctx).m_cr, l_layout);
+
+    if ((*i_ctx).m_option.m_highlight && 0 == (*i_ctx).m_selected)
+    {
+      item_common_cairo_dash_set((*i_ctx).m_cr, line_style_solid);
+      cairo_set_line_width((*i_ctx).m_cr, 1.0);
+      cairo_set_source_rgb((*i_ctx).m_cr, 0.50, 0.50, 0.00);
+      cairo_rectangle(
+        (*i_ctx).m_cr,
+        0,
+        0,
+        (*i_page_number).m_box.m_len_x,
+        (*i_page_number).m_box.m_len_y);
       cairo_stroke((*i_ctx).m_cr);
     }
 
-    if (0 == (*i_ctx).m_selected)
-    {
-      if ((*i_ctx).m_option.m_highlight &&
-        (item_draw_design == (*i_ctx).m_option.m_type))
-      {
-        item_common_box_draw_hightlight(
-          (*i_ctx).m_cr, 
-          (struct geom_rect*)i_page_number,
-          1.0);
-      }
-      break;
-    }
-
-    item_common_box_draw_grips((*i_ctx).m_cr, (struct geom_rect*)i_page_number);
+    cairo_restore((*i_ctx).m_cr);
 
   }while(0);
 
+  g_free(l_text);
+
   if (l_font)
   {
     pango_font_description_free(l_font);
@@ -254,43 +276,144 @@ item_page_number_draw(
 extern void
 item_page_number_get_bbox(
   struct geom_rect*const                o_bbox,
-  void const*const                      i_object)
+  cairo_t*                              io_cr,
+  double const                          i_scale,
+  struct item_page_number const*const   i_page_number)
 {
-  (*o_bbox)= *(struct geom_rect*)i_object;
+  item_common_box_get_bbox(
+    o_bbox, io_cr, &(*i_page_number).m_box, &(*i_page_number).m_transform, i_scale);
   return;
 }
 
 extern void
-item_page_number_in_event(
-  enum event_type*const                 o_type,
-  struct item_page_number const*const   i_page_number,
-  struct item_in_event const*const      i_ctx)
+item_page_number_get_position(
+  double*const                          o_pos_x,
+  double*const                          o_pos_y,
+  struct item_page_number const*const   i_page_number)
 {
 
-  item_common_box_in_event(o_type, i_ctx, (struct geom_rect*)i_page_number);
+  (*o_pos_x)= (*i_page_number).m_box.m_pos_x;
+  (*o_pos_y)= (*i_page_number).m_box.m_pos_y;
 
   return;
 }
 
+extern void
+item_page_number_get_rotation(
+  double*const                          o_rotation,
+  struct item_page_number const*const   i_page_number)
+{
+
+  (*o_rotation)= (*i_page_number).m_transform.m_rotation;
+
+  return;
+}
+
+extern void
+item_page_number_get_size(
+  double*const                          o_len_x,
+  double*const                          o_len_y,
+  struct item_page_number const*const   i_page_number)
+{
+
+  (*o_len_x)= (*i_page_number).m_box.m_len_x;
+  (*o_len_y)= (*i_page_number).m_box.m_len_y;
+
+  return;
+}
+
+extern void
+item_page_number_get_shear(
+  double*const                          o_shear_x,
+  double*const                          o_shear_y,
+  struct item_page_number const*const   i_page_number)
+{
+
+  (*o_shear_x)= (*i_page_number).m_transform.m_shear_x;
+  (*o_shear_y)= (*i_page_number).m_transform.m_shear_y;
+
+  return;
+}
+
+
+extern int
+item_page_number_in_event(
+  struct item_page_number const*const   i_page_number,
+  cairo_t*                              io_cr,
+  struct item_in_event const*const      i_ctx)
+{
+  int                                   l_hit;
+
+  l_hit= item_common_box_in_event(
+    io_cr, &(*i_page_number).m_box, &(*i_page_number).m_transform, i_ctx);
+
+  return l_hit;
+}
+
 extern void
 item_page_number_move(
   struct item_page_number*const         io_page_number,
   struct geom_point const*const         i_event)
 {
-  item_common_box_move((struct geom_rect*)io_page_number, i_event);
+  item_common_box_move(&(*io_page_number).m_box, i_event);
   return;
 }
 
 extern void
 item_page_number_normalize(
-  struct item_page_number*const         io_page_number,
-  double const                          i_bound_width,
-  double const                          i_bound_height)
+  struct item_page_number*const         io_page_number)
 {
-  item_common_box_normalize(
-    (struct geom_rect*)io_page_number, 
-    i_bound_width,
-    i_bound_height);
+  item_common_box_normalize(&(*io_page_number).m_box);
+  return;
+}
+
+extern void
+item_page_number_set_position(
+  struct item_page_number*const         io_page_number,
+  double const                          i_pos_x,
+  double const                          i_pos_y)
+{
+
+  (*io_page_number).m_box.m_pos_x= i_pos_x;
+  (*io_page_number).m_box.m_pos_y= i_pos_y;
+
+  return;
+}
+
+extern void
+item_page_number_set_rotation(
+  struct item_page_number*const         io_page_number,
+  double                                i_rotation)
+{
+
+  (*io_page_number).m_transform.m_rotation= i_rotation;
+
+  return;
+}
+
+extern void
+item_page_number_set_size(
+  struct item_page_number*const         io_page_number,
+  double                                i_len_x,
+  double                                i_len_y)
+{
+
+  (*io_page_number).m_box.m_len_x= i_len_x;
+  (*io_page_number).m_box.m_len_y= i_len_y;
+
+  return;
+}
+
+extern void
+item_page_number_set_shear(
+  struct item_page_number*const         io_page_number,
+  double                                i_shear_x,
+  double                                i_shear_y)
+{
+
+  (*io_page_number).m_transform.m_shear_x= i_shear_x;
+  (*io_page_number).m_transform.m_shear_y= i_shear_y;
+
   return;
 }
 
@@ -333,17 +456,11 @@ item_page_number_read(
     {
       switch(l_type)
       {
-        case element_tag_pos_x:
-          (*io_page_number).m_pos_x= xml_convert_double(l_value);
+        case element_tag_rect:
+          item_common_box_read(&l_error, &(*io_page_number).m_box, l_xml);
           break;
-        case element_tag_pos_y:
-          (*io_page_number).m_pos_y= xml_convert_double(l_value);
-          break;
-        case element_tag_len_x:
-          (*io_page_number).m_len_x= xml_convert_double(l_value);
-          break;
-        case element_tag_len_y:
-          (*io_page_number).m_len_y= xml_convert_double(l_value);
+        case element_tag_transform:
+          item_common_read_transform(&l_error, &(*io_page_number).m_transform, l_xml);
           break;
         case element_tag_font:
           (*io_page_number).m_font= pango_font_description_from_string(l_value);
@@ -356,7 +473,7 @@ item_page_number_read(
           }
           break;
         case element_tag_border:
-          l_exit= item_common_read_border_attr(&l_error, &(*io_page_number).m_border, l_xml);
+          l_exit= item_common_read_border(&l_error, &(*io_page_number).m_border, l_xml);
           break;
         case element_tag_fill:
           l_exit= item_common_read_fill(&l_error, &(*io_page_number).m_fill, l_xml);
@@ -383,7 +500,11 @@ item_page_number_read(
 
           break;
         case element_tag_format:
-          g_strlcpy((*io_page_number).m_format, l_value, sizeof((*io_page_number).m_format));
+          if (l_value[0])
+          {
+            g_free((*io_page_number).m_format);
+            (*io_page_number).m_format= g_strdup(l_value);
+          }
           break;
         default:
           break;
@@ -408,7 +529,28 @@ item_page_number_resize(
   struct item_resize_event const*const  i_ctx)
 {
 
-  item_common_box_resize((struct geom_rect *)io_page_number, i_ctx);
+  item_common_box_resize(&(*io_page_number).m_box, i_ctx, &(*io_page_number).m_transform);
+
+  return;
+}
+
+extern void
+item_page_number_rotate(
+  struct item_page_number*const         io_page_number,
+  double const                          i_rotation)
+{
+  (*io_page_number).m_transform.m_rotation= i_rotation;
+}
+  
+extern void
+item_page_number_shear(
+  struct item_page_number*const         io_page_number,
+  double const                          i_delta_x,
+  double const                          i_delta_y)
+{
+
+  (*io_page_number).m_transform.m_shear_x+= i_delta_x;
+  (*io_page_number).m_transform.m_shear_y+= i_delta_y;
 
   return;
 }
@@ -419,7 +561,6 @@ item_page_number_write(
   FILE*const                            io_fp,
   struct item_page_number const*const   i_page_number)
 {
-  char                                  l_buf[G_ASCII_DTOSTR_BUF_SIZE+1];
   int                                   l_exit;
   char*                                 l_text;
 
@@ -427,17 +568,15 @@ item_page_number_write(
   l_text= 0;
 
   fprintf(io_fp, "\t\t\t<item name=\"page_number\">\n");
-  fprintf(io_fp, "\t\t\t\t<pos_x>%s</pos_x>\n", g_ascii_dtostr(l_buf, sizeof(l_buf), (*i_page_number).m_pos_x));
-  fprintf(io_fp, "\t\t\t\t<pos_y>%s</pos_y>\n", g_ascii_dtostr(l_buf, sizeof(l_buf), (*i_page_number).m_pos_y));
-  fprintf(io_fp, "\t\t\t\t<len_x>%s</len_x>\n", g_ascii_dtostr(l_buf, sizeof(l_buf), (*i_page_number).m_len_x));
-  fprintf(io_fp, "\t\t\t\t<len_y>%s</len_y>\n", g_ascii_dtostr(l_buf, sizeof(l_buf), (*i_page_number).m_len_y));
+  item_common_box_write(o_error, io_fp, &(*i_page_number).m_box);
+  item_common_write_transform(o_error, io_fp, &(*i_page_number).m_transform);
   l_text= pango_font_description_to_string((*i_page_number).m_font);
   fprintf(io_fp, "\t\t\t\t<font>%s</font>\n", l_text);
   g_free(l_text);
   l_text= gdk_rgba_to_string(&(*i_page_number).m_color);
   fprintf(io_fp, "\t\t\t\t<color>%s</color>\n", l_text);
   g_free(l_text);
-  item_common_write_border_attr(o_error, io_fp, &(*i_page_number).m_border);
+  item_common_write_border(o_error, io_fp, &(*i_page_number).m_border);
   item_common_write_fill(o_error, io_fp, &(*i_page_number).m_fill);
 
   switch((*i_page_number).m_type)
@@ -457,7 +596,7 @@ item_page_number_write(
   }
 
   fprintf(io_fp, "\t\t\t\t<type>%s</type>\n", l_text);
-  fprintf(io_fp, "\t\t\t\t<format>%s</format>\n", (*i_page_number).m_format);
+  fprintf(io_fp, "\t\t\t\t<format>%s</format>\n", ((*i_page_number).m_format) ? (*i_page_number).m_format : "");
   fprintf(io_fp, "\t\t\t</item>\n");
 
   return l_exit;
