@@ -30,7 +30,8 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 #ifndef __item_page_number_h__
 
-#include "item_common.h"
+#include "item_common_attr.h"
+#include "item_common_base.h"
 #include "item_method.h"
 
 enum page_number_type
@@ -42,16 +43,14 @@ enum page_number_type
 
 struct item_page_number
 {
-  gdouble                               m_pos_x;
-  gdouble                               m_pos_y;
-  gdouble                               m_len_x;
-  gdouble                               m_len_y;
+  struct geom_rect                      m_box;
+  struct item_transform                 m_transform;
   PangoFontDescription*                 m_font; 
   GdkRGBA                               m_color;
-  struct item_border_attr               m_border;
+  struct item_border                    m_border;
   struct item_fill                      m_fill;
   enum page_number_type                 m_type;
-  gchar                                 m_format[1+FIELD_FORMAT_MAX_LEN];
+  gchar*                                m_format;
   guint64                               m_page_number;
 };
 
@@ -61,8 +60,9 @@ item_page_number_assign(
   struct item_method*const              o_method);
 
 extern void
-item_page_number_extent_update(
-  struct item_page_number*const         io_page_number);
+item_page_number_copy(
+  struct item_page_number *const        o_page_number,
+  struct item_page_number const*const   i_page_number);
 
 extern void
 item_page_number_discharge(
@@ -71,12 +71,37 @@ item_page_number_discharge(
 extern void
 item_page_number_get_bbox(
   struct geom_rect*const                o_bbox,
-  void const*const                      i_object);
+  cairo_t*                              io_cr,
+  double const                          i_scale,
+  struct item_page_number const*const   i_page_number);
 
 extern void
+item_page_number_get_position(
+  double*const                          o_pos_x,
+  double*const                          o_pos_y,
+  struct item_page_number const*const   i_page_number);
+
+extern void
+item_page_number_get_rotation(
+  double*const                          o_rotation,
+  struct item_page_number const*const   i_page_number);
+
+extern void
+item_page_number_get_size(
+  double*const                          o_len_x,
+  double*const                          o_len_y,
+  struct item_page_number const*const   i_page_number);
+
+extern void
+item_page_number_get_shear(
+  double*const                          o_shear_x,
+  double*const                          o_shear_y,
+  struct item_page_number const*const   i_page_number);
+
+extern int
 item_page_number_in_event(
-  enum event_type*const                 o_type,
   struct item_page_number const*const   i_page_number,
+  cairo_t*                              io_cr,
   struct item_in_event const*const      i_ctx);
 
 extern void
@@ -91,9 +116,31 @@ item_page_number_move(
 
 extern void
 item_page_number_normalize(
+  struct item_page_number*const         io_page_number);
+
+extern void
+item_page_number_set_position(
   struct item_page_number*const         io_page_number,
-  double const                          i_bound_width,
-  double const                          i_bound_height);
+  double const                          i_pos_x,
+  double const                          i_pos_y);
+
+extern void
+item_page_number_set_rotation(
+  struct item_page_number*const         io_page_number,
+  double                                i_rotation);
+
+extern void
+item_page_number_set_size(
+  struct item_page_number*const         io_page_number,
+  double                                i_len_x,
+  double                                i_len_y);
+
+extern void
+item_page_number_set_shear(
+  struct item_page_number*const         io_page_number,
+  double const                          i_shear_x,
+  double const                          i_shear_y);
+
 
 extern int
 item_page_number_property(
@@ -103,13 +150,24 @@ extern int
 item_page_number_read(
   GError**                              o_error,
   struct item_page_number*const         io_page_number,
-  struct xml *const               i_element);
+  struct xml *const                     i_element);
 
 extern void
 item_page_number_resize(
   struct item_page_number*const         io_page_number,
   struct item_resize_event const*const  i_ctx);
 
+extern void
+item_page_number_rotate(
+  struct item_page_number*const         io_page_number,
+  double const                          i_rotation);
+  
+extern void
+item_page_number_shear(
+  struct item_page_number*const         io_page_number,
+  double const                          i_delta_x,
+  double const                          i_delta_y);
+
 extern int
 item_page_number_write(
   GError**                              o_error,
