@@ -37,9 +37,9 @@ item_text_assign(
 {
 
   memset(o_text, 0, sizeof(*o_text));
-  (*o_text).m_pos_y1= 10.0;
-  (*o_text).m_pos_x2= 100.0;
-  (*o_text).m_pos_y2= 10.0;
+
+  (*o_text).m_box.m_len_x= 30.0;
+  (*o_text).m_box.m_len_y= 18.0;
   (*o_text).m_font= pango_font_description_new();
   (*o_text).m_color.alpha= 1.0;
 
@@ -48,6 +48,20 @@ item_text_assign(
   return;
 }
 
+extern void
+item_text_copy(
+  struct item_text *const               o_text,
+  struct item_text const*const          i_text)
+{
+
+  memcpy(o_text, i_text, sizeof(*o_text));
+  (*o_text).m_font= pango_font_description_copy((*i_text).m_font);
+  (*o_text).m_text= g_strdup((*i_text).m_text);
+  (*o_text).m_value= 0;
+
+  return;
+}
+
 extern void
 item_text_discharge(
   struct item_text*const                io_text)
@@ -77,17 +91,23 @@ item_text_draw(
   struct item_text*                     i_text,
   struct item_draw_context const*const  i_ctx)
 {
-  double                                l_length;
   PangoLayout*                          l_layout;
   double                                l_radians;
   char*                                 l_text;
+  double                                l_center_x;
+  double                                l_center_y;
+  cairo_matrix_t                        l_matrix;
+  double                                l_shear_x;
+  double                                l_shear_y;
   
   l_layout= 0;
 
   do
   {
 
+    cairo_new_path((*i_ctx).m_cr);
     cairo_save((*i_ctx).m_cr);
+    cairo_scale((*i_ctx).m_cr, (*i_ctx).m_scale, (*i_ctx).m_scale);
 
     cairo_set_source_rgba(
       (*i_ctx).m_cr,
@@ -122,73 +142,51 @@ item_text_draw(
       }
       else
       {
-        l_length= geom_line_length((struct geom_line*)i_text);
-        pango_layout_set_width(l_layout, (PANGO_SCALE*l_length));
+        pango_layout_set_width(l_layout, (PANGO_SCALE*(*i_text).m_box.m_len_x));
         pango_layout_set_wrap(l_layout, PANGO_WRAP_WORD); 
       }
       pango_layout_set_markup(l_layout, l_text, -1);
     }
 
     pango_layout_set_font_description(l_layout, (*i_text).m_font);
-    cairo_translate((*i_ctx).m_cr, (*i_text).m_pos_x1, (*i_text).m_pos_y1);
-    if ((*i_text).m_rotate)
-    {
-      l_radians= geom_deg2rad((*i_text).m_rotation);
-      cairo_rotate((*i_ctx).m_cr, l_radians);
-    }
+
+    l_center_x= (*i_text).m_box.m_pos_x + ((*i_text).m_box.m_len_x / 2.0);
+    l_center_y= (*i_text).m_box.m_pos_y + ((*i_text).m_box.m_len_y / 2.0);
+
+    cairo_translate((*i_ctx).m_cr, l_center_x, l_center_y);
+    l_radians= geom_deg2rad((*i_text).m_transform.m_rotation);
+    cairo_rotate((*i_ctx).m_cr, l_radians);
+    cairo_translate((*i_ctx).m_cr, -l_center_x, -l_center_y);
+
+    l_shear_x= tan(geom_deg2rad((*i_text).m_transform.m_shear_x));
+    l_shear_y= tan(geom_deg2rad((*i_text).m_transform.m_shear_y));
+    
+    cairo_matrix_init(
+      &l_matrix,
+      1.0, l_shear_y,
+      l_shear_x, 1.0,
+      (*i_text).m_box.m_pos_x, (*i_text).m_box.m_pos_y);
+    cairo_transform((*i_ctx).m_cr, &l_matrix);
+
     pango_cairo_update_layout((*i_ctx).m_cr, l_layout);
     pango_cairo_show_layout((*i_ctx).m_cr, l_layout);
-    cairo_restore((*i_ctx).m_cr);
 
-    if (0 == (*i_ctx).m_selected)
+    if ((*i_ctx).m_option.m_highlight && 0 == (*i_ctx).m_selected)
     {
-      if ((*i_ctx).m_option.m_highlight &&
-        (item_draw_design == (*i_ctx).m_option.m_type))
-      {
-        cairo_save((*i_ctx).m_cr);
-        cairo_set_source_rgb((*i_ctx).m_cr, 0.50, 0.50, 0.50);
-        item_common_cairo_dash_set((*i_ctx).m_cr, line_style_solid);
-        cairo_set_line_width((*i_ctx).m_cr, 1.0);
-        cairo_move_to((*i_ctx).m_cr, (*i_text).m_pos_x1, (*i_text).m_pos_y1);
-        cairo_line_to((*i_ctx).m_cr, (*i_text).m_pos_x2, (*i_text).m_pos_y2);
-        cairo_stroke((*i_ctx).m_cr);
-        cairo_restore((*i_ctx).m_cr);
-      }
-      break;
+      item_common_cairo_dash_set((*i_ctx).m_cr, line_style_solid);
+      cairo_set_line_width((*i_ctx).m_cr, 1.0);
+      cairo_set_source_rgb((*i_ctx).m_cr, 0.50, 0.50, 0.00);
+      cairo_rectangle(
+        (*i_ctx).m_cr,
+        0,
+        0,
+        (*i_text).m_box.m_len_x,
+        (*i_text).m_box.m_len_y);
+      cairo_stroke((*i_ctx).m_cr);
     }
 
-    if (item_draw_print == (*i_ctx).m_option.m_type)
-    {
-      break;
-    }
-
-    cairo_save((*i_ctx).m_cr);
-    cairo_set_source_rgb((*i_ctx).m_cr, 0.0, 0.0, 0.0);
-    item_common_cairo_dash_set((*i_ctx).m_cr, line_style_solid);
-    cairo_set_line_width((*i_ctx).m_cr, 1.0);
-    cairo_move_to((*i_ctx).m_cr, (*i_text).m_pos_x1, (*i_text).m_pos_y1);
-    cairo_line_to((*i_ctx).m_cr, (*i_text).m_pos_x2, (*i_text).m_pos_y2);
-    cairo_stroke((*i_ctx).m_cr);
     cairo_restore((*i_ctx).m_cr);
 
-    cairo_set_source_rgb((*i_ctx).m_cr, 0.0, 1.0, 0.0);
-
-    cairo_rectangle(
-      (*i_ctx).m_cr,
-      (*i_text).m_pos_x1-4,
-      (*i_text).m_pos_y1-4,
-      8,
-      8);
-    cairo_fill((*i_ctx).m_cr);
-
-    cairo_rectangle(
-      (*i_ctx).m_cr,
-      (*i_text).m_pos_x2-4,
-      (*i_text).m_pos_y2-4,
-      8,
-      8);
-    cairo_fill((*i_ctx).m_cr);
-
   }while(0);
 
   if (l_layout)
@@ -202,115 +200,78 @@ item_text_draw(
 extern void
 item_text_get_bbox(
   struct geom_rect*const                o_bbox,
-  void const*const                      i_object)
+  cairo_t*                              io_cr,
+  double const                          i_scale,
+  struct item_text const*const          i_text)
 {
-  struct item_text const*               l_text;
 
-  l_text= (struct item_text const*)i_object;
-  (*o_bbox).m_pos_x= (*l_text).m_pos_x1;
-  (*o_bbox).m_pos_y= (*l_text).m_pos_y1;
-  (*o_bbox).m_len_x= (*l_text).m_pos_x2 - (*l_text).m_pos_x1;
-  (*o_bbox).m_len_y= 1.0;
+  item_common_box_get_bbox(o_bbox, io_cr, &(*i_text).m_box, &(*i_text).m_transform, i_scale);
 
   return;
 }
 
-static int
-item_text_in_event_grips(
-  enum event_type*const                 o_type,
-  struct item_text const*const          i_text,
-  struct item_in_event const*const      i_ctx)
-{
-  int                                   l_hit;
-
-  l_hit= 0;
-
-  do
-  {
-
-    l_hit= item_common_event_inside(
-      i_ctx,
-      (*i_text).m_pos_x1-4,
-      (*i_text).m_pos_y1-4,
-      8,
-      8);
-
-    if (l_hit)
-    {
-      if (0 == (*i_text).m_rotate)
-      {
-        (*o_type)= event_resize_west;
-      }
-      else
-      {
-        (*o_type)= event_resize_north_west;
-      }
-      break;
-    }
-    
-    l_hit= item_common_event_inside(
-      i_ctx,
-      (*i_text).m_pos_x2-4,
-      (*i_text).m_pos_y2-4,
-      8,
-      8);
-
-    if (l_hit)
-    {
-      if (0 == (*i_text).m_rotate)
-      {
-        (*o_type)= event_resize_east;
-      }
-      else
-      {
-        (*o_type)= event_resize_south_east;
-      }
-      break;
-    }
-
-  }while(0);
-
-  return l_hit;
-}
-
 extern void
+item_text_get_position(
+  double*const                          o_pos_x,
+  double*const                          o_pos_y,
+  struct item_text const*const          i_text)
+{
+
+  (*o_pos_x)= (*i_text).m_box.m_pos_x;
+  (*o_pos_y)= (*i_text).m_box.m_pos_y;
+
+  return;
+}
+
+extern void
+item_text_get_rotation(
+  double*const                          o_rotation,
+  struct item_text const*const          i_text)
+{
+
+  (*o_rotation)= (*i_text).m_transform.m_rotation;
+
+  return;
+}
+
+extern void
+item_text_get_size(
+  double*const                          o_len_x,
+  double*const                          o_len_y,
+  struct item_text const*const          i_text)
+{
+
+  (*o_len_x)= (*i_text).m_box.m_len_x;
+  (*o_len_y)= (*i_text).m_box.m_len_y;
+
+  return;
+}
+
+extern void
+item_text_get_shear(
+  double*const                          o_shear_x,
+  double*const                          o_shear_y,
+  struct item_text const*const          i_text)
+{
+
+  (*o_shear_x)= (*i_text).m_transform.m_shear_x;
+  (*o_shear_y)= (*i_text).m_transform.m_shear_y;
+
+  return;
+}
+
+
+extern int
 item_text_in_event(
-  enum event_type*const                 o_type,
   struct item_text const*const          i_text,
+  cairo_t*                              io_cr,
   struct item_in_event const*const      i_ctx)
 {
   int                                   l_hit;
 
-  l_hit= 0;
+  l_hit= item_common_box_in_event(io_cr, &(*i_text).m_box, &(*i_text).m_transform, i_ctx);
 
-  do
-  {
-
-    (*o_type)= event_none;
-
-    l_hit= item_common_line_in_event(i_ctx, (struct geom_line*)i_text);
-
-    if (0 == l_hit)
-    {
-      break;
-    }
-
-    if ((*i_ctx).m_selected)
-    {
-
-      l_hit= item_text_in_event_grips(o_type, i_text, i_ctx);
-
-      if (l_hit)
-      {
-        break;
-      }
-    }
-
-    (*o_type)= event_move;
-
-  }while(0);
-
-  return;
+  return l_hit;
 }
 
 extern void
@@ -319,75 +280,67 @@ item_text_move(
   struct geom_point const*const         i_event)
 {
 
-  (*io_text).m_pos_x1+= (*i_event).m_pos_x;
-  (*io_text).m_pos_y1+= (*i_event).m_pos_y;
-  (*io_text).m_pos_x2+= (*i_event).m_pos_x;
-  (*io_text).m_pos_y2+= (*i_event).m_pos_y;
+  item_common_box_move(&(*io_text).m_box, i_event);
 
   return;
 }
 
 extern void
 item_text_normalize(
-  struct item_text*const                io_text,
-  double const                          i_bound_width,
-  double const                          i_bound_height)
+  struct item_text*const                io_text)
 {
-  gdouble                               l_swap;
 
-  do
-  {
+  item_common_box_normalize(&(*io_text).m_box);
 
-    if ((*io_text).m_rotate)
-    {
-      break;
-    }
+  return;
+}
 
-    (*io_text).m_rotation= 0.00;
+extern void
+item_text_set_position(
+  struct item_text*const                io_text,
+  double const                          i_pos_x,
+  double const                          i_pos_y)
+{
 
-    if ((*io_text).m_pos_x1 > (*io_text).m_pos_x2)
-    {
-      l_swap= (*io_text).m_pos_x1;
-      (*io_text).m_pos_x1= (*io_text).m_pos_x2;
-      (*io_text).m_pos_x2= l_swap;
-    }
+  (*io_text).m_box.m_pos_x= i_pos_x;
+  (*io_text).m_box.m_pos_y= i_pos_y;
 
-    if ((*io_text).m_pos_y1 > (*io_text).m_pos_y2)
-    {
-      l_swap= (*io_text).m_pos_y1;
-      (*io_text).m_pos_y1= (*io_text).m_pos_y2;
-      (*io_text).m_pos_y2= l_swap;
-    }
+  return;
+}
 
-    if (0 > (int)(*io_text).m_pos_x2)
-    {
-      l_swap= (*io_text).m_pos_x2 - (*io_text).m_pos_x1;
-      (*io_text).m_pos_x2= 2.0;
-      (*io_text).m_pos_x1= (*io_text).m_pos_x2 - l_swap;
-    }
+extern void
+item_text_set_rotation(
+  struct item_text*const                io_text,
+  double                                i_rotation)
+{
 
-    if (0 > (int)(*io_text).m_pos_y2)
-    {
-      l_swap= (*io_text).m_pos_y2 - (*io_text).m_pos_y1;
-      (*io_text).m_pos_y1= 2.0 - l_swap;
-      (*io_text).m_pos_y2= (*io_text).m_pos_y1 + l_swap;
-    }
+  (*io_text).m_transform.m_rotation= i_rotation;
 
-    if (i_bound_width < (int)(*io_text).m_pos_x1)
-    {
-      l_swap= (*io_text).m_pos_x2 - (*io_text).m_pos_x1;
-      (*io_text).m_pos_x1= i_bound_width - 2.0;
-      (*io_text).m_pos_x2= (*io_text).m_pos_x1 + l_swap;
-    }
+  return;
+}
 
-    if (i_bound_height < (int)(*io_text).m_pos_y1)
-    {
-      l_swap= (*io_text).m_pos_y2 - (*io_text).m_pos_y1;
-      (*io_text).m_pos_y1= i_bound_height - 2.0;
-      (*io_text).m_pos_y2= (*io_text).m_pos_y1 + l_swap;
-    }
+extern void
+item_text_set_size(
+  struct item_text*const                io_text,
+  double                                i_len_x,
+  double                                i_len_y)
+{
 
-  }while(0);
+  (*io_text).m_box.m_len_x= i_len_x;
+  (*io_text).m_box.m_len_y= i_len_y;
+
+  return;
+}
+
+extern void
+item_text_set_shear(
+  struct item_text*const                io_text,
+  double                                i_shear_x,
+  double                                i_shear_y)
+{
+
+  (*io_text).m_transform.m_shear_x= i_shear_x;
+  (*io_text).m_transform.m_shear_y= i_shear_y;
 
   return;
 }
@@ -431,17 +384,11 @@ item_text_read(
     {
       switch(l_type)
       {
-        case element_tag_pos_x1:
-          (*io_text).m_pos_x1= xml_convert_double(l_value);
+        case element_tag_rect:
+          item_common_box_read(&l_error, &(*io_text).m_box, l_xml);
           break;
-        case element_tag_pos_y1:
-          (*io_text).m_pos_y1= xml_convert_double(l_value);
-          break;
-        case element_tag_pos_x2:
-          (*io_text).m_pos_x2= xml_convert_double(l_value);
-          break;
-        case element_tag_pos_y2:
-          (*io_text).m_pos_y2= xml_convert_double(l_value);
+        case element_tag_transform:
+          item_common_read_transform(&l_error, &(*io_text).m_transform, l_xml);
           break;
         case element_tag_font:
           (*io_text).m_font= pango_font_description_from_string(l_value);
@@ -453,10 +400,6 @@ item_text_read(
             (*io_text).m_color= l_rgba;
           }
           break;
-        case element_tag_rotate:
-          (*io_text).m_rotate= xml_convert_boolean(xml_lookup_attribute_value(l_xml, "on"));
-          (*io_text).m_rotation= xml_convert_ulong(l_value);
-          break;
         case element_tag_text:
           (*io_text).m_text= g_strdup((*l_xml).m_string->str);
           break;
@@ -482,79 +425,64 @@ item_text_resize(
   struct item_text*const                io_text,
   struct item_resize_event const*const  i_ctx)
 {
-  gdouble                               l_delta_x;
-  gdouble                               l_delta_y;
 
-  switch((*i_ctx).m_type)
-  {
-    case event_resize_east:
-      (*io_text).m_pos_x2+= (*i_ctx).m_event.m_pos_x;
-      break;
-    case event_resize_north:
-      (*io_text).m_pos_y1+= (*i_ctx).m_event.m_pos_y;
-      break;
-    case event_resize_north_east:
-      (*io_text).m_pos_y1+= (*i_ctx).m_event.m_pos_y;
-      (*io_text).m_pos_x2+= (*i_ctx).m_event.m_pos_x;
-      break;
-    case event_resize_north_west:
-      (*io_text).m_pos_y1+= (*i_ctx).m_event.m_pos_y;
-      (*io_text).m_pos_x1+= (*i_ctx).m_event.m_pos_x;
-      break;
-    case event_resize_south:
-      (*io_text).m_pos_y2+= (*i_ctx).m_event.m_pos_y;
-      break;
-    case event_resize_south_east:
-      (*io_text).m_pos_y2+= (*i_ctx).m_event.m_pos_y;
-      (*io_text).m_pos_x2+= (*i_ctx).m_event.m_pos_x;
-      break;
-    case event_resize_south_west:
-      (*io_text).m_pos_y2+= (*i_ctx).m_event.m_pos_y;
-      (*io_text).m_pos_x1+= (*i_ctx).m_event.m_pos_x;
-      break;
-    case event_resize_west:
-      (*io_text).m_pos_x1+= (*i_ctx).m_event.m_pos_x;
-      break;
-    default:
-      break;
-  }
-
-  l_delta_x= (*io_text).m_pos_x2 - (*io_text).m_pos_x1;
-  l_delta_y= (*io_text).m_pos_y2 - (*io_text).m_pos_y1;
-  (*io_text).m_rotation= atan2(l_delta_y, l_delta_x) * 180 / G_PI;
+  item_common_box_resize(&(*io_text).m_box, i_ctx, &(*io_text).m_transform);
 
   return;
 }
 
+extern void
+item_text_rotate(
+  struct item_text*const                io_text,
+  double const                          i_rotation)
+{
+
+  (*io_text).m_transform.m_rotation= i_rotation;
+
+  return;
+}
+  
+extern void
+item_text_shear(
+  struct item_text*const                io_text,
+  double const                          i_delta_x,
+  double const                          i_delta_y)
+{
+
+  (*io_text).m_transform.m_shear_x+= i_delta_x;
+  (*io_text).m_transform.m_shear_y+= i_delta_y;
+
+  return; 
+}
+
+
+
+
 extern int
 item_text_write(
   GError**                              o_error,
   FILE*const                            io_fp,
   struct item_text const*const          i_text)
 {
-  char                                  l_buf[G_ASCII_DTOSTR_BUF_SIZE+1];
   int                                   l_exit;
   char*                                 l_text;
 
   l_exit= 0;
 
   fprintf(io_fp, "\t\t\t<item name=\"text\">\n");
-  fprintf(io_fp, "\t\t\t\t<pos_x1>%s</pos_x1>\n", g_ascii_dtostr(l_buf, sizeof(l_buf), (*i_text).m_pos_x1));
-  fprintf(io_fp, "\t\t\t\t<pos_y1>%s</pos_y1>\n", g_ascii_dtostr(l_buf, sizeof(l_buf), (*i_text).m_pos_y1));
-  fprintf(io_fp, "\t\t\t\t<pos_x2>%s</pos_x2>\n", g_ascii_dtostr(l_buf, sizeof(l_buf), (*i_text).m_pos_x2));
-  fprintf(io_fp, "\t\t\t\t<pos_y2>%s</pos_y2>\n", g_ascii_dtostr(l_buf, sizeof(l_buf), (*i_text).m_pos_y2));
+  item_common_box_write(o_error, io_fp, &(*i_text).m_box);
+  item_common_write_transform(o_error, io_fp, &(*i_text).m_transform);
   l_text= pango_font_description_to_string((*i_text).m_font);
   fprintf(io_fp, "\t\t\t\t<font>%s</font>\n", l_text);
   g_free(l_text);
   l_text= gdk_rgba_to_string(&(*i_text).m_color);
   fprintf(io_fp, "\t\t\t\t<color>%s</color>\n", l_text);
   g_free(l_text);
-  fprintf(io_fp, "\t\t\t\t<rotate on=\"%s\">%s</rotate>\n", ((*i_text).m_rotate ? "true" : "false"),g_ascii_dtostr(l_buf, sizeof(l_buf), (*i_text).m_rotation));
   fprintf(io_fp, "\t\t\t\t<autowrap on=\"%s\"/>\n", ((*i_text).m_autowrap ? "true" : "false"));
 
   if ((*i_text).m_text && (*i_text).m_text[0])
   {
-    fprintf(io_fp, "\t\t\t\t<text>%s</text>", (*i_text).m_text);
+    fprintf(io_fp, "\t\t\t\t<text>%s</text>\n", (*i_text).m_text);
   }
 
   fprintf(io_fp, "\t\t\t</item>\n");
