@@ -35,14 +35,10 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 struct item_text
 {
-  gdouble                               m_pos_x1;
-  gdouble                               m_pos_y1;
-  gdouble                               m_pos_x2;
-  gdouble                               m_pos_y2;
+  struct geom_rect                      m_box;
+  struct item_transform                 m_transform;
   PangoFontDescription*                 m_font; 
   GdkRGBA                               m_color;
-  gint                                  m_rotate;
-  gdouble                               m_rotation;
   gint                                  m_autowrap;
   gchar*                                m_text;
   gchar*                                m_value;
@@ -54,19 +50,9 @@ item_text_assign(
   struct item_method*const              o_method);
 
 extern void
-item_text_extent_update(
-  struct item_text*const                io_text);
-
-extern void
-item_text_get_bbox(
-  struct geom_rect*const                o_bbox,
-  void const*const                      i_object);
-
-extern void
-item_text_in_event(
-  enum event_type*const                 o_type,
-  struct item_text const*const          i_text,
-  struct item_in_event const*const      i_ctx);
+item_text_copy(
+  struct item_text *const               o_text,
+  struct item_text const*const          i_text);
 
 extern void
 item_text_discharge(
@@ -77,6 +63,42 @@ item_text_draw(
   struct item_text      *               i_text,
   struct item_draw_context const*const  i_ctx);
 
+extern void
+item_text_get_bbox(
+  struct geom_rect*const                o_bbox,
+  cairo_t*                              io_cr,
+  double const                          i_scale,
+  struct item_text const*const          i_text);
+
+extern void
+item_text_get_position(
+  double*const                          o_pos_x,
+  double*const                          o_pos_y,
+  struct item_text const*const          i_text);
+
+extern void
+item_text_get_rotation(
+  double*const                          o_rotation,
+  struct item_text const*const          i_text);
+
+extern void
+item_text_get_size(
+  double*const                          o_len_x,
+  double*const                          o_len_y,
+  struct item_text const*const          i_text);
+
+extern void
+item_text_get_shear(
+  double*const                          o_shear_x,
+  double*const                          o_shear_y,
+  struct item_text const*const          i_text);
+
+extern int
+item_text_in_event(
+  struct item_text const*const          i_text,
+  cairo_t*                              io_cr,
+  struct item_in_event const*const      i_ctx);
+
 extern void
 item_text_move(
   struct item_text*const                io_text,
@@ -84,9 +106,30 @@ item_text_move(
 
 extern void
 item_text_normalize(
+  struct item_text*const                io_text);
+
+extern void
+item_text_set_position(
   struct item_text*const                io_text,
-  double const                          i_bound_width,
-  double const                          i_bound_height);
+  double const                          i_pos_x,
+  double const                          i_pos_y);
+
+extern void
+item_text_set_rotation(
+  struct item_text*const                io_text,
+  double                                i_rotation);
+
+extern void
+item_text_set_size(
+  struct item_text*const                io_text,
+  double                                i_len_x,
+  double                                i_len_y);
+
+extern void
+item_text_set_shear(
+  struct item_text*const                io_text,
+  double const                          i_shear_x,
+  double const                          i_shear_y);
 
 extern int
 item_text_property(
@@ -96,13 +139,24 @@ extern int
 item_text_read(
   GError**                              o_error,
   struct item_text*const                io_text,
-  struct xml *const               i_element);
+  struct xml *const                     i_element);
 
 extern void
 item_text_resize(
   struct item_text*const                io_text,
   struct item_resize_event const*const  i_ctx);
 
+extern void
+item_text_rotate(
+  struct item_text*const                io_text,
+  double const                          i_rotation);
+  
+extern void
+item_text_shear(
+  struct item_text*const                io_text,
+  double const                          i_delta_x,
+  double const                          i_delta_y);
+
 extern int
 item_text_write(
   GError**                              o_error,
