@@ -29,6 +29,7 @@ NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 #include "item_text.h"
+#include "item_property.h"
 
 struct text_dialog
 {
@@ -41,152 +42,48 @@ struct text_dialog
   GtkTextView*                          m_text_textview;
 };
 
-static void
-item_text_color_button_cb(
-  GtkWidget *                           i_widget,
-  gpointer                              i_data)
-{
-  GdkRGBA                               l_color;
-  GtkWidget*                            l_dialog;
-  int                                   l_exit;
-  struct text_dialog*                   l_textd;
-  gchar*                                l_rgba;
-  gchar const*                          l_text;
-
-  l_dialog= 0;
-  memset(&l_color, 0, sizeof(l_color));
-
-  do
-  {
-
-    l_textd= (struct text_dialog*)i_data;
-
-    l_dialog= gtk_color_chooser_dialog_new("Border Color", get_main_window());
-
-    l_text= gtk_entry_get_text((*l_textd).m_color_entry);
-    gdk_rgba_parse(&l_color, l_text);
-    gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(l_dialog), &l_color);
-
-    gtk_window_set_modal((GtkWindow*)l_dialog, 1);
-    l_exit= gtk_dialog_run(GTK_DIALOG(l_dialog));
-
-    if (GTK_RESPONSE_OK != l_exit)
-    {
-      break;
-    }
-
-    gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(l_dialog), &l_color);
-
-    l_rgba= gdk_rgba_to_string(&l_color);
-    gtk_entry_set_text((*l_textd).m_color_entry, l_rgba);
-    g_free(l_rgba);
-
-  }while(0);
-
-  if (l_dialog)
-  {
-    gtk_widget_destroy((GtkWidget*)l_dialog);
-  }
-  
-  return;
-}
-
-static void
-item_text_font_button_cb(
-  GtkWidget *                           i_widget,
-  gpointer                              i_data)
-{
-  GtkWidget*                            l_dialog;
-  int                                   l_exit;
-  struct text_dialog*                  l_textd;
-  gchar*                                l_font;
-  gchar const*                          l_text;
-
-  l_dialog= 0;
-  l_exit= 0;
-  l_font= 0;
-
-  do
-  {
-
-    l_textd= (struct text_dialog*)i_data;
-
-    l_text= gtk_entry_get_text(GTK_ENTRY((*l_textd).m_font_entry));
-
-    l_dialog= gtk_font_chooser_dialog_new("Font", get_main_window());
-
-    gtk_font_chooser_set_font(GTK_FONT_CHOOSER(l_dialog), l_text);
-
-    gtk_window_set_modal((GtkWindow*)l_dialog, 1);
-    l_exit= gtk_dialog_run(GTK_DIALOG(l_dialog));
-
-    if (GTK_RESPONSE_OK != l_exit)
-    {
-      break;
-    }
-
-    l_font= gtk_font_chooser_get_font(GTK_FONT_CHOOSER(l_dialog));
-    gtk_entry_set_text(
-      (GTK_ENTRY((*l_textd).m_font_entry)),
-      l_font);
-
-  }while(0);
-
-  if (l_font)
-  {
-    g_free(l_font);
-  }
-
-  if (l_dialog)
-  {
-    gtk_widget_destroy((GtkWidget*)l_dialog);
-  }
-
-  return;
-}
-
 static void
 item_text_bind(
-  struct text_dialog*const              o_textd,
+  struct text_dialog*const              io_dlg,
   GtkBuilder*const                      i_builder)
 {
 
-  memset(o_textd, 0, sizeof(*o_textd));
+  memset(io_dlg, 0, sizeof(*io_dlg));
 
   do
   {
 
-    (*o_textd).m_color_entry=
+    (*io_dlg).m_color_entry=
       GTK_ENTRY(gtk_builder_get_object(i_builder, "color_entry"));
 
-    (*o_textd).m_color_button=
+    (*io_dlg).m_color_button=
       GTK_BUTTON(gtk_builder_get_object(i_builder, "color_button"));
 
     g_signal_connect(
-      (*o_textd).m_color_button,
+      (*io_dlg).m_color_button,
       "clicked",
-      G_CALLBACK(item_text_color_button_cb),
-      o_textd);
+      G_CALLBACK(item_property_color_button_cb),
+      (*io_dlg).m_color_entry);
 
-    (*o_textd).m_font_entry=
+    (*io_dlg).m_font_entry=
       GTK_ENTRY(gtk_builder_get_object(i_builder, "font_entry"));
 
-    (*o_textd).m_font_button=
+    (*io_dlg).m_font_button=
       GTK_BUTTON(gtk_builder_get_object(i_builder, "font_button"));
 
     g_signal_connect(
-      (*o_textd).m_font_button,
+      (*io_dlg).m_font_button,
       "clicked",
-      G_CALLBACK(item_text_font_button_cb),
-      o_textd);
+      G_CALLBACK(item_property_font_button_cb),
+      (*io_dlg).m_font_entry);
 
-    (*o_textd).m_rotate_checkbutton=
+    (*io_dlg).m_rotate_checkbutton=
       GTK_CHECK_BUTTON(gtk_builder_get_object(i_builder, "rotate_checkbutton"));
 
-    (*o_textd).m_autowrap_checkbutton=
+    (*io_dlg).m_autowrap_checkbutton=
       GTK_CHECK_BUTTON(gtk_builder_get_object(i_builder, "autowrap_checkbutton"));
 
-    (*o_textd).m_text_textview=
+    (*io_dlg).m_text_textview=
       GTK_TEXT_VIEW(gtk_builder_get_object(i_builder, "text_textview"));
 
   }while(0);
@@ -196,34 +93,36 @@ item_text_bind(
 
 static void
 item_text_set_values(
-  struct text_dialog*const              i_textd,
-  struct item_text *const               i_text)
+  struct text_dialog*const              i_dlg,
+  struct item_text *const               i_object)
 {
   GtkTextBuffer*                        l_buffer;
   gchar *                               l_color;
   gchar *                               l_font;
 
-  l_color= gdk_rgba_to_string(&(*i_text).m_color);
-  gtk_entry_set_text((*i_textd).m_color_entry, l_color);
+  l_color= gdk_rgba_to_string(&(*i_object).m_color);
+  gtk_entry_set_text((*i_dlg).m_color_entry, l_color);
   g_free(l_color);
   l_color= 0;
 
-  l_font= pango_font_description_to_string((*i_text).m_font);
-  gtk_entry_set_text((*i_textd).m_font_entry, l_font);
+  l_font= pango_font_description_to_string((*i_object).m_font);
+  gtk_entry_set_text((*i_dlg).m_font_entry, l_font);
   g_free(l_font);
 
+/*
   gtk_toggle_button_set_active(
-    GTK_TOGGLE_BUTTON((*i_textd).m_rotate_checkbutton),
-    (*i_text).m_rotate);
+    GTK_TOGGLE_BUTTON((*i_dlg).m_rotate_checkbutton),
+    (*i_object).m_rotate);
+*/
 
   gtk_toggle_button_set_active(
-    GTK_TOGGLE_BUTTON((*i_textd).m_autowrap_checkbutton),
-    (*i_text).m_autowrap);
+    GTK_TOGGLE_BUTTON((*i_dlg).m_autowrap_checkbutton),
+    (*i_object).m_autowrap);
 
-  if ((*i_text).m_text)
+  if ((*i_object).m_text)
   {
-    l_buffer= gtk_text_view_get_buffer((*i_textd).m_text_textview);
-    gtk_text_buffer_set_text(l_buffer, (*i_text).m_text, -1);
+    l_buffer= gtk_text_view_get_buffer((*i_dlg).m_text_textview);
+    gtk_text_buffer_set_text(l_buffer, (*i_object).m_text, -1);
   }
 
   return;
@@ -231,8 +130,8 @@ item_text_set_values(
 
 static void
 item_text_copy_values(
-  struct item_text *const              io_text,
-  struct text_dialog const*const       i_textd)
+  struct item_text *const               io_object,
+  struct text_dialog const*const        i_dlg)
 {
   GtkTextBuffer*                        l_buffer;
   GtkTextIter                           l_end;
@@ -242,32 +141,36 @@ item_text_copy_values(
   GtkTextIter                           l_start;
   gchar const*                          l_text;
 
-  l_text= gtk_entry_get_text(GTK_ENTRY((*i_textd).m_color_entry));
-  gdk_rgba_parse(&(*io_text).m_color, l_text);
+  l_text= gtk_entry_get_text(GTK_ENTRY((*i_dlg).m_color_entry));
+  gdk_rgba_parse(&(*io_object).m_color, l_text);
 
-  l_text= gtk_entry_get_text(GTK_ENTRY((*i_textd).m_font_entry));
-  if ((*io_text).m_font)
+  l_text= gtk_entry_get_text(GTK_ENTRY((*i_dlg).m_font_entry));
+  if ((*io_object).m_font)
   {
-    pango_font_description_free((*io_text).m_font);
+    pango_font_description_free((*io_object).m_font);
   }
 
-  (*io_text).m_font= pango_font_description_from_string(l_text);
+  (*io_object).m_font= pango_font_description_from_string(l_text);
 
-  (*io_text).m_rotate= 
+/*
+  (*io_object).m_rotate= 
     gtk_toggle_button_get_active(
-      GTK_TOGGLE_BUTTON((*i_textd).m_rotate_checkbutton));
+      GTK_TOGGLE_BUTTON((*i_dlg).m_rotate_checkbutton));
+*/
 
-  if (0 == (*io_text).m_rotate)
+/*
+  if (0 == (*io_object).m_rotate)
   {
-    (*io_text).m_rotation= 0.0;
-    (*io_text).m_pos_y2= (*io_text).m_pos_y1;
+    (*io_object).m_rotation= 0.0;
+    (*io_object).m_pos_y2= (*io_object).m_pos_y1;
   }
+*/
 
-  (*io_text).m_autowrap= 
+  (*io_object).m_autowrap= 
     gtk_toggle_button_get_active(
-      GTK_TOGGLE_BUTTON((*i_textd).m_autowrap_checkbutton));
+      GTK_TOGGLE_BUTTON((*i_dlg).m_autowrap_checkbutton));
 
-  l_buffer= gtk_text_view_get_buffer((*i_textd).m_text_textview);
+  l_buffer= gtk_text_view_get_buffer((*i_dlg).m_text_textview);
 
   gtk_text_buffer_get_start_iter(l_buffer, &l_start);
   gtk_text_buffer_get_end_iter(l_buffer, &l_end);
@@ -275,31 +178,31 @@ item_text_copy_values(
   l_last= gtk_text_iter_get_offset(&l_end);
   l_size= l_last - l_first;
 
-  if ((*io_text).m_text)
+  if ((*io_object).m_text)
   {
-    g_free((*io_text).m_text);
+    g_free((*io_object).m_text);
   }
 
-  (*io_text).m_text= (char*)g_malloc0(1+l_size);
+  (*io_object).m_text= (char*)g_malloc0(1+l_size);
 
   l_text= gtk_text_buffer_get_text(l_buffer, &l_start, &l_end, 0); 
-  memcpy((*io_text).m_text, l_text, l_size);
-  utf8_scrub_kludge((*io_text).m_text);
+  memcpy((*io_object).m_text, l_text, l_size);
+  utf8_scrub_kludge((*io_object).m_text);
 
   return;
 }
 
 extern int
 item_text_property(
-  struct item_text*const               io_text)
+  struct item_text*const                io_object)
 {
   GtkBox*                               l_box;
   GtkBuilder*                           l_builder;
   GtkDialog*                            l_dialog;
-  GtkBox*                               l_instance;
+  struct text_dialog                    l_dlg;
   GError*                               l_error;
   int                                   l_exit;
-  struct text_dialog                    l_textd;
+  GtkBox*                               l_instance;
   int                                   l_rc;
 
   l_builder= 0;
@@ -332,9 +235,9 @@ item_text_property(
       break;
     }
 
-    item_text_bind(&l_textd, l_builder);
+    item_text_bind(&l_dlg, l_builder);
 
-    item_text_set_values(&l_textd, io_text);
+    item_text_set_values(&l_dlg, io_object);
 
     l_dialog= GTK_DIALOG(gtk_dialog_new_with_buttons(
       "Text Edit",
@@ -363,7 +266,7 @@ item_text_property(
       break;
     }
 
-    item_text_copy_values(io_text, &l_textd);
+    item_text_copy_values(io_object, &l_dlg);
 
   }while(0);
 
