@@ -29,7 +29,14 @@ NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 #include "iwr_page.h"
-#include "iwr_page_menu.h"
+#include "item_selection.h"
+#include "mainw.h"
+
+extern struct mainw*                    g_mainw;
+
+extern GtkMenu*
+iwr_page_menu_new(
+  IwrPage*const                         i_page);
 
 enum key_action_type
 {
@@ -59,9 +66,12 @@ struct _IwrPagePrivate
   enum event_type                       m_sticky;
   double                                m_scale;
   enum iwr_page_drag_type               m_drag_type;
-  int                                   m_horizontal_line_show:1;
-  int                                   m_vertical_line_show:1;
-  int                                   m_highlight_objects:1; 
+  enum item_selection_drag_type         m_drag_level;
+  unsigned                              m_level_debounce:1;
+  unsigned                              m_horizontal_line_show:1;
+  unsigned                              m_vertical_line_show:1;
+  unsigned                              m_highlight_objects:1; 
+  unsigned                              m_cmd_pushed:1;
 };
 
 G_DEFINE_TYPE_WITH_PRIVATE(IwrPage, iwr_page, GTK_TYPE_WIDGET)
@@ -76,20 +86,6 @@ iwr_page_clear(
   return;
 }
 
-extern void
-iwr_page_draw_item(
-  cairo_t*const                         i_cr,
-  IwrPage *const                        io_page,
-  struct item_draw_options const*const  i_option)
-{
-  IwrPagePrivate*                       l_priv; 
-
-  l_priv= (*io_page).m_priv;
-  item_draw(&(*l_priv).m_item, i_cr, i_option);
-
-  return;
-}
-
 extern void
 iwr_page_item_selected_move(
   IwrPage*const                         io_page,
@@ -188,7 +184,7 @@ iwr_page_key_press(
 
     if (GDK_KEY_Delete == (*i_event).keyval)
     {
-      item_selected_remove(&(*l_page).m_priv->m_item);
+      mainw_edit_cut(g_mainw);
       l_redraw= 1;
       break;
     }
@@ -277,7 +273,8 @@ iwr_page_key_press(
   else if (key_action_resize == l_action)
   {
  
-    l_resize.m_event= l_delta;
+    l_resize.m_delta_x= l_delta.m_pos_x;
+    l_resize.m_delta_y= l_delta.m_pos_y;
     l_resize.m_type= l_type;
     item_selected_resize(&(*l_priv).m_item, &l_resize);
     l_redraw= 1;
@@ -401,15 +398,17 @@ iwr_page_button_press(
   GtkWidget*                            i_widget,
   GdkEventButton*                       i_event)
 {
+  cairo_t*                              l_cr;
+  int                                   l_hit;
+  struct item_node*                     l_node;
   IwrPage*                              l_page;
   IwrPagePrivate*                       l_priv; 
-  struct item_node*                     l_node;
   enum event_type                       l_type;
 
+  l_cr = gdk_cairo_create((*i_event).window);
   l_page= IWR_PAGE(i_widget);
   l_priv= (*l_page).m_priv;
   l_node= 0;
-  l_type= event_none;
 
   if (!gtk_widget_has_focus(i_widget))
   {
@@ -424,23 +423,48 @@ iwr_page_button_press(
     (*l_priv).m_event.m_pos_y= (*i_event).y;
     (*l_priv).m_drag_type= drag_type_none;
 
+    l_hit= item_selection_in_event(
+      &l_type,
+      l_cr,
+      &(*l_priv).m_item,
+      &(*l_priv).m_event,
+      (*l_priv).m_scale);
+
     item_node_in_event(
       &l_node,
-      &l_type,
+      l_cr,
       &(*l_priv).m_item,
       &(*l_priv).m_event,
       (*l_priv).m_scale);
 
     if (0 == l_node)
     {
-      item_deselect_all(&(*l_priv).m_item);
+
+      if (l_hit)
+      {
+        (*l_priv).m_drag_type= drag_type_item;
+        (*l_priv).m_sticky= l_type;
+        break;
+      }
+
+      if (0 == (GDK_SHIFT_MASK & (*i_event).state))
+      {
+        item_deselect_all(&(*l_priv).m_item);
+      }
+
       if (section_label != (*l_priv).m_type)
       {
         iwr_page_button_press2(i_widget, i_event);
       }
+
       break;
     }
 
+    if (0 == (*l_node).m_selected)
+    {
+      (*l_priv).m_drag_level= drag_none;
+    }
+
     if (0 == (GDK_SHIFT_MASK & (*i_event).state))
     {
       item_deselect_all(&(*l_priv).m_item);
@@ -459,7 +483,7 @@ iwr_page_button_press(
 
       if (0 == (*l_priv).m_popup)
       {
-        (*l_priv).m_popup= iwr_page_menu_new(&(*l_priv).m_item);
+        (*l_priv).m_popup= iwr_page_menu_new(l_page);
         gtk_widget_show_all(GTK_WIDGET((*l_priv).m_popup));
       }
 
@@ -476,10 +500,11 @@ iwr_page_button_press(
     }
 
     (*l_priv).m_drag_type= drag_type_item;
-    (*l_priv).m_sticky= l_type;
+    (*l_priv).m_sticky= (l_hit) ? l_type : event_move;
 
   }while(0);
 
+  cairo_destroy(l_cr);
   gtk_widget_queue_draw(i_widget);
 
   return 1;
@@ -490,7 +515,6 @@ iwr_page_button_release(
   GtkWidget*                            i_widget,
   GdkEventButton*                       i_event)
 {
-  GtkAllocation                         l_alloc;
   GdkCursor*                            l_cursor;
   IwrPage*                              l_page;
   IwrPagePrivate*                       l_priv; 
@@ -511,11 +535,24 @@ iwr_page_button_release(
 
     if (event_none == (*l_priv).m_sticky)
     {
+      (*l_priv).m_drag_level= drag_none;
       break;
     }
 
-    gtk_widget_get_allocation(i_widget, &l_alloc);
-    item_selected_normalize(&(*l_priv).m_item, l_alloc.width, l_alloc.height);
+    if (0 == (*l_priv).m_level_debounce)
+    {
+      switch((*l_priv).m_drag_level)
+      {
+        case drag_move_resize:
+          (*l_priv).m_drag_level= drag_rotate_shear;
+          break;
+        default:
+          (*l_priv).m_drag_level= drag_move_resize;
+          break;
+      }
+    }
+
+    item_selected_normalize(&(*l_priv).m_item);
 
     l_cursor= gdk_cursor_new_for_display(gdk_display_get_default(), GDK_ARROW);
     gdk_window_set_cursor((*l_priv).m_event_window, l_cursor);
@@ -525,7 +562,9 @@ iwr_page_button_release(
 
   }while(0);
 
+  (*l_priv).m_level_debounce= 0;
   (*l_priv).m_drag_type= drag_type_none;
+  (*l_priv).m_cmd_pushed= 0;
   (*l_priv).m_sticky= event_none;
   (*l_priv).m_event.m_pos_x= (*i_event).x;
   (*l_priv).m_event.m_pos_y= (*i_event).y;
@@ -563,22 +602,109 @@ iwr_page_motion_notify2(
   return 1;
 }
 
+static void
+iwr_page_rotate_selected(
+  IwrPagePrivate*                       i_page,
+  GdkEventMotion*                       i_event)
+{
+  double                                l_center_x;
+  double                                l_center_y;
+  cairo_t*                              l_cr;
+  double                                l_delta_x;
+  double                                l_delta_y;
+  double                                l_rotation;
+  int                                   l_count;
+  struct geom_rect                      l_bbox;
+
+  l_cr = gdk_cairo_create((*i_event).window);
+
+  do
+  {
+
+    l_count= item_selection_get_bbox(&l_bbox, l_cr, (*i_page).m_scale, &(*i_page).m_item);
+
+    if (0 == l_count)
+    {
+      break;
+    }
+
+    l_center_x= l_bbox.m_pos_x + (l_bbox.m_len_x / 2.0);
+    l_center_y= l_bbox.m_pos_y + (l_bbox.m_len_y / 2.0);
+    l_delta_x= l_center_x - (*i_event).x;
+    l_delta_y= l_center_y - (*i_event).y;
+    l_rotation= (atan2(l_delta_y, l_delta_x) * 180.0) / G_PI;
+
+    if (0.0 > l_rotation)
+    {
+      l_rotation= 360.0 + l_rotation;
+    }
+
+    item_selected_rotate(&(*i_page).m_item, l_rotation);
+
+  }while(0);
+
+  cairo_destroy(l_cr);
+
+  return;
+}
+
+static void
+iwr_page_cmd_push(
+  GtkWidget*                            i_widget)
+{
+  enum cmd_type                         l_cmd;
+  IwrPagePrivate*                       l_priv; 
+
+  l_priv= IWR_PAGE(i_widget)->m_priv;
+
+  if (event_move == (*l_priv).m_sticky)
+  {
+    l_cmd= cmd_move;
+  }
+  else
+  {
+    if (drag_rotate_shear != (*l_priv).m_drag_level)
+    {
+      l_cmd= cmd_resize;
+    }
+    else
+    {
+      switch((*l_priv).m_sticky)
+      {
+        case event_resize_east: 
+        case event_resize_west:
+        case event_resize_north:
+        case event_resize_south:
+          l_cmd= cmd_shear;
+          break;
+        default:
+          l_cmd= cmd_rotate;
+          break;
+      }
+    }
+  }
+
+  mainw_cmd_push(g_mainw, IWR_PAGE(i_widget), l_cmd);
+
+  return;
+}
+
 static gboolean
 iwr_page_motion_notify(
   GtkWidget*                            i_widget,
   GdkEventMotion*                       i_event)
 {
+  cairo_t*                              l_cr;
   GdkCursor*                            l_cursor;
   struct geom_point                     l_event;
-  struct item_node*                     l_node;
   IwrPage*                              l_page;
   IwrPagePrivate*                       l_priv; 
   struct item_resize_event              l_resize;
   enum event_type                       l_type;
 
+  l_cr = gdk_cairo_create((*i_event).window);
   l_page= IWR_PAGE(i_widget);
   l_priv= (*l_page).m_priv;
-  l_node= 0;
   l_type= event_none;
 
   do
@@ -596,9 +722,9 @@ iwr_page_motion_notify(
     if (drag_type_none == (*l_priv).m_drag_type)
     {
 
-      item_node_in_event(
-        &l_node,
+      item_selection_in_event(
         &l_type,
+        l_cr,
         &(*l_priv).m_item,
         &l_event,
         (*l_priv).m_scale);
@@ -621,10 +747,19 @@ iwr_page_motion_notify(
       g_object_unref(l_cursor);
 
       (*l_priv).m_sticky= l_type;
+      gtk_widget_queue_draw(i_widget);
 
       break;
     }
 
+    if (0 == (*l_priv).m_cmd_pushed)
+    {
+      (*l_priv).m_cmd_pushed= 1;
+      iwr_page_cmd_push(i_widget);
+    }
+
+    (*l_priv).m_level_debounce= 1;
+
     l_event.m_pos_x= ((*i_event).x - (*l_priv).m_event.m_pos_x);
     l_event.m_pos_y= ((*i_event).y - (*l_priv).m_event.m_pos_y);
     l_event.m_pos_x*= (1.00 / (*l_priv).m_scale);
@@ -636,15 +771,37 @@ iwr_page_motion_notify(
     }
     else
     {
-      l_resize.m_event= l_event;
-      l_resize.m_type= (*l_priv).m_sticky;
-      item_selected_resize(&(*l_priv).m_item, &l_resize);
+      if (drag_rotate_shear != (*l_priv).m_drag_level)
+      {
+        l_resize.m_delta_x= l_event.m_pos_x;
+        l_resize.m_delta_y= l_event.m_pos_y;
+        l_resize.m_type= (*l_priv).m_sticky;
+        item_selected_resize(&(*l_priv).m_item, &l_resize);
+      }
+      else
+      {
+        switch((*l_priv).m_sticky)
+        {
+          case event_resize_east: 
+          case event_resize_west:
+            item_selected_shear(&(*l_priv).m_item, 0.0, l_event.m_pos_y);
+            break;
+          case event_resize_north:
+          case event_resize_south:
+            item_selected_shear(&(*l_priv).m_item, l_event.m_pos_x, 0.0);
+            break;
+          default:
+            iwr_page_rotate_selected(l_priv, i_event);
+            break;
+        }
+      }
     }
 
     gtk_widget_queue_draw(i_widget);
 
   }while(0);
 
+  cairo_destroy(l_cr);
   (*l_priv).m_event.m_pos_x= (*i_event).x;
   (*l_priv).m_event.m_pos_y= (*i_event).y;
 
@@ -727,7 +884,7 @@ iwr_page_realize(
     GDK_BUTTON_RELEASE_MASK|
     GDK_ENTER_NOTIFY_MASK);
 
-  l_win= gtk_widget_get_window(i_widget),
+  l_win= gtk_widget_get_parent_window(i_widget);
   (*l_priv).m_event_window= gdk_window_new(l_win, &l_attr, l_attr_mask);
   gtk_widget_register_window(i_widget, (*l_priv).m_event_window);
 
@@ -900,6 +1057,7 @@ iwr_page_draw(
 
   l_has_focus= gtk_widget_has_focus(i_widget);
 
+  cairo_new_path(io_cr);
   cairo_save(io_cr);
   cairo_scale(io_cr, (*l_priv).m_scale, (*l_priv).m_scale);
 
@@ -996,11 +1154,19 @@ iwr_page_draw(
     }while(1);
   }
 
+  cairo_restore(io_cr);
+
   l_option.m_type= item_draw_design;
   l_option.m_highlight= (*l_priv).m_highlight_objects;
-  item_draw(&(*l_priv).m_item, io_cr, &l_option);
+  item_draw(&(*l_priv).m_item, io_cr, (*l_priv).m_scale, &l_option);
 
-  cairo_restore(io_cr);
+  item_selection_draw(
+    io_cr,
+    &(*l_priv).m_item,
+    (*l_priv).m_scale,
+    (*l_priv).m_drag_level,
+    (drag_type_item == (*l_priv).m_drag_type),
+    (*l_priv).m_sticky);
 
   return 0;
 }
@@ -1150,12 +1316,6 @@ iwr_page_set_paper(
 
   l_priv= (*io_page).m_priv;
 
-  if ((*l_priv).m_paper.m_width > (*i_paper).m_width ||
-    (*l_priv).m_paper.m_height > (*i_paper).m_height)
-  {
-    item_normalize(&(*l_priv).m_item, (*i_paper).m_width, (*i_paper).m_height);
-  }
-
   memcpy(&(*l_priv).m_paper, i_paper, sizeof(*i_paper));
 
   gtk_widget_queue_resize(GTK_WIDGET(io_page));
