@@ -173,19 +173,19 @@ label_paper_read(
 
 extern void
 label_paper_set_defaults(
-  struct label_paper*const              io_paper)
+  struct label_paper*const              o_paper)
 {
 
-  /* todo: fixme with actual label dimensions */
+  /* _mjo TODO: fixme with actual label dimensions */
 
-  (*io_paper).m_page_width= 3.95;
-  (*io_paper).m_page_height= 3.95;
-  (*io_paper).m_horizontal_pitch= 3.95;
-  (*io_paper).m_vertical_pitch= 3.95;
-  (*io_paper).m_label_width= 3.94;
-  (*io_paper).m_label_height= 3.94;
-  (*io_paper).m_columns= 1;
-  (*io_paper).m_rows= 1;
+  (*o_paper).m_page_width= 3.95;
+  (*o_paper).m_page_height= 3.95;
+  (*o_paper).m_horizontal_pitch= 3.95;
+  (*o_paper).m_vertical_pitch= 3.95;
+  (*o_paper).m_label_width= 3.94;
+  (*o_paper).m_label_height= 3.94;
+  (*o_paper).m_columns= 1;
+  (*o_paper).m_rows= 1;
 
   return;
 }
