@@ -116,7 +116,7 @@ label_run_loop(
   l_row= 0;
   l_time1= g_get_monotonic_time();
 
-  rw_item_clear_accumulator(&(*io_label).m_report.m_item);
+  rw_item_clear_accumulator(&(*io_label).m_report.m_item, 0);
 
   (*io_dialog).m_tuple= 1;
 
@@ -129,7 +129,7 @@ label_run_loop(
     rw_item_set_value(&(*io_label).m_report.m_item, io_rw);
     cairo_save((*io_rw).m_cr);
     cairo_translate((*io_rw).m_cr, (*io_rw).m_pos_x, (*io_rw).m_pos_y);
-    item_draw(&(*io_label).m_report.m_item, (*io_rw).m_cr, 0);
+    item_draw(&(*io_label).m_report.m_item, (*io_rw).m_cr, 1.0, 0);
     cairo_restore((*io_rw).m_cr);
 
     l_col++;
