@@ -75,7 +75,7 @@ layout_add_default_sections(
   gtk_widget_set_sensitive(l_widget, 0);
   l_page= IWR_PAGE(iwr_page_new());
   (*io_layout).m_report.m_header.m_page= l_page;
-  g_strlcpy((*io_layout).m_report.m_header.m_tag, "Report.Header", sizeof((*io_layout).m_report.m_header.m_tag));
+  (*io_layout).m_report.m_header.m_label= g_strdup("Report.Header");
   iwr_page_set_section_type(l_page, section_report_header);
   l_paper.m_height= POINTS_PER_INCH * 1.5;
   iwr_page_set_paper(l_page, &l_paper);
@@ -88,7 +88,7 @@ layout_add_default_sections(
   gtk_widget_set_sensitive(l_widget, 0);
   l_page= IWR_PAGE(iwr_page_new());
   (*io_layout).m_report.m_detail.m_page= l_page;
-  g_strlcpy((*io_layout).m_report.m_detail.m_tag, "Report.Detail", sizeof((*io_layout).m_report.m_detail.m_tag));
+  (*io_layout).m_report.m_detail.m_label= g_strdup("Report.Detail");
   iwr_page_set_section_type(l_page, section_report_detail);
   l_paper.m_height= POINTS_PER_INCH * 1.5;
   iwr_page_set_paper(l_page, &l_paper);
@@ -101,7 +101,7 @@ layout_add_default_sections(
   gtk_widget_set_sensitive(l_widget, 0);
   l_page= IWR_PAGE(iwr_page_new());
   (*io_layout).m_report.m_footer.m_page= l_page;
-  g_strlcpy((*io_layout).m_report.m_footer.m_tag, "Report.Footer", sizeof((*io_layout).m_report.m_footer.m_tag));
+  (*io_layout).m_report.m_footer.m_label= g_strdup("Report.Footer");
   iwr_page_set_section_type(l_page, section_report_footer);
   l_paper.m_height= POINTS_PER_INCH * 1.0;
   iwr_page_set_paper(l_page, &l_paper);
@@ -128,119 +128,6 @@ layout_add_default_sections(
   return;
 }
 
-extern void
-layout_add_divisions_to_grid(
-  struct layout*const                   io_layout)
-{
-  IwrPage*                              l_page;
-  unsigned                              l_row;
-  unsigned                              l_slot;
-  GtkWidget*                            l_widget;
-
-  l_row= 0;
-
-  l_page= (*io_layout).m_cover.m_header.m_page;
-  if (l_page)
-  {
-    l_widget= gtk_button_new_with_label((*io_layout).m_cover.m_header.m_tag);
-    gtk_button_set_relief(GTK_BUTTON(l_widget), GTK_RELIEF_NONE);
-    gtk_widget_set_sensitive(l_widget, 0);
-    gtk_grid_attach((*io_layout).m_grid, l_widget, 0, l_row++, 1, 1);
-    gtk_grid_attach((*io_layout).m_grid, GTK_WIDGET(l_page), 0, l_row++, 1, 1);
-    g_signal_connect(l_page, "size-allocate", G_CALLBACK(layout_division_size_allocate_cb), io_layout);
-  }
-
-  l_page= (*io_layout).m_cover.m_footer.m_page;
-  if (l_page)
-  {
-    l_widget= gtk_button_new_with_label((*io_layout).m_cover.m_footer.m_tag);
-    gtk_button_set_relief(GTK_BUTTON(l_widget), GTK_RELIEF_NONE);
-    gtk_widget_set_sensitive(l_widget, 0);
-    gtk_grid_attach((*io_layout).m_grid, l_widget, 0, l_row++, 1, 1);
-    gtk_grid_attach((*io_layout).m_grid, GTK_WIDGET(l_page), 0, l_row++, 1, 1);
-    g_signal_connect(l_page, "size-allocate", G_CALLBACK(layout_division_size_allocate_cb), io_layout);
-  }
-
-  l_page= (*io_layout).m_report.m_header.m_page;
-  if (l_page)
-  {
-    l_widget= gtk_button_new_with_label((*io_layout).m_report.m_header.m_tag);
-    gtk_button_set_relief(GTK_BUTTON(l_widget), GTK_RELIEF_NONE);
-    gtk_widget_set_sensitive(l_widget, 0);
-    gtk_grid_attach((*io_layout).m_grid, l_widget, 0, l_row++, 1, 1);
-    gtk_grid_attach((*io_layout).m_grid, GTK_WIDGET(l_page), 0, l_row++, 1, 1);
-    g_signal_connect(l_page, "size-allocate", G_CALLBACK(layout_division_size_allocate_cb), io_layout);
-  }
-
-  for (l_slot= 0; (*io_layout).m_group_slots > l_slot; l_slot++)
-  {
-    l_page= (*io_layout).m_group[l_slot].m_header.m_page;
-    l_widget= gtk_button_new_with_label((*io_layout).m_group[l_slot].m_header.m_tag);
-    gtk_button_set_relief(GTK_BUTTON(l_widget), GTK_RELIEF_NONE);
-    gtk_widget_set_sensitive(l_widget, 0);
-    gtk_grid_attach((*io_layout).m_grid, l_widget, 0, l_row++, 1, 1);
-    gtk_grid_attach((*io_layout).m_grid, GTK_WIDGET(l_page), 0, l_row++, 1, 1);
-    g_signal_connect(l_page, "size-allocate", G_CALLBACK(layout_division_size_allocate_cb), io_layout);
-  }
-
-  l_page= (*io_layout).m_report.m_detail.m_page;
-  if (l_page)
-  {
-    l_widget= gtk_button_new_with_label((*io_layout).m_report.m_detail.m_tag);
-    gtk_button_set_relief(GTK_BUTTON(l_widget), GTK_RELIEF_NONE);
-    gtk_widget_set_sensitive(l_widget, 0);
-    gtk_grid_attach((*io_layout).m_grid, l_widget, 0, l_row++, 1, 1);
-    gtk_grid_attach((*io_layout).m_grid, GTK_WIDGET(l_page), 0, l_row++, 1, 1);
-    g_signal_connect(l_page, "size-allocate", G_CALLBACK(layout_division_size_allocate_cb), io_layout);
-  }
-
-  l_slot= (*io_layout).m_group_slots;
-
-  do
-  {
-
-    if (0 == l_slot)
-    {
-      break;
-    }
-
-    l_slot--;
-
-    l_page= (*io_layout).m_group[l_slot].m_footer.m_page;
-    l_widget= gtk_button_new_with_label((*io_layout).m_group[l_slot].m_footer.m_tag);
-    gtk_button_set_relief(GTK_BUTTON(l_widget), GTK_RELIEF_NONE);
-    gtk_widget_set_sensitive(l_widget, 0);
-    gtk_grid_attach((*io_layout).m_grid, l_widget, 0, l_row++, 1, 1);
-    gtk_grid_attach((*io_layout).m_grid, GTK_WIDGET(l_page), 0, l_row++, 1, 1);
-    g_signal_connect(l_page, "size-allocate", G_CALLBACK(layout_division_size_allocate_cb), io_layout);
-
-  }while(1);
-
-  l_page= (*io_layout).m_report.m_footer.m_page;
-  if (l_page)
-  {
-    l_widget= gtk_button_new_with_label((*io_layout).m_report.m_footer.m_tag);
-    gtk_button_set_relief(GTK_BUTTON(l_widget), GTK_RELIEF_NONE);
-    gtk_widget_set_sensitive(l_widget, 0);
-    gtk_grid_attach((*io_layout).m_grid, l_widget, 0, l_row++, 1, 1);
-    gtk_grid_attach((*io_layout).m_grid, GTK_WIDGET(l_page), 0, l_row++, 1, 1);
-    g_signal_connect(l_page, "size-allocate", G_CALLBACK(layout_division_size_allocate_cb), io_layout);
-  }
-
-  l_page= (*io_layout).m_cover.m_footer.m_page;
-  if (l_page)
-  {
-    l_widget= gtk_button_new_with_label((*io_layout).m_cover.m_footer.m_tag);
-    gtk_button_set_relief(GTK_BUTTON(l_widget), GTK_RELIEF_NONE);
-    gtk_widget_set_sensitive(l_widget, 0);
-    gtk_grid_attach((*io_layout).m_grid, l_widget, 0, l_row++, 1, 1);
-    gtk_grid_attach((*io_layout).m_grid, GTK_WIDGET(l_page), 0, l_row++, 1, 1);
-    g_signal_connect(l_page, "size-allocate", G_CALLBACK(layout_division_size_allocate_cb), io_layout);
-  }
-
-  return;
-}
-
 extern void
 layout_assign(
   struct layout*const                   o_layout)
@@ -321,11 +208,12 @@ layout_delete_coverheader(
       break;
     }
 
+    (*io_layout).m_cover.m_header.m_page= 0;
+
     gtk_grid_remove_row((*io_layout).m_grid, 0);
     gtk_grid_remove_row((*io_layout).m_grid, 0);
 
     layout_set_layout_size(io_layout);
-    (*io_layout).m_cover.m_header.m_page= 0;
 
   }while(0);
 
@@ -464,6 +352,29 @@ layout_delete_reportheader(
   return;
 }
 
+static void
+layout_division_break_discharge(
+  struct layout_division_break*const    io_break)
+{
+
+  g_free((*io_break).m_column);
+  memset(io_break, 0, sizeof(*io_break));
+
+  return;
+}
+
+static void
+layout_division_discharge(
+  struct layout_division*const          io_div)
+{
+
+  g_free((*io_div).m_label);
+  memset(io_div, 0, sizeof(*io_div));
+
+  return;
+}
+
+
 extern void
 layout_discharge(
   struct layout*const                   io_layout)
@@ -472,11 +383,18 @@ layout_discharge(
 
   paper_discharge(&(*io_layout).m_paper);
 
-  g_free((*io_layout).m_page_break.m_value);
+  layout_division_discharge(&(*io_layout).m_cover.m_header);
+  layout_division_discharge(&(*io_layout).m_cover.m_footer);
+  layout_division_discharge(&(*io_layout).m_report.m_header);
+  layout_division_discharge(&(*io_layout).m_report.m_detail);
+  layout_division_discharge(&(*io_layout).m_report.m_footer);
+  layout_division_break_discharge(&(*io_layout).m_page_break);
 
   for (l_slot= 0; (*io_layout).m_group_slots > l_slot; l_slot++)
   {
-    g_free((*io_layout).m_group[l_slot].m_break.m_value);
+    layout_division_break_discharge(&(*io_layout).m_group[l_slot].m_break);
+    layout_division_discharge(&(*io_layout).m_group[l_slot].m_header);
+    layout_division_discharge(&(*io_layout).m_group[l_slot].m_footer);
   }
 
   gtk_widget_destroy(GTK_WIDGET((*io_layout).m_window));
@@ -788,7 +706,7 @@ layout_new_coverfooter(
     gtk_widget_set_sensitive(l_widget, 0);
     l_page= IWR_PAGE(iwr_page_new());
     (*io_layout).m_cover.m_footer.m_page= l_page;
-    g_strlcpy((*io_layout).m_cover.m_footer.m_tag, "Cover.Footer", sizeof((*io_layout).m_cover.m_footer.m_tag));
+    (*io_layout).m_cover.m_footer.m_label= g_strdup("Cover.Footer");
     iwr_page_set_section_type(l_page, section_cover_footer);
     iwr_page_set_paper(l_page, &(*io_layout).m_paper);
     gtk_grid_attach((*io_layout).m_grid, l_widget, 0, l_row++, 1, 1);
@@ -824,7 +742,7 @@ layout_new_coverheader(
     gtk_widget_set_sensitive(l_widget, 0);
     l_page= IWR_PAGE(iwr_page_new());
     (*io_layout).m_cover.m_header.m_page= l_page;
-    g_strlcpy((*io_layout).m_cover.m_header.m_tag, "Cover.Header", sizeof((*io_layout).m_cover.m_header.m_tag));
+    (*io_layout).m_cover.m_header.m_label= g_strdup("Cover.Header");
     iwr_page_set_section_type(l_page, section_cover_header);
     iwr_page_set_paper(l_page, &(*io_layout).m_paper);
     gtk_grid_insert_row((*io_layout).m_grid, 0);
@@ -880,7 +798,7 @@ layout_new_reportdetail(
     gtk_widget_set_sensitive(l_widget, 0);
     l_page= IWR_PAGE(iwr_page_new());
     (*io_layout).m_report.m_detail.m_page= l_page;
-    g_strlcpy((*io_layout).m_report.m_detail.m_tag, "Report.Detail", sizeof((*io_layout).m_report.m_detail.m_tag));
+    (*io_layout).m_report.m_detail.m_label= g_strdup("Report.Detail");
     iwr_page_set_section_type(l_page, section_report_detail);
     l_paper.m_height= POINTS_PER_INCH * 1.5;
     iwr_page_set_paper(l_page, &l_paper);
@@ -947,7 +865,7 @@ layout_new_reportfooter(
     gtk_widget_set_sensitive(l_widget, 0);
     l_page= IWR_PAGE(iwr_page_new());
     (*io_layout).m_report.m_footer.m_page= l_page;
-    g_strlcpy((*io_layout).m_report.m_footer.m_tag, "Report.Footer", sizeof((*io_layout).m_report.m_footer.m_tag));
+    (*io_layout).m_report.m_footer.m_label= g_strdup("Report.Footer");
     l_paper.m_height= POINTS_PER_INCH * 1.0;
     iwr_page_set_section_type(l_page, section_report_footer);
     iwr_page_set_paper(l_page, &l_paper);
@@ -996,7 +914,7 @@ layout_new_reportheader(
     gtk_widget_set_sensitive(l_widget, 0);
     l_page= IWR_PAGE(iwr_page_new());
     (*io_layout).m_report.m_header.m_page= l_page;
-    g_strlcpy((*io_layout).m_report.m_header.m_tag, "Report.Header", sizeof((*io_layout).m_report.m_header.m_tag));
+    (*io_layout).m_report.m_header.m_label= g_strdup("Report.Header");
     iwr_page_set_section_type(l_page, section_report_header);
     l_paper.m_height= POINTS_PER_INCH * 1.5;
     iwr_page_set_paper(l_page, &l_paper);
@@ -1458,7 +1376,7 @@ layout_write_division(
     }
 
     fprintf(io_fp, "\t\t<section name=\"%s\" type=\"%s\">\n", 
-      (*i_division).m_tag,
+      (*i_division).m_label,
       l_text);
 
     iwr_page_get_paper(&l_paper, (*i_division).m_page); 
@@ -1551,7 +1469,7 @@ layout_write_group(
   do
   {
 
-    fprintf(io_fp, "\t\t<group name=\"%s\">\n", (*i_group).m_break.m_tag);
+    fprintf(io_fp, "\t\t<group name=\"%s\">\n", (*i_group).m_break.m_column);
     
     l_exit= layout_write_division(o_error, io_fp, &(*i_group).m_header);
 
@@ -1591,10 +1509,10 @@ layout_write_groups(
 
     fprintf(io_fp, "\t<groups>\n");
 
-    if ((*i_layout).m_page_break.m_tag[0])
+    if ((*i_layout).m_page_break.m_column)
     {
       fprintf(io_fp, "\t\t<page_break>%s</page_break>\n",
-        (*i_layout).m_page_break.m_tag);
+        (*i_layout).m_page_break.m_column);
     }
 
     l_group= &(*i_layout).m_group[0];
