@@ -30,8 +30,39 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 #ifndef __layout_h__
 
+#include "iwr_page.h"
 #include "paper.h"
-#include "layout_division.h"
+
+struct layout_division
+{
+  char*                                 m_label;
+  IwrPage*                              m_page;
+};
+
+struct layout_division_cover
+{
+  struct layout_division                m_header;
+  struct layout_division                m_footer;
+};
+
+struct layout_division_report
+{
+  struct layout_division                m_header;
+  struct layout_division                m_detail;
+  struct layout_division                m_footer;
+};
+
+struct layout_division_break
+{
+  char*                                 m_column;
+};
+
+struct layout_division_group
+{
+  struct layout_division_break          m_break;
+  struct layout_division                m_header;
+  struct layout_division                m_footer;
+};
 
 struct layout
 {
@@ -51,10 +82,6 @@ extern void
 layout_add_default_sections(
   struct layout*const                   io_layout);
 
-extern void
-layout_add_divisions_to_grid(
-  struct layout*const                   io_layout);
-
 extern void
 layout_assign(
   struct layout*const                   o_layout);
@@ -98,6 +125,10 @@ layout_item_new(
   struct layout*const                   io_layout,
   enum item_type const                  i_type);
 
+extern IwrPage*
+layout_get_focused_page(
+  struct layout*const                   io_layout);
+
 extern GtkWidget*
 layout_gui_new(
   struct layout*const                   io_layout);
