@@ -79,18 +79,33 @@ layout_spec_sync_paper(
   return;
 }
 
+static void
+layout_spec_division_break_discharge(
+  struct layout_spec_division_break*    io_break)
+{
+
+  g_free((*io_break).m_column);
+  g_free((*io_break).m_value);
+  memset(io_break, 0, sizeof(*io_break));
+
+  return;
+}
+
 static void
 layout_spec_division_discharge(
   struct layout_spec_division*const     o_div)
 {
 
-  if (o_div && (*o_div).m_item)
+  g_free((*o_div).m_label);
+
+  if ((*o_div).m_item)
   {
     item_discharge((*o_div).m_item);
     g_free((*o_div).m_item);
-    paper_discharge(&(*o_div).m_paper);
   }
 
+  paper_discharge(&(*o_div).m_paper);
+
   memset(o_div, 0, sizeof(*o_div));
 
   return;
@@ -115,6 +130,8 @@ layout_spec_discharge(
 
   for (l_slot= 0; (*io_layout).m_group_slots > l_slot; l_slot++)
   {
+    layout_spec_division_break_discharge(&(*io_layout).m_group[l_slot].m_break);
+
     layout_spec_division_discharge(&(*io_layout).m_group[l_slot].m_header);
     layout_spec_division_discharge(&(*io_layout).m_group[l_slot].m_footer);
   }
@@ -360,7 +377,7 @@ layout_spec_read_division(
       break;
     }
 
-    g_strlcpy((*l_division).m_tag, l_attr_name, sizeof((*l_division).m_tag));
+    (*l_division).m_label= g_strdup(l_attr_name);
 
     l_exit= layout_spec_read_section(&l_error, l_division, l_xml);
 
@@ -488,7 +505,7 @@ layout_spec_read_group(
       break;
     }
 
-    g_strlcpy((*l_division).m_tag, l_attr_name, sizeof((*l_division).m_tag));
+    (*l_division).m_label= g_strdup(l_attr_name);
 
     l_exit= layout_spec_read_section(&l_error, l_division, l_xml);
 
@@ -545,7 +562,7 @@ layout_spec_read_groups(
 
       if (0 == l_rc)
       {
-        g_strlcpy((*io_layout).m_page_break.m_tag, l_value, sizeof((*io_layout).m_page_break.m_tag));
+        (*io_layout).m_page_break.m_column= g_strdup(l_value);
         break;
       }
 
@@ -581,10 +598,9 @@ layout_spec_read_groups(
       for(l_slot= 0; (*io_layout).m_group_slots > l_slot; l_slot++)
       {
 
-        l_found= (0 == strncmp(
-          (*io_layout).m_group[l_slot].m_break.m_tag,
-          l_attr_name,
-          sizeof((*io_layout).m_group[l_slot].m_break.m_tag)));
+        l_found= (0 == g_strcmp0(
+          (*io_layout).m_group[l_slot].m_break.m_column,
+          l_attr_name));
 
         if (l_found)
         {
@@ -614,10 +630,7 @@ layout_spec_read_groups(
       memset(l_group, 0, sizeof(*l_group));
       (*io_layout).m_group_slots++;
 
-      g_strlcpy(
-        (*l_group).m_break.m_tag, 
-        l_attr_name,
-        sizeof((*l_group).m_break.m_tag));
+      (*l_group).m_break.m_column= g_strdup(l_attr_name);
 
       l_exit= layout_spec_read_group(&l_error, l_group, l_xml);
 
