@@ -29,6 +29,7 @@ NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 #include "mainw.h"
+#include "handles.h"
 #include "option.h"
 #include "goop.h"
 #include "report_util.h"
@@ -178,8 +179,10 @@ main(
       l_exit= -1;
       break;
     }
-    
+
+    handles_new();
     l_exit= main_run_gui(i_argc, i_argv, &l_option);
+    handles_delete();
 
   }while(0);
 
