@@ -29,6 +29,7 @@ NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 #include "menu.h"
+#include "layout.h"
 
 #define WINDOW_WIDTH                    612
 #define WINDOW_HEIGHT                   640
@@ -63,17 +64,72 @@ mainw_size_allocate(
   return;
 }
 
+extern void
+mainw_size_allocate_hack(
+  struct mainw*const                    io_mainw)
+{
+  GtkAllocation                         l_alloc;
+  GtkRequisition                        l_min;
+  GtkRequisition                        l_nat;
+
+  gtk_widget_get_preferred_size(GTK_WIDGET((*io_mainw).m_grid), &l_min, &l_nat);
+  gtk_widget_get_allocation(GTK_WIDGET((*io_mainw).m_window), &l_alloc);
+  g_signal_emit_by_name((*io_mainw).m_window, "size-allocate", &l_alloc, 0);
+
+  return;
+}
+
 extern void
 mainw_assign(
   struct mainw*const                    o_mainw)
 {
 
   memset(o_mainw, 0, sizeof(*o_mainw));
+  copybuf_assign(&(*o_mainw).m_copybuf);
+  cmd_assign(&(*o_mainw).m_cmd);
   report_assign(&(*o_mainw).m_report);
 
   return;
 }
 
+extern void
+mainw_cmd_push(
+  struct mainw*const                    io_mainw,
+  IwrPage*                              io_page,
+  enum cmd_type const                   i_type)
+{
+
+  cmd_push(&(*io_mainw).m_cmd, io_page, i_type);
+  mainw_edit_set_menu_state(io_mainw);
+
+  return;
+}
+
+extern void
+mainw_cmd_push_create(
+  struct mainw*const                    io_mainw)
+{
+  IwrPage *                             l_page;
+
+  l_page= 0;
+
+  if (style_label == (*io_mainw).m_report.m_style)
+  {
+    l_page= (*io_mainw).m_report.m_object.m_label.m_page; 
+  }
+  else if (style_layout == (*io_mainw).m_report.m_style) 
+  {
+    l_page= layout_get_focused_page(&(*io_mainw).m_report.m_object.m_layout);
+  }
+
+  if (l_page)
+  {
+    mainw_cmd_push(io_mainw, l_page, cmd_create);
+  }
+
+  return;
+}
+
 extern int
 mainw_create(
   struct mainw*const                    io_mainw)
@@ -120,7 +176,7 @@ mainw_create(
       break;
     }
 
-    menu_layout_bind(l_builder, io_mainw);
+    menu_bind(l_builder, io_mainw);
     menu_layout_set_defaults();
 
     (*io_mainw).m_grid= GTK_GRID(gtk_builder_get_object(l_builder, "grid1"));
@@ -191,7 +247,7 @@ mainw_create_default_layout(
   gtk_widget_get_allocation(GTK_WIDGET((*io_mainw).m_window), &l_alloc);
   g_signal_emit_by_name((*io_mainw).m_window, "size-allocate", &l_alloc, 0);
 
-  return;
+  return 0;
 }
 
 void
@@ -204,18 +260,155 @@ mainw_discharge(
     gtk_widget_destroy(GTK_WIDGET((*io_mainw).m_window));
   }
 
+  copybuf_discharge(&(*io_mainw).m_copybuf);
+  cmd_discharge(&(*io_mainw).m_cmd);
   report_discharge(&(*io_mainw).m_report);
   memset(io_mainw, 0, sizeof(*io_mainw));
 
   return;
 }
 
+extern void
+mainw_edit_clear(
+  struct mainw*const                    io_mainw)
+{
+
+  /*copybuf_clear(&(*io_mainw).m_copybuf);*/
+  cmd_clear(&(*io_mainw).m_cmd);
+  mainw_edit_set_menu_state(io_mainw);
+
+  return;
+}
+
+extern void
+mainw_edit_copy(
+  struct mainw*const                    io_mainw)
+{
+  struct item *                         l_item;
+  IwrPage *                             l_page;
+
+  l_page= 0;
+  copybuf_clear(&(*io_mainw).m_copybuf);
+
+  if (style_label == (*io_mainw).m_report.m_style)
+  {
+    l_page= (*io_mainw).m_report.m_object.m_label.m_page; 
+  }
+  else if (style_layout == (*io_mainw).m_report.m_style) 
+  {
+    l_page= layout_get_focused_page(&(*io_mainw).m_report.m_object.m_layout);
+  }
+
+  if (l_page)
+  {
+    iwr_page_get_item(&l_item, l_page);
+    copybuf_copy_item_selected(&(*io_mainw).m_copybuf, l_item);
+  }
+
+  return;
+}
+
+extern void
+mainw_edit_cut(
+  struct mainw*const                    io_mainw)
+{
+  struct item *                         l_item;
+  IwrPage *                             l_page;
+
+  l_page= 0;
+  copybuf_clear(&(*io_mainw).m_copybuf);
+
+  if (style_label == (*io_mainw).m_report.m_style)
+  {
+    l_page= (*io_mainw).m_report.m_object.m_label.m_page; 
+  }
+  else if (style_layout == (*io_mainw).m_report.m_style) 
+  {
+    l_page= layout_get_focused_page(&(*io_mainw).m_report.m_object.m_layout);
+  }
+
+  if (l_page)
+  {
+    iwr_page_get_item(&l_item, l_page);
+    copybuf_copy_item_selected(&(*io_mainw).m_copybuf, l_item);
+    mainw_cmd_push(io_mainw, l_page, cmd_delete);
+    gtk_widget_queue_draw(GTK_WIDGET(l_page));
+  }
+
+  return;
+}
+
+extern void
+mainw_edit_paste(
+  struct mainw*const                    io_mainw)
+{
+  struct item *                         l_item;
+  IwrPage *                             l_page;
+
+  l_page= 0;
+
+  if (style_label == (*io_mainw).m_report.m_style)
+  {
+    l_page= (*io_mainw).m_report.m_object.m_label.m_page; 
+  }
+  else if (style_layout == (*io_mainw).m_report.m_style)
+  {
+    l_page= layout_get_focused_page(&(*io_mainw).m_report.m_object.m_layout);
+  }
+
+  if (l_page)
+  {
+    iwr_page_get_item(&l_item, l_page);
+    copybuf_paste_item_selected(l_item, &(*io_mainw).m_copybuf);
+    mainw_cmd_push(io_mainw, l_page, cmd_paste); 
+    gtk_widget_queue_draw(GTK_WIDGET(l_page));
+  }
+
+  return;
+}
+
+extern void
+mainw_edit_redo(
+  struct mainw*const                    io_mainw)
+{
+
+  cmd_redo(&(*io_mainw).m_cmd);
+  mainw_edit_set_menu_state(io_mainw);
+
+  return;
+}
+
+extern void
+mainw_edit_set_menu_state(
+  struct mainw*const                    io_mainw)
+{
+  char const*                           l_label;
+
+  l_label= cmd_get_undo_label(&(*io_mainw).m_cmd);
+  menu_edit_undo_set_state(l_label);
+
+  l_label= cmd_get_redo_label(&(*io_mainw).m_cmd);
+  menu_edit_redo_set_state(l_label);
+
+  return;
+}
+
+extern void
+mainw_edit_undo(
+  struct mainw*const                    io_mainw)
+{
+
+  cmd_undo(&(*io_mainw).m_cmd);
+  mainw_edit_set_menu_state(io_mainw);
+
+  return;
+}
+
 extern int
 mainw_open(
   struct mainw*const                    io_mainw,
   char const*                           i_reportfile)
 {
-  GtkAllocation                         l_alloc;
   GtkDialog*                            l_dialog;
   GError*                               l_error;
   int                                   l_exit;
@@ -266,8 +459,7 @@ mainw_open(
             G_CALLBACK(mainw_size_allocate),
             io_mainw);
         }
-        gtk_widget_get_allocation(GTK_WIDGET((*io_mainw).m_window), &l_alloc);
-        g_signal_emit_by_name((*io_mainw).m_window, "size-allocate", &l_alloc, 0);
+        mainw_size_allocate_hack(io_mainw); 
         break;
       case style_export:
         menu_export_set_defaults();
@@ -292,8 +484,7 @@ mainw_open(
             G_CALLBACK(mainw_size_allocate),
             io_mainw);
         }
-        gtk_widget_get_allocation(GTK_WIDGET((*io_mainw).m_window), &l_alloc);
-        g_signal_emit_by_name((*io_mainw).m_window, "size-allocate", &l_alloc, 0);
+        mainw_size_allocate_hack(io_mainw); 
         break;
       default:
         break;
