@@ -68,13 +68,11 @@ break_menuitem_activate_cb(
   gpointer                              i_user_data)
 {
   struct mainw*                         l_mainw;
-  GtkAllocation                         l_alloc;
 
   l_mainw= (struct mainw*)i_user_data;
   layout_break_property(&(*l_mainw).m_report.m_object.m_layout);
 
-  gtk_widget_get_allocation(GTK_WIDGET((*l_mainw).m_window), &l_alloc);
-  g_signal_emit_by_name((*l_mainw).m_window, "size-allocate", &l_alloc, 0);
+  mainw_size_allocate_hack(l_mainw);
 
   return;
 }
@@ -88,6 +86,33 @@ circle_menuitem_activate_cb(
 
   l_mainw= (struct mainw*)i_user_data;
   report_item_new(&(*l_mainw).m_report, item_type_circle);
+  mainw_cmd_push_create(l_mainw);
+
+  return;
+}
+
+G_MODULE_EXPORT void
+copy_menuitem_activate_cb(
+  GtkMenuItem *                         i_menuitem,
+  gpointer                              i_user_data)
+{
+  struct mainw*                         l_mainw;
+
+  l_mainw= (struct mainw*)i_user_data;
+  mainw_edit_copy(l_mainw);
+
+  return;
+}
+
+G_MODULE_EXPORT void
+cut_menuitem_activate_cb(
+  GtkMenuItem *                         i_menuitem,
+  gpointer                              i_user_data)
+{
+  struct mainw*                         l_mainw;
+
+  l_mainw= (struct mainw*)i_user_data;
+  mainw_edit_cut(l_mainw);
 
   return;
 }
@@ -110,8 +135,11 @@ coverfooter_menuitem_toggled_cb(
   else
   {
     layout_delete_coverfooter(&(*l_mainw).m_report.m_object.m_layout);
+    mainw_edit_clear(l_mainw);
   }
 
+  mainw_size_allocate_hack(l_mainw);
+
   return;
 }
 
@@ -133,8 +161,11 @@ coverheader_menuitem_toggled_cb(
   else
   {
     layout_delete_coverheader(&(*l_mainw).m_report.m_object.m_layout);
+    mainw_edit_clear(l_mainw);
   }
 
+  mainw_size_allocate_hack(l_mainw);
+
   return;
 }
 
@@ -154,6 +185,7 @@ export_menuitem_activate_cb(
     (*l_mainw).m_size_allocate_handle= 0;
   }
 
+  mainw_edit_clear(l_mainw);
   report_discharge(&(*l_mainw).m_report);
   report_assign_export(&(*l_mainw).m_report);
 
@@ -164,6 +196,7 @@ export_menuitem_activate_cb(
   menu_export_set_defaults();
 
   gtk_widget_show_all(GTK_WIDGET((*l_mainw).m_paned));
+  gtk_widget_queue_resize(GTK_WIDGET((*l_mainw).m_window));
 
   return;
 }
@@ -199,6 +232,7 @@ datetime_menuitem_activate_cb(
 
   l_mainw= (struct mainw*)i_user_data;
   report_item_new(&(*l_mainw).m_report, item_type_date);
+  mainw_cmd_push_create(l_mainw);
 
   return;
 }
@@ -212,6 +246,7 @@ fbarcode_menuitem_activate_cb(
 
   l_mainw= (struct mainw*)i_user_data;
   report_item_new(&(*l_mainw).m_report, item_type_fbarcode);
+  mainw_cmd_push_create(l_mainw);
 
   return;
 }
@@ -225,6 +260,7 @@ fimage_menuitem_activate_cb(
 
   l_mainw= (struct mainw*)i_user_data;
   report_item_new(&(*l_mainw).m_report, item_type_fimage);
+  mainw_cmd_push_create(l_mainw);
 
   return;
 }
@@ -238,6 +274,7 @@ fnumber_menuitem_activate_cb(
 
   l_mainw= (struct mainw*)i_user_data;
   report_item_new(&(*l_mainw).m_report, item_type_fnumber);
+  mainw_cmd_push_create(l_mainw);
 
   return;
 }
@@ -251,6 +288,7 @@ frame_menuitem_activate_cb(
 
   l_mainw= (struct mainw*)i_user_data;
   report_item_new(&(*l_mainw).m_report, item_type_frame);
+  mainw_cmd_push_create(l_mainw);
 
   return;
 }
@@ -264,6 +302,7 @@ ftext_menuitem_activate_cb(
 
   l_mainw= (struct mainw*)i_user_data;
   report_item_new(&(*l_mainw).m_report, item_type_ftext);
+  mainw_cmd_push_create(l_mainw);
 
   return;
 }
@@ -292,6 +331,7 @@ image_menuitem_activate_cb(
 
   l_mainw= (struct mainw*)i_user_data;
   report_item_new(&(*l_mainw).m_report, item_type_image);
+  mainw_cmd_push_create(l_mainw);
 
   return;
 }
@@ -305,6 +345,7 @@ line_menuitem_activate_cb(
 
   l_mainw= (struct mainw*)i_user_data;
   report_item_new(&(*l_mainw).m_report, item_type_line);
+  mainw_cmd_push_create(l_mainw);
 
   return;
 }
@@ -314,12 +355,12 @@ label_menuitem_activate_cb(
   GtkMenuItem *                         i_menuitem,
   gpointer                              i_user_data)
 {
-  GtkAllocation                         l_alloc;
   struct mainw*                         l_mainw;
   GtkWidget*                            l_widget;
 
   l_mainw= (struct mainw*)i_user_data;
 
+  mainw_edit_clear(l_mainw);
   report_discharge(&(*l_mainw).m_report);
   report_assign_label(&(*l_mainw).m_report);
 
@@ -337,9 +378,7 @@ label_menuitem_activate_cb(
 
   menu_label_set_defaults();
   gtk_widget_show_all(GTK_WIDGET((*l_mainw).m_paned));
-
-  gtk_widget_get_allocation(GTK_WIDGET((*l_mainw).m_window), &l_alloc);
-  g_signal_emit_by_name((*l_mainw).m_window, "size-allocate", &l_alloc, 0);
+  mainw_size_allocate_hack(l_mainw);
   database_field_destroy_cache();
 
   return;
@@ -350,12 +389,12 @@ layout_menuitem_activate_cb(
   GtkMenuItem *                         i_menuitem,
   gpointer                              i_user_data)
 {
-  GtkAllocation                         l_alloc;
   struct mainw*                         l_mainw;
   GtkWidget*                            l_widget;
 
   l_mainw= (struct mainw*)i_user_data;
 
+  mainw_edit_clear(l_mainw);
   report_discharge(&(*l_mainw).m_report);
   report_assign_layout(&(*l_mainw).m_report);
 
@@ -377,8 +416,7 @@ layout_menuitem_activate_cb(
 
   gtk_widget_show_all(GTK_WIDGET((*l_mainw).m_paned));
 
-  gtk_widget_get_allocation(GTK_WIDGET((*l_mainw).m_window), &l_alloc);
-  g_signal_emit_by_name((*l_mainw).m_window, "size-allocate", &l_alloc, 0);
+  mainw_size_allocate_hack(l_mainw);
   database_field_destroy_cache();
 
   return;
@@ -454,6 +492,7 @@ pagenumber_menuitem_activate_cb(
 
   l_mainw= (struct mainw*)i_user_data;
   report_item_new(&(*l_mainw).m_report, item_type_page_number);
+  mainw_cmd_push_create(l_mainw);
 
   return;
 }
@@ -463,7 +502,6 @@ pagesetup_menuitem_activate_cb(
   GtkMenuItem *                         i_menuitem,
   gpointer                              i_user_data)
 {
-  GtkAllocation                         l_alloc;
   struct mainw*                         l_mainw;
   int                                   l_exit;
 
@@ -508,14 +546,26 @@ pagesetup_menuitem_activate_cb(
       break;
     }
 
-    gtk_widget_get_allocation(GTK_WIDGET((*l_mainw).m_window), &l_alloc);
-    g_signal_emit_by_name((*l_mainw).m_window, "size-allocate", &l_alloc, 0);
+    mainw_size_allocate_hack(l_mainw);
 
   }while(0);
 
   return;
 }
 
+G_MODULE_EXPORT void
+paste_menuitem_activate_cb(
+  GtkMenuItem *                         i_menuitem,
+  gpointer                              i_user_data)
+{
+  struct mainw*                         l_mainw;
+
+  l_mainw= (struct mainw*)i_user_data;
+  mainw_edit_paste(l_mainw);
+
+  return;
+}
+
 G_MODULE_EXPORT void
 reportdetail_menuitem_toggled_cb(
   GtkMenuItem *                         i_menuitem,
@@ -534,8 +584,11 @@ reportdetail_menuitem_toggled_cb(
   else
   {
     layout_delete_reportdetail(&(*l_mainw).m_report.m_object.m_layout);
+    mainw_edit_clear(l_mainw);
   }
 
+  mainw_size_allocate_hack(l_mainw);
+
   return;
 }
 
@@ -557,8 +610,11 @@ reportfooter_menuitem_toggled_cb(
   else
   {
     layout_delete_reportfooter(&(*l_mainw).m_report.m_object.m_layout);
+    mainw_edit_clear(l_mainw);
   }
 
+  mainw_size_allocate_hack(l_mainw);
+
   return;
 }
 
@@ -580,8 +636,11 @@ reportheader_menuitem_toggled_cb(
   else
   {
     layout_delete_reportheader(&(*l_mainw).m_report.m_object.m_layout);
+    mainw_edit_clear(l_mainw);
   }
 
+  mainw_size_allocate_hack(l_mainw);
+
   return;
 }
 
@@ -621,6 +680,19 @@ quit_menuitem_activate_cb(
   return;
 }
 
+G_MODULE_EXPORT void
+redo_menuitem_activate_cb(
+  GtkMenuItem *                         i_menuitem,
+  gpointer                              i_user_data)
+{
+  struct mainw*                         l_mainw;
+
+  l_mainw= (struct mainw*)i_user_data;
+  mainw_edit_redo(l_mainw);
+
+  return;
+}
+
 G_MODULE_EXPORT void
 ruleline_horizontal_menuitem_toggled_cb(
   GtkCheckMenuItem *                    i_menuitem,
@@ -699,6 +771,7 @@ fsum_menuitem_activate_cb(
 
   l_mainw= (struct mainw*)i_user_data;
   report_item_new(&(*l_mainw).m_report, item_type_fsum);
+  mainw_cmd_push_create(l_mainw);
 
   return;
 }
@@ -712,6 +785,20 @@ text_menuitem_activate_cb(
 
   l_mainw= (struct mainw*)i_user_data;
   report_item_new(&(*l_mainw).m_report, item_type_text);
+  mainw_cmd_push_create(l_mainw);
+
+  return;
+}
+
+G_MODULE_EXPORT void
+undo_menuitem_activate_cb(
+  GtkMenuItem *                         i_menuitem,
+  gpointer                              i_user_data)
+{
+  struct mainw*                         l_mainw;
+
+  l_mainw= (struct mainw*)i_user_data;
+  mainw_edit_undo(l_mainw);
 
   return;
 }
@@ -721,14 +808,12 @@ zoom100_menuitem_activate_cb(
   GtkMenuItem *                         i_menuitem,
   gpointer                              i_user_data)
 {
-  GtkAllocation                         l_alloc;
   struct mainw*                         l_mainw;
 
   l_mainw= (struct mainw*)i_user_data;
   report_set_scale(&(*l_mainw).m_report, 1.00);
 
-  gtk_widget_get_allocation(GTK_WIDGET((*l_mainw).m_window), &l_alloc);
-  g_signal_emit_by_name((*l_mainw).m_window, "size-allocate", &l_alloc, 0);
+  mainw_size_allocate_hack(l_mainw);
 
   return;
 }
@@ -738,14 +823,12 @@ zoom200_menuitem_activate_cb(
   GtkMenuItem *                         i_menuitem,
   gpointer                              i_user_data)
 {
-  GtkAllocation                         l_alloc;
   struct mainw*                         l_mainw;
 
   l_mainw= (struct mainw*)i_user_data;
   report_set_scale(&(*l_mainw).m_report, 2.00);
 
-  gtk_widget_get_allocation(GTK_WIDGET((*l_mainw).m_window), &l_alloc);
-  g_signal_emit_by_name((*l_mainw).m_window, "size-allocate", &l_alloc, 0);
+  mainw_size_allocate_hack(l_mainw);
 
   return;
 }
@@ -755,14 +838,12 @@ zoom50_menuitem_activate_cb(
   GtkMenuItem *                         i_menuitem,
   gpointer                              i_user_data)
 {
-  GtkAllocation                         l_alloc;
   struct mainw*                         l_mainw;
 
   l_mainw= (struct mainw*)i_user_data;
   report_set_scale(&(*l_mainw).m_report, 0.50);
 
-  gtk_widget_get_allocation(GTK_WIDGET((*l_mainw).m_window), &l_alloc);
-  g_signal_emit_by_name((*l_mainw).m_window, "size-allocate", &l_alloc, 0);
+  mainw_size_allocate_hack(l_mainw);
 
   return;
 }
@@ -772,14 +853,12 @@ zoom75_menuitem_activate_cb(
   GtkMenuItem *                         i_menuitem,
   gpointer                              i_user_data)
 {
-  GtkAllocation                         l_alloc;
   struct mainw*                         l_mainw;
 
   l_mainw= (struct mainw*)i_user_data;
   report_set_scale(&(*l_mainw).m_report, 0.75);
 
-  gtk_widget_get_allocation(GTK_WIDGET((*l_mainw).m_window), &l_alloc);
-  g_signal_emit_by_name((*l_mainw).m_window, "size-allocate", &l_alloc, 0);
+  mainw_size_allocate_hack(l_mainw);
 
   return;
 }
@@ -789,14 +868,12 @@ zoomin_menuitem_activate_cb(
   GtkMenuItem *                         i_menuitem,
   gpointer                              i_user_data)
 {
-  GtkAllocation                         l_alloc;
   struct mainw*                         l_mainw;
 
   l_mainw= (struct mainw*)i_user_data;
   report_set_scale_zoom_in(&(*l_mainw).m_report);
 
-  gtk_widget_get_allocation(GTK_WIDGET((*l_mainw).m_window), &l_alloc);
-  g_signal_emit_by_name((*l_mainw).m_window, "size-allocate", &l_alloc, 0);
+  mainw_size_allocate_hack(l_mainw);
 
   return;
 }
@@ -806,14 +883,12 @@ zoomout_menuitem_activate_cb(
   GtkMenuItem *                         i_menuitem,
   gpointer                              i_user_data)
 {
-  GtkAllocation                         l_alloc;
   struct mainw*                         l_mainw;
 
   l_mainw= (struct mainw*)i_user_data;
   report_set_scale_zoom_out(&(*l_mainw).m_report);
 
-  gtk_widget_get_allocation(GTK_WIDGET((*l_mainw).m_window), &l_alloc);
-  g_signal_emit_by_name((*l_mainw).m_window, "size-allocate", &l_alloc, 0);
+  mainw_size_allocate_hack(l_mainw);
 
   return;
 }
@@ -822,6 +897,9 @@ GtkMenuItem*                            g_view_menuitem;
 GtkMenuItem*                            g_section_menuitem;
 GtkMenuItem*                            g_insert_menuitem;
 GtkMenuItem*                            g_break_menuitem;
+GtkMenuItem*                            g_edit_menuitem;
+GtkMenuItem*                            g_undo_menuitem;
+GtkMenuItem*                            g_redo_menuitem;
 GtkCheckMenuItem*                       g_highlight_menuitem;
 GtkCheckMenuItem*                       g_ruleline_horizontal_menuitem;
 GtkCheckMenuItem*                       g_ruleline_vertical_menuitem;
@@ -831,49 +909,104 @@ GtkCheckMenuItem*                       g_reportheader_menuitem;
 GtkCheckMenuItem*                       g_reportdetail_menuitem;
 GtkCheckMenuItem*                       g_reportfooter_menuitem;
 
+extern void
+menu_edit_redo_set_state(
+  char const*                           i_label)
+{
+  char                                  l_buf[128];
+
+  gtk_widget_set_sensitive(GTK_WIDGET(g_redo_menuitem), (ptrdiff_t)i_label); 
+
+  if (i_label)
+  {
+    snprintf(l_buf, sizeof(l_buf), "_Redo: %s", i_label);
+  }
+  else
+  {
+    snprintf(l_buf, sizeof(l_buf), "_Redo");
+  }
+
+  gtk_menu_item_set_label(g_redo_menuitem, l_buf);
+
+  return;
+}
+
+extern void
+menu_edit_undo_set_state(
+  char const*                           i_label)
+{
+  char                                  l_buf[128];
+
+  gtk_widget_set_sensitive(GTK_WIDGET(g_undo_menuitem), (ptrdiff_t)i_label); 
+
+  if (i_label)
+  {
+    snprintf(l_buf, sizeof(l_buf), "_Undo: %s", i_label);
+  }
+  else
+  {
+    snprintf(l_buf, sizeof(l_buf), "_Undo");
+  }
+
+  gtk_menu_item_set_label(g_undo_menuitem, l_buf);
+
+  return;
+}
+
 extern int
-menu_layout_bind(
-  GtkBuilder*const                      i_builder,
-  struct mainw*                         i_mainw)
+menu_bind(
+  GtkBuilder*const                      io_builder,
+  struct mainw*                         io_mainw)
 {
 
-  gtk_builder_connect_signals(i_builder, i_mainw);
+  gtk_builder_connect_signals(io_builder, io_mainw);
 
   g_view_menuitem= GTK_MENU_ITEM(
-    gtk_builder_get_object(i_builder, "view_menuitem"));
+    gtk_builder_get_object(io_builder, "view_menuitem"));
 
   g_section_menuitem= GTK_MENU_ITEM(
-    gtk_builder_get_object(i_builder, "section_menuitem"));
+    gtk_builder_get_object(io_builder, "section_menuitem"));
 
   g_insert_menuitem= GTK_MENU_ITEM(
-    gtk_builder_get_object(i_builder, "insert_menuitem"));
+    gtk_builder_get_object(io_builder, "insert_menuitem"));
 
   g_break_menuitem= GTK_MENU_ITEM(
-    gtk_builder_get_object(i_builder, "break_menuitem"));
+    gtk_builder_get_object(io_builder, "break_menuitem"));
+
+  g_edit_menuitem= GTK_MENU_ITEM(
+    gtk_builder_get_object(io_builder, "edit_menuitem"));
+
+  g_undo_menuitem= GTK_MENU_ITEM(
+    gtk_builder_get_object(io_builder, "undo_menuitem"));
+  gtk_widget_set_sensitive(GTK_WIDGET(g_undo_menuitem), 0); 
+
+  g_redo_menuitem= GTK_MENU_ITEM(
+    gtk_builder_get_object(io_builder, "redo_menuitem"));
+  gtk_widget_set_sensitive(GTK_WIDGET(g_redo_menuitem), 0); 
 
   g_highlight_menuitem= GTK_CHECK_MENU_ITEM(
-    gtk_builder_get_object(i_builder, "highlight_menuitem"));
+    gtk_builder_get_object(io_builder, "highlight_menuitem"));
 
   g_ruleline_horizontal_menuitem= GTK_CHECK_MENU_ITEM(
-    gtk_builder_get_object(i_builder, "ruleline_horizontal_menuitem"));
+    gtk_builder_get_object(io_builder, "ruleline_horizontal_menuitem"));
 
   g_ruleline_vertical_menuitem= GTK_CHECK_MENU_ITEM(
-    gtk_builder_get_object(i_builder, "ruleline_vertical_menuitem"));
+    gtk_builder_get_object(io_builder, "ruleline_vertical_menuitem"));
 
   g_coverheader_menuitem= GTK_CHECK_MENU_ITEM(
-    gtk_builder_get_object(i_builder, "coverheader_menuitem"));
+    gtk_builder_get_object(io_builder, "coverheader_menuitem"));
 
   g_coverfooter_menuitem= GTK_CHECK_MENU_ITEM(
-    gtk_builder_get_object(i_builder, "coverfooter_menuitem"));
+    gtk_builder_get_object(io_builder, "coverfooter_menuitem"));
 
   g_reportheader_menuitem= GTK_CHECK_MENU_ITEM(
-    gtk_builder_get_object(i_builder, "reportheader_menuitem"));
+    gtk_builder_get_object(io_builder, "reportheader_menuitem"));
 
   g_reportdetail_menuitem= GTK_CHECK_MENU_ITEM(
-    gtk_builder_get_object(i_builder, "reportdetail_menuitem"));
+    gtk_builder_get_object(io_builder, "reportdetail_menuitem"));
 
   g_reportfooter_menuitem= GTK_CHECK_MENU_ITEM(
-    gtk_builder_get_object(i_builder, "reportfooter_menuitem"));
+    gtk_builder_get_object(io_builder, "reportfooter_menuitem"));
 
   return 0;
 }
@@ -886,10 +1019,12 @@ menu_export_set_defaults()
   gtk_widget_set_sensitive(GTK_WIDGET(g_section_menuitem), 0);
   gtk_widget_set_sensitive(GTK_WIDGET(g_insert_menuitem), 0);
   gtk_widget_set_sensitive(GTK_WIDGET(g_break_menuitem), 0);
+  gtk_widget_set_sensitive(GTK_WIDGET(g_edit_menuitem), 0);
   gtk_widget_hide(GTK_WIDGET(g_view_menuitem));
   gtk_widget_hide(GTK_WIDGET(g_section_menuitem));
   gtk_widget_hide(GTK_WIDGET(g_insert_menuitem));
   gtk_widget_hide(GTK_WIDGET(g_break_menuitem));
+  gtk_widget_hide(GTK_WIDGET(g_edit_menuitem));
 
   return;
 }
@@ -902,10 +1037,12 @@ menu_label_set_defaults()
   gtk_widget_set_sensitive(GTK_WIDGET(g_section_menuitem), 0);
   gtk_widget_set_sensitive(GTK_WIDGET(g_insert_menuitem), 1);
   gtk_widget_set_sensitive(GTK_WIDGET(g_break_menuitem), 0);
+  gtk_widget_set_sensitive(GTK_WIDGET(g_edit_menuitem), 1);
   gtk_widget_show(GTK_WIDGET(g_view_menuitem));
   gtk_widget_hide(GTK_WIDGET(g_section_menuitem));
   gtk_widget_show(GTK_WIDGET(g_insert_menuitem));
   gtk_widget_hide(GTK_WIDGET(g_break_menuitem));
+  gtk_widget_show(GTK_WIDGET(g_edit_menuitem));
 
   gtk_check_menu_item_set_active(g_highlight_menuitem, 0);
   gtk_check_menu_item_set_active(g_ruleline_horizontal_menuitem, 0);
@@ -922,10 +1059,12 @@ menu_layout_set_defaults()
   gtk_widget_set_sensitive(GTK_WIDGET(g_section_menuitem), 1);
   gtk_widget_set_sensitive(GTK_WIDGET(g_insert_menuitem), 1);
   gtk_widget_set_sensitive(GTK_WIDGET(g_break_menuitem), 1);
+  gtk_widget_set_sensitive(GTK_WIDGET(g_edit_menuitem), 1);
   gtk_widget_show(GTK_WIDGET(g_view_menuitem));
   gtk_widget_show(GTK_WIDGET(g_section_menuitem));
   gtk_widget_show(GTK_WIDGET(g_insert_menuitem));
   gtk_widget_show(GTK_WIDGET(g_break_menuitem));
+  gtk_widget_show(GTK_WIDGET(g_edit_menuitem));
 
   gtk_check_menu_item_set_active(g_highlight_menuitem, 0);
   gtk_check_menu_item_set_active(g_ruleline_horizontal_menuitem, 0);
