@@ -44,8 +44,28 @@ extern void
 query_clear(
   struct query*                         io_query)
 {
+  struct query_node*                    l_node;
+  struct query_node*                    l_next;
+
+  l_node= (*io_query).m_head;
+
+  do
+  {
+
+    if (0 == l_node)
+    {
+      break;
+    }
+
+    l_next= (*l_node).m_next;
+
+    query_node_discharge(l_node);
+
+    g_free(l_node);
+    l_node= l_next;
+
+  }while(1);
 
-  query_list_delete(io_query);
   memset(io_query, 0, sizeof(*io_query));
 
   return;
@@ -152,22 +172,22 @@ query_first_new(
 extern void
 query_insert_after(
   struct query*const                     io_query,
-  struct query_node*const                i_node,
-  struct query_node*const                i_node_new)
+  struct query_node*const                io_node,
+  struct query_node*const                io_node_new)
 {
 
-  if (0 == (*i_node).m_next)
+  if (0 == (*io_node).m_next)
   {
-    (*io_query).m_tail= i_node_new;
+    (*io_query).m_tail= io_node_new;
   }
   else
   {
-    (*i_node).m_next->m_prev= i_node_new;
+    (*io_node).m_next->m_prev= io_node_new;
   }
 
-  (*i_node_new).m_next= (*i_node).m_next;
-  (*i_node_new).m_prev= i_node;
-  (*i_node).m_next= i_node_new;
+  (*io_node_new).m_next= (*io_node).m_next;
+  (*io_node_new).m_prev= io_node;
+  (*io_node).m_next= io_node_new;
 
   return;
 }
@@ -175,22 +195,22 @@ query_insert_after(
 extern void
 query_insert_before(
   struct query*const                     io_query,
-  struct query_node*const                i_node,
-  struct query_node*const                i_node_new)
+  struct query_node*const                io_node,
+  struct query_node*const                io_node_new)
 {
 
-  if (0 == (*i_node).m_prev)
+  if (0 == (*io_node).m_prev)
   {
-    (*io_query).m_head= i_node_new;
+    (*io_query).m_head= io_node_new;
   }
   else
   {
-    (*i_node).m_prev->m_next= i_node_new;
+    (*io_node).m_prev->m_next= io_node_new;
   }
 
-  (*i_node_new).m_next= i_node;
-  (*i_node_new).m_prev= (*i_node).m_prev;
-  (*i_node).m_prev= i_node_new;
+  (*io_node_new).m_next= io_node;
+  (*io_node_new).m_prev= (*io_node).m_prev;
+  (*io_node).m_prev= io_node_new;
 
   return;
 }
@@ -224,44 +244,12 @@ query_last_new(
   return;
 }
 
-extern void
-query_list_delete(
-  struct query*                         io_query)
-{
-  struct query_node*                    l_node;
-  struct query_node*                    l_next;
-
-  l_node= (*io_query).m_head;
-
-  do
-  {
-
-    if (0 == l_node)
-    {
-      break;
-    }
-
-    l_next= (*l_node).m_next;
-
-    query_node_discharge(l_node);
-
-    g_free(l_node);
-    l_node= l_next;
-
-  }while(1);
-
-  (*io_query).m_head= 0;
-  (*io_query).m_tail= 0;
-
-  return;
-}
-
 extern void
 query_node_assign(
-  struct query_node*                    io_node)
+  struct query_node*                    o_node)
 {
 
-  memset(io_node, 0, sizeof(*io_node));
+  memset(o_node, 0, sizeof(*o_node));
 
   return;
 }
