@@ -619,9 +619,10 @@ query_exec_lookup(
 
 static int
 query_exec_write(
-  FILE*                                 io_fp,
+  GOutputStream*                        io_gio,
   struct query_exec_node const*const    i_sql)
 {
+  gsize                                 l_bytes;
   int                                   l_exit;
   struct sql_node*                      l_node;
 
@@ -640,41 +641,44 @@ query_exec_write(
     {
       if ((*l_node).m_object.m_segment.m_text)
       {
-        fwrite(
+        g_output_stream_write(
+          io_gio,
           (*l_node).m_object.m_segment.m_text, 
           (*l_node).m_object.m_segment.m_size, 
-          1,
-          io_fp);
+          0,
+          0);
       }
     }
     else if (sql_type_input == (*l_node).m_type)
     {
       if ((*l_node).m_object.m_input.m_answer)
       {
-        fwrite(
+        g_output_stream_write(
+          io_gio,
           (*l_node).m_object.m_input.m_answer,
           strlen((*l_node).m_object.m_input.m_answer),
-          1,
-          io_fp);
+          0,
+          0);
       }
       else
       {
-        fwrite("''", 2, 1, io_fp);
+        g_output_stream_printf(io_gio, &l_bytes, 0, 0, "''");
       }
     }
     else if (sql_type_parm == (*l_node).m_type)
     {
       if ((*l_node).m_object.m_parm.m_answer)
       {
-        fwrite(
+        g_output_stream_write(
+          io_gio,
           (*l_node).m_object.m_parm.m_answer,
           strlen((*l_node).m_object.m_parm.m_answer),
-          1,
-          io_fp);
+          0,
+          0);
       }
       else
       {
-        fwrite("''", 2, 1, io_fp);
+        g_output_stream_printf(io_gio, &l_bytes, 0, 0, "''");
       }
     }
 
@@ -696,13 +700,13 @@ query_exec_prepare(
   GError*                               l_error;
   int                                   l_exit;
   FILE*                                 l_fp;
+  GOutputStream*                        l_gio;
   struct query_exec_node*               l_query;
-  size_t                                l_size;
-  char*                                 l_text;
 
   l_error= 0;
   l_exit= 0;
   l_fp= 0;
+  l_gio= 0;
 
   do
   {
@@ -723,21 +727,6 @@ query_exec_prepare(
       l_exit= query_exec_prompt_set_values(io_exec, i_prompt);
     }
 
-    l_fp= tmpfile();
-
-    if (0 == l_fp)
-    {
-      l_error= g_error_new(
-        QUERY_EXEC, 
-        QUERY_EXEC_FILE_CREATE1,
-        "Unable to create temporary file; errno(%d)='%s'",
-        errno,
-        strerror(errno));
-      _error_log(l_error);
-      l_exit= -1; 
-      break;
-    }
-
     l_query= &(*io_exec).m_sql[PRIMARY];
 
     if (0 == l_query)
@@ -745,30 +734,23 @@ query_exec_prepare(
       break;
     }
 
-    query_exec_write(l_fp, l_query);
-
-    fseek(l_fp, 0, SEEK_END);
-    l_size= ftell(l_fp);
-    fseek(l_fp, 0, SEEK_SET);
-
-    l_text= (char*)g_malloc0(1+l_size);
-    memset(l_text, 0, (1+l_size));
-
-    fread(l_text, l_size, 1, l_fp);
+    l_gio= g_memory_output_stream_new_resizable();
+    query_exec_write(l_gio, l_query);
 
     if ((*l_query).m_text)
     {
       g_free((*l_query).m_text);
     }
 
-    (*l_query).m_text= l_text;
-    (*l_query).m_text_size= l_size;
+    g_output_stream_close(l_gio, 0, 0);
+    (*l_query).m_text= g_memory_output_stream_steal_data(G_MEMORY_OUTPUT_STREAM(l_gio));
+    (*l_query).m_text_size= g_memory_output_stream_get_data_size(G_MEMORY_OUTPUT_STREAM(l_gio));
 
   }while(0);
 
-  if (l_fp)
+  if (l_gio)
   {
-    fclose(l_fp);
+    g_object_unref(l_gio);
   }
 
   if (l_error)
@@ -998,14 +980,13 @@ query_exec_next(
   int                                   l_eof;
   GError*                               l_error;
   int                                   l_exit;
-  FILE*                                 l_fp;
+  GOutputStream*                        l_gio;
   struct query_exec_node*               l_query;
-  size_t                                l_size;
   unsigned                              l_slot;
-  char*                                 l_text;
 
   l_error= 0;
   l_exit= 0;
+  l_gio= 0;
   (*o_eof)= 0;
 
   do
@@ -1044,41 +1025,17 @@ query_exec_next(
 
       query_exec_parm_resolve(io_exec, l_slot);
 
-      l_fp= tmpfile();
-
-      if (0 == l_fp)
-      {
-        l_error= g_error_new(
-          QUERY_EXEC, 
-          QUERY_EXEC_FILE_CREATE2,
-          "Unable to create temporary file; errno(%d)='%s'",
-          errno,
-          strerror(errno));
-        _error_log(l_error);
-        l_exit= -1;
-        break;
-      }
-
-      query_exec_write(l_fp, l_query);
-
-      fseek(l_fp, 0, SEEK_END);
-      l_size= ftell(l_fp);
-      fseek(l_fp, 0, SEEK_SET);
-
-      l_text= (char*)g_malloc0(1+l_size);
-      memset(l_text, 0, (1+l_size));
-
-      fread(l_text, l_size, 1, l_fp);
-      fclose(l_fp);
-      l_fp= 0;
+      l_gio= g_memory_output_stream_new_resizable();
+      query_exec_write(l_gio, l_query);
 
       if ((*l_query).m_text)
       {
         g_free((*l_query).m_text);
       }
 
-      (*l_query).m_text= l_text;
-      (*l_query).m_text_size= l_size;
+      g_output_stream_close(l_gio, 0, 0);
+      (*l_query).m_text= g_memory_output_stream_steal_data(G_MEMORY_OUTPUT_STREAM(l_gio));
+      (*l_query).m_text_size= g_memory_output_stream_get_data_size(G_MEMORY_OUTPUT_STREAM(l_gio));
 
       l_exit= database_session_exec_buffer(
         &l_error,
@@ -1111,6 +1068,11 @@ query_exec_next(
 
   }while(0);
 
+  if (l_gio)
+  {
+    g_object_unref(l_gio);
+  }
+
   if (l_error)
   {
     g_propagate_error(o_error, l_error);
