@@ -603,11 +603,13 @@ void
 query_property_show_results(
   struct query_exec const*const         io_exec)
 {
+  char                                  l_buf[15+1];
   GtkTextBuffer*                        l_buffer;
   GtkBuilder*                           l_builder;
+  gsize                                 l_bytes;
   GtkDialog*                            l_dialog;
   GError*                               l_error;
-  FILE*                                 l_fp;
+  GOutputStream*                        l_gio;
   struct query_exec_node*               l_query;
   int                                   l_rc;
   size_t                                l_size;
@@ -615,24 +617,18 @@ query_property_show_results(
   unsigned                              l_slot_sql;
   char*                                 l_text;
   GtkTextView*                          l_textview;
-  char                                  l_buf[15+1];
 
   l_builder= 0;
   l_dialog= 0;
   l_error= 0;
+  l_gio= 0;
   l_text= 0;
   memset(&l_buf[0], 0, sizeof(l_buf));
 
   do
   {
 
-    l_fp= tmpfile();
-
-    if (0 == l_fp)
-    {
-      break;
-    }
-
+    l_gio= g_memory_output_stream_new_resizable();
     l_query= &(*io_exec).m_sql[0];
     l_slot_sql= 0;
 
@@ -647,17 +643,17 @@ query_property_show_results(
       for(l_slot_attr= 0; (*l_query).m_attr_count > l_slot_attr; l_slot_attr++)
       {
         strncpy(l_buf, (*l_query).m_attr[l_slot_attr].m_tag, sizeof(l_buf)-1);
-        fprintf(l_fp, "%-15s  ", l_buf);
+        g_output_stream_printf(l_gio, &l_bytes, 0, 0, "%-15s  ", l_buf);
       }
 
-      fprintf(l_fp, "\n");
+      g_output_stream_printf(l_gio, &l_bytes, 0, 0, "\n");
 
       for(l_slot_attr= 0; (*l_query).m_attr_count > l_slot_attr; l_slot_attr++)
       {
-        fprintf(l_fp, "---------------  ");
+        g_output_stream_printf(l_gio, &l_bytes, 0, 0, "---------------  ");
       }
 
-      fprintf(l_fp, "\n");
+      g_output_stream_printf(l_gio, &l_bytes, 0, 0, "\n");
 
       for(l_slot_attr= 0; (*l_query).m_attr_count > l_slot_attr; l_slot_attr++)
       {
@@ -667,26 +663,16 @@ query_property_show_results(
           strncpy(l_buf, (*l_query).m_attr[l_slot_attr].m_value, sizeof(l_buf)-1);
         }
         utf8_scrub_kludge(l_buf); 
-        fprintf(l_fp, "%-15s  ", l_buf);
+        g_output_stream_printf(l_gio, &l_bytes, 0, 0, "%-15s  ", l_buf);
       }
 
-      fprintf(l_fp, "\n\n");
+      g_output_stream_printf(l_gio, &l_bytes, 0, 0, "\n\n");
 
       l_slot_sql++;
       l_query++;
 
     }while(1);
 
-    fseek(l_fp, 0, SEEK_END);
-    l_size= ftell(l_fp);
-    fseek(l_fp, 0, SEEK_SET);
-
-    l_text= (char*)g_malloc0(1+l_size);
-
-    fread(l_text, l_size, 1, l_fp);
-    fclose(l_fp);
-    l_fp= 0;
-
     l_builder= gtk_builder_new();
 
     l_rc= wrap_gtk_builder_add_from_file(
@@ -715,6 +701,8 @@ query_property_show_results(
     gtk_text_view_set_monospace(l_textview, 1);
 #endif
     l_buffer= gtk_text_view_get_buffer(l_textview);
+    l_text= g_memory_output_stream_get_data(G_MEMORY_OUTPUT_STREAM(l_gio));
+    l_size= g_memory_output_stream_get_data_size(G_MEMORY_OUTPUT_STREAM(l_gio));
     gtk_text_buffer_set_text(l_buffer, l_text, l_size);
 
     gtk_window_set_transient_for(GTK_WINDOW(l_dialog), get_main_window());
@@ -724,6 +712,11 @@ query_property_show_results(
 
   }while(0);
 
+  if (l_gio)
+  {
+    g_object_unref(l_gio);
+  }
+
   if (l_error)
   {
     _error_display_prompt(l_error);
@@ -731,11 +724,6 @@ query_property_show_results(
 
   g_clear_error(&l_error);
 
-  if (l_text)
-  {
-    g_free(l_text);
-  }
-
   if (l_dialog)
   {
     gtk_widget_destroy((GtkWidget*)l_dialog);
