@@ -284,19 +284,19 @@ report_layout_division_new_from_layout_spec(
       break;
     }
 
-    l_widget= gtk_button_new_with_label((*io_spec).m_tag);
+    l_widget= gtk_button_new_with_label((*io_spec).m_label);
     gtk_button_set_relief(GTK_BUTTON(l_widget), GTK_RELIEF_NONE);
     gtk_widget_set_sensitive(l_widget, 0);
     l_page= IWR_PAGE(iwr_page_new());
     (*io_div).m_page= l_page;
-    g_strlcpy((*io_div).m_tag, (*io_spec).m_tag, sizeof((*io_div).m_tag));
+    (*io_div).m_label= g_strdup((*io_spec).m_label);
     iwr_page_set_section_type(l_page, (*io_spec).m_type);
     l_paper= (*io_spec).m_paper;
     paper_convert_to_points(&l_paper);
     iwr_page_set_paper(l_page, &l_paper);
     iwr_page_get_item(&l_item, (*io_div).m_page);
     (*l_item)= *(*io_spec).m_item;
-    memset((*io_spec).m_item, 0, sizeof(*(*io_spec).m_item));
+    (*io_spec).m_item= 0;
     gtk_grid_attach((*io_layout).m_grid, l_widget, 0, (*io_row)++, 1, 1);
     gtk_grid_attach((*io_layout).m_grid, GTK_WIDGET(l_page), 0, (*io_row)++, 1, 1);
     g_signal_connect(l_page, "size-allocate", G_CALLBACK(layout_division_size_allocate_cb), io_layout);
@@ -365,6 +365,9 @@ report_read_layout(
       l_layout,
       &l_row);
 
+    (*l_layout).m_page_break.m_column= l_spec.m_page_break.m_column;
+    l_spec.m_page_break.m_column= 0;
+
     if (l_spec.m_group_slots)
     {
       (*l_layout).m_group= (struct layout_division_group*)
@@ -374,10 +377,8 @@ report_read_layout(
 
       for (l_slot= 0; l_spec.m_group_slots > l_slot; l_slot++)
       {
-        memcpy(
-          &(*l_layout).m_group[l_slot].m_break,
-          &l_spec.m_group[l_slot].m_break,
-          sizeof((*l_layout).m_group[l_slot].m_break));
+        (*l_layout).m_group[l_slot].m_break.m_column= l_spec.m_group[l_slot].m_break.m_column;
+        l_spec.m_group[l_slot].m_break.m_column= 0;
         report_layout_division_new_from_layout_spec(
           &(*l_layout).m_group[l_slot].m_header,
           &l_spec.m_group[l_slot].m_header,
