@@ -101,11 +101,6 @@ report_read(
   GtkWidget**                           o_widget,
   struct report*const                   io_report);
 
-extern int
-report_run(
-  struct report*const                   io_report,
-  char const*                           i_outputfile);
-
 extern void
 report_set_horizontal_ruler_line(
   struct report *const                  io_report,
