@@ -48,23 +48,38 @@ rw_attr_lookup_by_name(
   struct iwsql_attr const**             o_attr,
   struct query_exec const*const         i_exec,
   char const*                           i_table,
-  char const*                           i_field)
+  char const*                           i_column)
 {
   struct query_exec_node const*         l_query;
+  char const*                           l_table;
 
   (*o_attr)= 0;
 
   do
   {
 
-    query_exec_lookup(&l_query, i_table, i_exec);
+    if (0 == i_column)
+    {
+      break;
+    }
+
+    if (i_table)
+    {
+      l_table= i_table;
+    }
+    else
+    {
+      l_table= "primary";
+    }
+
+    query_exec_lookup(&l_query, l_table, i_exec);
 
     if (0 == l_query)
     {
       break;
     }
 
-    query_exec_node_lookup(o_attr, i_field, l_query);
+    query_exec_node_lookup(o_attr, i_column, l_query);
 
   }while(0);
 
@@ -145,51 +160,35 @@ rw_discharge(
 
 static void
 rw_fbarcode_set_value(
-  struct item_fbarcode*                 io_fbarcode,
+  struct item_fbarcode*                 io_object,
   struct query_exec*const               io_exec)
 {
   struct iwsql_attr const*              l_attr;
-  char                                  l_buf[1+FIELD_NAME_MAX_LEN];
-  char*                                 l_table;
-  char*                                 l_field;
-  char*                                 l_ptr;
 
   do
   {
 
-    if ((*io_fbarcode).m_value)
+    if ((*io_object).m_value)
     {
-      g_free((*io_fbarcode).m_value);
-      (*io_fbarcode).m_value= 0;
-      (*io_fbarcode).m_value_size= 0;
+      g_free((*io_object).m_value);
+      (*io_object).m_value= 0;
+      (*io_object).m_value_size= 0;
     }
 
-    memset(l_buf, 0, sizeof(l_buf));
-    g_strlcpy(l_buf, (*io_fbarcode).m_tag, sizeof(l_buf));
-    l_ptr= strchr(l_buf, '.');
-
-    if (0 == l_ptr)
-    {
-      l_table= "primary";
-      l_field= l_buf;
-    } 
-    else
-    {
-      (*l_ptr)= 0;
-      l_table= l_buf;
-      l_field= l_ptr+1;
-    }
-
-    rw_attr_lookup_by_name(&l_attr, io_exec, l_table, l_field);
+    rw_attr_lookup_by_name(
+      &l_attr,
+      io_exec,
+      (*io_object).m_table.m_query,
+      (*io_object).m_table.m_column);
 
     if (0 == l_attr)
     {
       break;
     }
 
-    (*io_fbarcode).m_value= g_malloc0((*l_attr).m_size);
-    memcpy((*io_fbarcode).m_value, (*l_attr).m_value, (*l_attr).m_size);
-    (*io_fbarcode).m_value_size= (*l_attr).m_size;
+    (*io_object).m_value= g_malloc0((*l_attr).m_size);
+    memcpy((*io_object).m_value, (*l_attr).m_value, (*l_attr).m_size);
+    (*io_object).m_value_size= (*l_attr).m_size;
 
   }while(0);
 
@@ -198,14 +197,10 @@ rw_fbarcode_set_value(
 
 static void
 rw_sum_set_value(
-  struct item_fsum*const                io_sum,
+  struct item_fsum*const                io_object,
   struct query_exec*const               io_exec)
 {
   struct iwsql_attr const*              l_attr;
-  char                                  l_buf[1+FIELD_NAME_MAX_LEN];
-  char*                                 l_field;
-  char*                                 l_ptr;
-  char*                                 l_table;
   decNumber                             l_value;
 
   memset(&l_value, 0, sizeof(l_value));
@@ -213,35 +208,23 @@ rw_sum_set_value(
   do
   {
 
-    memset(l_buf, 0, sizeof(l_buf));
-    g_strlcpy(l_buf, (*io_sum).m_tag, sizeof(l_buf));
-    l_ptr= strchr(l_buf, '.');
-
-    if (0 == l_ptr)
-    {
-      l_table= "primary";
-      l_field= l_buf;
-    } 
-    else
-    {
-      (*l_ptr)= 0;
-      l_table= l_buf;
-      l_field= l_ptr+1;
-    }
-
-    rw_attr_lookup_by_name(&l_attr, io_exec, l_table, l_field);
+    rw_attr_lookup_by_name(
+      &l_attr,
+      io_exec,
+      (*io_object).m_table.m_query,
+      (*io_object).m_table.m_column);
 
     if (0 == l_attr)
     {
       break;
     }
 
-    decNumberFromString(&l_value, (*l_attr).m_value, &(*io_sum).m_ctx);
+    decNumberFromString(&l_value, (*l_attr).m_value, &(*io_object).m_ctx);
     decNumberAdd(
-      &(*io_sum).m_accumulator, 
-      &(*io_sum).m_accumulator, 
+      &(*io_object).m_accumulator, 
+      &(*io_object).m_accumulator, 
       &l_value,
-      &(*io_sum).m_ctx);
+      &(*io_object).m_ctx);
 
   }while(0);
 
@@ -250,51 +233,35 @@ rw_sum_set_value(
 
 static void
 rw_fimage_set_value(
-  struct item_fimage*                   io_fimage,
+  struct item_fimage*                   io_object,
   struct query_exec*const               io_exec)
 {
   struct iwsql_attr const*              l_attr;
-  char                                  l_buf[1+FIELD_NAME_MAX_LEN];
-  char*                                 l_table;
-  char*                                 l_field;
-  char*                                 l_ptr;
 
   do
   {
 
-    if ((*io_fimage).m_value)
+    if ((*io_object).m_value)
     {
-      g_free((*io_fimage).m_value);
-      (*io_fimage).m_value= 0;
-      (*io_fimage).m_value_size= 0;
+      g_free((*io_object).m_value);
+      (*io_object).m_value= 0;
+      (*io_object).m_value_size= 0;
     }
 
-    memset(l_buf, 0, sizeof(l_buf));
-    g_strlcpy(l_buf, (*io_fimage).m_tag, sizeof(l_buf));
-    l_ptr= strchr(l_buf, '.');
-
-    if (0 == l_ptr)
-    {
-      l_table= "primary";
-      l_field= l_buf;
-    } 
-    else
-    {
-      (*l_ptr)= 0;
-      l_table= l_buf;
-      l_field= l_ptr+1;
-    }
-
-    rw_attr_lookup_by_name(&l_attr, io_exec, l_table, l_field);
+    rw_attr_lookup_by_name(
+      &l_attr,
+      io_exec,
+      (*io_object).m_table.m_query,
+      (*io_object).m_table.m_column);
 
     if (0 == l_attr)
     {
       break;
     }
 
-    (*io_fimage).m_value= g_malloc0((*l_attr).m_size);
-    memcpy((*io_fimage).m_value, (*l_attr).m_value, (*l_attr).m_size);
-    (*io_fimage).m_value_size= (*l_attr).m_size;
+    (*io_object).m_value= g_malloc0((*l_attr).m_size);
+    memcpy((*io_object).m_value, (*l_attr).m_value, (*l_attr).m_size);
+    (*io_object).m_value_size= (*l_attr).m_size;
 
   }while(0);
 
@@ -303,48 +270,32 @@ rw_fimage_set_value(
 
 static void
 rw_fnumber_set_value(
-  struct item_fnumber*                  io_fnumber,
+  struct item_fnumber*                  io_object,
   struct query_exec*const               io_exec)
 {
   struct iwsql_attr const*              l_attr;
-  char                                  l_buf[1+FIELD_NAME_MAX_LEN];
-  char*                                 l_table;
-  char*                                 l_field;
-  char*                                 l_ptr;
 
   do
   {
 
-    if ((*io_fnumber).m_value)
+    if ((*io_object).m_value)
     {
-      g_free((*io_fnumber).m_value);
-      (*io_fnumber).m_value= 0;
+      g_free((*io_object).m_value);
+      (*io_object).m_value= 0;
     }
 
-    memset(l_buf, 0, sizeof(l_buf));
-    g_strlcpy(l_buf, (*io_fnumber).m_tag, sizeof(l_buf));
-    l_ptr= strchr(l_buf, '.');
-
-    if (0 == l_ptr)
-    {
-      l_table= "primary";
-      l_field= l_buf;
-    } 
-    else
-    {
-      (*l_ptr)= 0;
-      l_table= l_buf;
-      l_field= l_ptr+1;
-    }
-
-    rw_attr_lookup_by_name(&l_attr, io_exec, l_table, l_field);
+    rw_attr_lookup_by_name(
+      &l_attr,
+      io_exec,
+      (*io_object).m_table.m_query,
+      (*io_object).m_table.m_column);
 
     if (0 == l_attr)
     {
       break;
     }
 
-    (*io_fnumber).m_value= g_strdup((*l_attr).m_value);
+    (*io_object).m_value= g_strdup((*l_attr).m_value);
 
   }while(0);
 
@@ -353,48 +304,32 @@ rw_fnumber_set_value(
 
 static void
 rw_ftext_set_value(
-  struct item_ftext*                    io_ftext,
+  struct item_ftext*                    io_object,
   struct query_exec*const               io_exec)
 {
   struct iwsql_attr const*              l_attr;
-  char                                  l_buf[1+FIELD_NAME_MAX_LEN];
-  char*                                 l_table;
-  char*                                 l_field;
-  char*                                 l_ptr;
 
   do
   {
 
-    if ((*io_ftext).m_value)
+    if ((*io_object).m_value)
     {
-      g_free((*io_ftext).m_value);
-      (*io_ftext).m_value= 0;
+      g_free((*io_object).m_value);
+      (*io_object).m_value= 0;
     }
 
-    memset(l_buf, 0, sizeof(l_buf));
-    g_strlcpy(l_buf, (*io_ftext).m_tag, sizeof(l_buf));
-    l_ptr= strchr(l_buf, '.');
-
-    if (0 == l_ptr)
-    {
-      l_table= "primary";
-      l_field= l_buf;
-    } 
-    else
-    {
-      (*l_ptr)= 0;
-      l_table= l_buf;
-      l_field= l_ptr+1;
-    }
-
-    rw_attr_lookup_by_name(&l_attr, io_exec, l_table, l_field);
+    rw_attr_lookup_by_name(
+      &l_attr,
+      io_exec,
+      (*io_object).m_table.m_query,
+      (*io_object).m_table.m_column);
 
     if (0 == l_attr)
     {
       break;
     }
 
-    (*io_ftext).m_value= g_strdup((*l_attr).m_value);
+    (*io_object).m_value= g_strdup((*l_attr).m_value);
 
   }while(0);
 
@@ -402,7 +337,7 @@ rw_ftext_set_value(
 }
 
 /*
- * ':{'[table'.']field'}'
+ * ':{'[table'.']column'}'
  * escape '::{' results in ':{'
  */
 static void
@@ -411,16 +346,15 @@ rw_text_set_value(
   struct query_exec*const               io_exec)
 {
   struct iwsql_attr const*              l_attr;
-  char*                                 l_buf;
-  char*                                 l_field;
-  FILE*                                 l_fp;
-  FILE*                                 l_fp2;
-  char*                                 l_ptr;
-  size_t                                l_size;
-  char*                                 l_table;
-  char*                                 l_tail;
+  gchar*                                l_buf;
+  gchar*                                l_column;
+  gchar*                                l_ptr;
+  GString*                              l_lookup;
+  gchar*                                l_table;
+  gchar*                                l_tail;
+  GString*                              l_value;
 
-  l_fp= tmpfile();
+  l_value= g_string_new(0);
 
   do
   {
@@ -431,11 +365,6 @@ rw_text_set_value(
       (*io_text).m_value= 0;
     }
 
-    if (0 == l_fp)
-    {
-      break;
-    }
-
     l_tail= (*io_text).m_text;
 
     if (0 == l_tail)
@@ -454,7 +383,7 @@ rw_text_set_value(
       if (':' != l_tail[0])
       {
 rw_text_fill_store:
-        fwrite(l_tail, 1, 1, l_fp);
+        g_string_append_c(l_value, l_tail[0]);
         l_tail++;
         continue;
       }
@@ -468,11 +397,12 @@ rw_text_fill_store:
 
       if ('{' != l_tail[0])
       {
+        g_string_append_c(l_value, ':');
         goto rw_text_fill_store;
       }
 
       l_tail++;
-      l_fp2= tmpfile();
+      l_lookup= g_string_new(0);
 
       do  
       {
@@ -487,57 +417,41 @@ rw_text_fill_store:
           break;
         }
 
-        fwrite(l_tail, 1, 1, l_fp2);
+        g_string_append_c(l_lookup, l_tail[0]);
         l_tail++;
 
       }while(1);
 
-      l_size= ftell(l_fp2);
-      l_buf= (char*)g_malloc0(1+l_size);
-      fseek(l_fp2, 0, SEEK_SET);
-      fread(l_buf, l_size, 1, l_fp2);
-      fclose(l_fp2);
+      l_buf= g_string_free(l_lookup, 0);
       l_ptr= strchr(l_buf, '.');
 
       if (0 == l_ptr)
       {
         l_table= "primary";
-        l_field= l_buf;
+        l_column= l_buf;
       } 
       else
       {
         (*l_ptr)= 0;
         l_table= l_buf;
-        l_field= l_ptr+1;
+        l_column= l_ptr+1;
       }
 
-      rw_attr_lookup_by_name(&l_attr, io_exec, l_table, l_field);
+      rw_attr_lookup_by_name(&l_attr, io_exec, l_table, l_column);
       g_free(l_buf);
-      l_buf= 0;
 
       if (l_attr && (*l_attr).m_value)
       {
-        l_size= strlen((*l_attr).m_value);
-        fwrite((*l_attr).m_value, l_size, 1, l_fp);
+        g_string_append(l_value, (*l_attr).m_value);
       }
 
       l_tail++;
 
     }while(1);
 
-    l_size= ftell(l_fp);
-    l_buf= (char*)g_malloc0(1+l_size);
-    fseek(l_fp, 0, SEEK_SET);
-    fread(l_buf, l_size, 1, l_fp);
-    (*io_text).m_value= l_buf;
-    l_buf= 0;
-
   }while(0);
 
-  if (l_fp)
-  {
-    fclose(l_fp);
-  }
+  (*io_text).m_value= g_string_free(l_value, 0);
 
   return;
 }
@@ -566,9 +480,12 @@ rw_page_number_set_value(
 
 extern void
 rw_item_clear_accumulator(
-  struct item*const                     io_item)
+  struct item*const                     io_item,
+  char const*                           i_group)
 {
+  struct item_fsum*                     l_fsum;
   struct item_node*                     l_node;
+  int                                   l_rc;
 
   do
   {
@@ -588,20 +505,35 @@ rw_item_clear_accumulator(
         break;
       }
 
-      if (item_type_fsum == (*l_node).m_type)
+      do
       {
 
-        memset(
-          &(*l_node).m_object.m_fsum.m_accumulator,
-          0,
-          sizeof((*l_node).m_object.m_fsum.m_accumulator));
+        if (item_type_fsum != (*l_node).m_type)
+        {
+          break;
+        }
 
-        decNumberFromString(
-          &(*l_node).m_object.m_fsum.m_accumulator,
-          "0.0",
-          &(*l_node).m_object.m_fsum.m_ctx);
+        l_fsum= &(*l_node).m_object.m_fsum;
 
-      }
+        if (i_group)
+        {
+          if (0 == (*l_fsum).m_group)
+          {
+            break;
+          }
+
+          l_rc= strcmp((*l_fsum).m_group, i_group);
+
+          if (l_rc)
+          {
+            break;
+          }
+        }
+
+        memset(&(*l_fsum).m_accumulator, 0, sizeof((*l_fsum).m_accumulator));
+        decNumberFromString(&(*l_fsum).m_accumulator, "0.0", &(*l_fsum).m_ctx);
+
+      }while(0);
 
       l_node= (*l_node).m_next;
 
@@ -682,18 +614,18 @@ rw_layout_clear_accumulator(
 {
   unsigned                              l_slot;
 
-  rw_item_clear_accumulator((*io_layout).m_cover.m_header.m_item);
-  rw_item_clear_accumulator((*io_layout).m_cover.m_footer.m_item);
-  rw_item_clear_accumulator((*io_layout).m_report.m_header.m_item);
-  rw_item_clear_accumulator((*io_layout).m_report.m_detail.m_item);
-  rw_item_clear_accumulator((*io_layout).m_report.m_footer.m_item);
+  rw_item_clear_accumulator((*io_layout).m_cover.m_header.m_item, 0);
+  rw_item_clear_accumulator((*io_layout).m_cover.m_footer.m_item, 0);
+  rw_item_clear_accumulator((*io_layout).m_report.m_header.m_item, 0);
+  rw_item_clear_accumulator((*io_layout).m_report.m_detail.m_item, 0);
+  rw_item_clear_accumulator((*io_layout).m_report.m_footer.m_item, 0);
 
   for (l_slot= 0; (*io_layout).m_group_slots > l_slot; l_slot++)
   {
     g_free((*io_layout).m_group[l_slot].m_break.m_value);
     (*io_layout).m_group[l_slot].m_break.m_value= 0;
-    rw_item_clear_accumulator((*io_layout).m_group[l_slot].m_header.m_item);
-    rw_item_clear_accumulator((*io_layout).m_group[l_slot].m_footer.m_item);
+    rw_item_clear_accumulator((*io_layout).m_group[l_slot].m_header.m_item, 0);
+    rw_item_clear_accumulator((*io_layout).m_group[l_slot].m_footer.m_item, 0);
   }
 
   return;
@@ -716,13 +648,13 @@ rw_level_break_set_value(
     (*io_layout).m_page_break.m_value= 0;
   }
 
-  if ((*io_layout).m_page_break.m_tag && (*io_layout).m_page_break.m_tag[0])
+  if ((*io_layout).m_page_break.m_column && (*io_layout).m_page_break.m_column[0])
   {
     rw_attr_lookup_by_name(
       &l_attr,
       &(*i_rw).m_exec,
       "primary",
-      (*io_layout).m_page_break.m_tag);
+      (*io_layout).m_page_break.m_column);
 
     if (l_attr)
     {
@@ -743,7 +675,7 @@ rw_level_break_set_value(
       &l_attr,
       &(*i_rw).m_exec,
       "primary",
-      (*l_group).m_break.m_tag);
+      (*l_group).m_break.m_column);
 
     if ((*l_group).m_break.m_value)
     {
