@@ -98,7 +98,8 @@ rw_layout_set_fence(
 
 extern void
 rw_item_clear_accumulator(
-  struct item*const                     io_item);
+  struct item*const                     io_item,
+  char const*                           i_group);
 
 #define __rw_h__
 #endif
